# MODEL High-Speed Rail System
# Andrew Stephenson
# University of Nevada, Reno
# ------------------------------------------------------------------------------------------------------------------------------------------------------------------

wipe;	 							# Clear memory of all past model definitions
model BasicBuilder -ndm 3 -ndf 6;	# Define the model builder, ndm=#dimension, ndf=#dofs
set dataDir DataLC6_KB_x2;			# Directory name
set scale 2;						# GM Scale
file mkdir $dataDir;				# Create data directory
set GMdir "../GMfiles";				# Ground-motion file directory
set g 9.810;						# Gravitational acceleration  

# ------------------------------------------------------------------------------------------------------------------------------------------------------------------
set orientx 1	
set orienty 0

# Right Track and Left Track Center Line (Looking in the positive x-direction)
set R  3;     # Track 1 (Right)
set L -3;     # Track 2 (Left)

# Distance between train wheels in the y-direction
set wr 2 

# Train Wheel Distance, Wheels are 2 m apart
set R1 [expr $R + $wr/2];  # Rail 1 (Right) in the Track 1
set R2 [expr $R - $wr/2];  # Rail 2 (Left)  in the Track 1
set R3 [expr $L + $wr/2];  # Rail 3 (Right) in the Track 2
set R4 [expr $L - $wr/2];  # Rail 4 (Left)  in the Track 2

# Rail Height
set hr 16.59;  # Column height of 13.5 m + Girder depth of 3.09 m

# Girder Height
set yg 15.5;   # Column height of 13.5 m + Girder COM 2.0 m from bottom of soffit

# Column Height
set hcol 13.5; 

# Footing Height
set hf -2.0;   # 1/2 of assumed footing depth (4 m)

# Nodes for Bridge Bearing
set Rb  2;     # Right Side
set Lb -2;     # Left Side


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #


#===========================================================================================================================================================================================
#                TRACK SYSTEM NODES
#===========================================================================================================================================================================================

#=========================================================
#               RAIL NODES
#=========================================================
# Replace R1, R2, R3, R4 with appropriate train wheel-set spacing

# Rail 1
#	   nodeTag	   (x)	  (y)     (z)
node	10001	  0.000	  $R1	  $hr
node	10002	  3.195	  $R1	  $hr
node	10003	  6.390	  $R1	  $hr
node	10004	  9.585	  $R1	  $hr
node	10005	 12.780	  $R1	  $hr
node	10006	 15.975	  $R1	  $hr
node	10007	 19.170	  $R1	  $hr
node	10008	 22.365	  $R1	  $hr
node	10009	 25.560	  $R1	  $hr
node	10010	 28.755	  $R1	  $hr
node	10011	 31.950	  $R1	  $hr
node	10012	 32.000	  $R1	  $hr
node	10013	 35.195	  $R1	  $hr
node	10014	 38.390	  $R1	  $hr
node	10015	 41.585	  $R1	  $hr
node	10016	 44.780	  $R1	  $hr
node	10017	 47.975	  $R1	  $hr
node	10018	 51.170	  $R1	  $hr
node	10019	 54.365	  $R1	  $hr
node	10020	 57.560	  $R1	  $hr
node	10021	 60.755	  $R1	  $hr
node	10022	 63.950	  $R1	  $hr
node	10023	 64.000	  $R1	  $hr
node	10024	 67.195	  $R1	  $hr
node	10025	 70.390	  $R1	  $hr
node	10026	 73.585	  $R1	  $hr
node	10027	 76.780	  $R1	  $hr
node	10028	 79.975	  $R1	  $hr
node	10029	 83.170	  $R1	  $hr
node	10030	 86.365	  $R1	  $hr
node	10031	 89.560	  $R1	  $hr
node	10032	 92.755	  $R1	  $hr
node	10033	 95.950	  $R1	  $hr
node	10034	 96.000	  $R1	  $hr
node	10035	 99.195	  $R1	  $hr
node	10036	102.390	  $R1	  $hr
node	10037	105.585	  $R1	  $hr
node	10038	108.780	  $R1	  $hr
node	10039	111.975	  $R1	  $hr
node	10040	115.170	  $R1	  $hr
node	10041	118.365	  $R1	  $hr
node	10042	121.560	  $R1	  $hr
node	10043	124.755	  $R1	  $hr
node	10044	127.950	  $R1	  $hr
node	10045	128.000	  $R1	  $hr
node	10046	131.195	  $R1	  $hr
node	10047	134.390	  $R1	  $hr
node	10048	137.585	  $R1	  $hr
node	10049	140.780	  $R1	  $hr
node	10050	143.975	  $R1	  $hr
node	10051	147.170	  $R1	  $hr
node	10052	150.365	  $R1	  $hr
node	10053	153.560	  $R1	  $hr
node	10054	156.755	  $R1	  $hr
node	10055	159.950	  $R1	  $hr
node	10056	160.000	  $R1	  $hr
node	10057	163.195	  $R1	  $hr
node	10058	166.390	  $R1	  $hr
node	10059	169.585	  $R1	  $hr
node	10060	172.780	  $R1	  $hr
node	10061	175.975	  $R1	  $hr
node	10062	179.170	  $R1	  $hr
node	10063	182.365	  $R1	  $hr
node	10064	185.560	  $R1	  $hr
node	10065	188.755	  $R1	  $hr
node	10066	191.950	  $R1	  $hr
node	10067	192.000	  $R1	  $hr
node	10068	195.195	  $R1	  $hr
node	10069	198.390	  $R1	  $hr
node	10070	201.585	  $R1	  $hr
node	10071	204.780	  $R1	  $hr
node	10072	207.975	  $R1	  $hr
node	10073	211.170	  $R1	  $hr
node	10074	214.365	  $R1	  $hr
node	10075	217.560	  $R1	  $hr
node	10076	220.755	  $R1	  $hr
node	10077	223.950	  $R1	  $hr
node	10078	224.000	  $R1	  $hr
node	10079	227.195	  $R1	  $hr
node	10080	230.390	  $R1	  $hr
node	10081	233.585	  $R1	  $hr
node	10082	236.780	  $R1	  $hr
node	10083	239.975	  $R1	  $hr
node	10084	243.170	  $R1	  $hr
node	10085	246.365	  $R1	  $hr
node	10086	249.560	  $R1	  $hr
node	10087	252.755	  $R1	  $hr
node	10088	255.950	  $R1	  $hr
node	10089	256.000	  $R1	  $hr
node	10090	259.195	  $R1	  $hr
node	10091	262.390	  $R1	  $hr
node	10092	265.585	  $R1	  $hr
node	10093	268.780	  $R1	  $hr
node	10094	271.975	  $R1	  $hr
node	10095	275.170	  $R1	  $hr
node	10096	278.365	  $R1	  $hr
node	10097	281.560	  $R1	  $hr
node	10098	284.755	  $R1	  $hr
node	10099	287.950	  $R1	  $hr
node	10100	288.000	  $R1	  $hr
node	10101	291.195	  $R1	  $hr
node	10102	294.390	  $R1	  $hr
node	10103	297.585	  $R1	  $hr
node	10104	300.780	  $R1	  $hr
node	10105	303.975	  $R1	  $hr
node	10106	307.170	  $R1	  $hr
node	10107	310.365	  $R1	  $hr
node	10108	313.560	  $R1	  $hr
node	10109	316.755	  $R1	  $hr
node	10110	319.950	  $R1	  $hr

# Rail 1 Copy
#	   nodeTag	   (x)	  (y)     (z)
node	11001	  0.000	  $R1	  $hr
node	11002	  3.195	  $R1	  $hr
node	11003	  6.390	  $R1	  $hr
node	11004	  9.585	  $R1	  $hr
node	11005	 12.780	  $R1	  $hr
node	11006	 15.975	  $R1	  $hr
node	11007	 19.170	  $R1	  $hr
node	11008	 22.365	  $R1	  $hr
node	11009	 25.560	  $R1	  $hr
node	11010	 28.755	  $R1	  $hr
node	11011	 31.950	  $R1	  $hr
node	11012	 32.000	  $R1	  $hr
node	11013	 35.195	  $R1	  $hr
node	11014	 38.390	  $R1	  $hr
node	11015	 41.585	  $R1	  $hr
node	11016	 44.780	  $R1	  $hr
node	11017	 47.975	  $R1	  $hr
node	11018	 51.170	  $R1	  $hr
node	11019	 54.365	  $R1	  $hr
node	11020	 57.560	  $R1	  $hr
node	11021	 60.755	  $R1	  $hr
node	11022	 63.950	  $R1	  $hr
node	11023	 64.000	  $R1	  $hr
node	11024	 67.195	  $R1	  $hr
node	11025	 70.390	  $R1	  $hr
node	11026	 73.585	  $R1	  $hr
node	11027	 76.780	  $R1	  $hr
node	11028	 79.975	  $R1	  $hr
node	11029	 83.170	  $R1	  $hr
node	11030	 86.365	  $R1	  $hr
node	11031	 89.560	  $R1	  $hr
node	11032	 92.755	  $R1	  $hr
node	11033	 95.950	  $R1	  $hr
node	11034	 96.000	  $R1	  $hr
node	11035	 99.195	  $R1	  $hr
node	11036	102.390	  $R1	  $hr
node	11037	105.585	  $R1	  $hr
node	11038	108.780	  $R1	  $hr
node	11039	111.975	  $R1	  $hr
node	11040	115.170	  $R1	  $hr
node	11041	118.365	  $R1	  $hr
node	11042	121.560	  $R1	  $hr
node	11043	124.755	  $R1	  $hr
node	11044	127.950	  $R1	  $hr
node	11045	128.000	  $R1	  $hr
node	11046	131.195	  $R1	  $hr
node	11047	134.390	  $R1	  $hr
node	11048	137.585	  $R1	  $hr
node	11049	140.780	  $R1	  $hr
node	11050	143.975	  $R1	  $hr
node	11051	147.170	  $R1	  $hr
node	11052	150.365	  $R1	  $hr
node	11053	153.560	  $R1	  $hr
node	11054	156.755	  $R1	  $hr
node	11055	159.950	  $R1	  $hr
node	11056	160.000	  $R1	  $hr
node	11057	163.195	  $R1	  $hr
node	11058	166.390	  $R1	  $hr
node	11059	169.585	  $R1	  $hr
node	11060	172.780	  $R1	  $hr
node	11061	175.975	  $R1	  $hr
node	11062	179.170	  $R1	  $hr
node	11063	182.365	  $R1	  $hr
node	11064	185.560	  $R1	  $hr
node	11065	188.755	  $R1	  $hr
node	11066	191.950	  $R1	  $hr
node	11067	192.000	  $R1	  $hr
node	11068	195.195	  $R1	  $hr
node	11069	198.390	  $R1	  $hr
node	11070	201.585	  $R1	  $hr
node	11071	204.780	  $R1	  $hr
node	11072	207.975	  $R1	  $hr
node	11073	211.170	  $R1	  $hr
node	11074	214.365	  $R1	  $hr
node	11075	217.560	  $R1	  $hr
node	11076	220.755	  $R1	  $hr
node	11077	223.950	  $R1	  $hr
node	11078	224.000	  $R1	  $hr
node	11079	227.195	  $R1	  $hr
node	11080	230.390	  $R1	  $hr
node	11081	233.585	  $R1	  $hr
node	11082	236.780	  $R1	  $hr
node	11083	239.975	  $R1	  $hr
node	11084	243.170	  $R1	  $hr
node	11085	246.365	  $R1	  $hr
node	11086	249.560	  $R1	  $hr
node	11087	252.755	  $R1	  $hr
node	11088	255.950	  $R1	  $hr
node	11089	256.000	  $R1	  $hr
node	11090	259.195	  $R1	  $hr
node	11091	262.390	  $R1	  $hr
node	11092	265.585	  $R1	  $hr
node	11093	268.780	  $R1	  $hr
node	11094	271.975	  $R1	  $hr
node	11095	275.170	  $R1	  $hr
node	11096	278.365	  $R1	  $hr
node	11097	281.560	  $R1	  $hr
node	11098	284.755	  $R1	  $hr
node	11099	287.950	  $R1	  $hr
node	11100	288.000	  $R1	  $hr
node	11101	291.195	  $R1	  $hr
node	11102	294.390	  $R1	  $hr
node	11103	297.585	  $R1	  $hr
node	11104	300.780	  $R1	  $hr
node	11105	303.975	  $R1	  $hr
node	11106	307.170	  $R1	  $hr
node	11107	310.365	  $R1	  $hr
node	11108	313.560	  $R1	  $hr
node	11109	316.755	  $R1	  $hr
node	11110	319.950	  $R1	  $hr

# Rail 2
#	   nodeTag	   (x)	  (y)     (z)
node	20001	  0.000	  $R2	  $hr
node	20002	  3.195	  $R2	  $hr
node	20003	  6.390	  $R2	  $hr
node	20004	  9.585	  $R2	  $hr
node	20005	 12.780	  $R2	  $hr
node	20006	 15.975	  $R2	  $hr
node	20007	 19.170	  $R2	  $hr
node	20008	 22.365	  $R2	  $hr
node	20009	 25.560	  $R2	  $hr
node	20010	 28.755	  $R2	  $hr
node	20011	 31.950	  $R2	  $hr
node	20012	 32.000	  $R2	  $hr
node	20013	 35.195	  $R2	  $hr
node	20014	 38.390	  $R2	  $hr
node	20015	 41.585	  $R2	  $hr
node	20016	 44.780	  $R2	  $hr
node	20017	 47.975	  $R2	  $hr
node	20018	 51.170	  $R2	  $hr
node	20019	 54.365	  $R2	  $hr
node	20020	 57.560	  $R2	  $hr
node	20021	 60.755	  $R2	  $hr
node	20022	 63.950	  $R2	  $hr
node	20023	 64.000	  $R2	  $hr
node	20024	 67.195	  $R2	  $hr
node	20025	 70.390	  $R2	  $hr
node	20026	 73.585	  $R2	  $hr
node	20027	 76.780	  $R2	  $hr
node	20028	 79.975	  $R2	  $hr
node	20029	 83.170	  $R2	  $hr
node	20030	 86.365	  $R2	  $hr
node	20031	 89.560	  $R2	  $hr
node	20032	 92.755	  $R2	  $hr
node	20033	 95.950	  $R2	  $hr
node	20034	 96.000	  $R2	  $hr
node	20035	 99.195	  $R2	  $hr
node	20036	102.390	  $R2	  $hr
node	20037	105.585	  $R2	  $hr
node	20038	108.780	  $R2	  $hr
node	20039	111.975	  $R2	  $hr
node	20040	115.170	  $R2	  $hr
node	20041	118.365	  $R2	  $hr
node	20042	121.560	  $R2	  $hr
node	20043	124.755	  $R2	  $hr
node	20044	127.950	  $R2	  $hr
node	20045	128.000	  $R2	  $hr
node	20046	131.195	  $R2	  $hr
node	20047	134.390	  $R2	  $hr
node	20048	137.585	  $R2	  $hr
node	20049	140.780	  $R2	  $hr
node	20050	143.975	  $R2	  $hr
node	20051	147.170	  $R2	  $hr
node	20052	150.365	  $R2	  $hr
node	20053	153.560	  $R2	  $hr
node	20054	156.755	  $R2	  $hr
node	20055	159.950	  $R2	  $hr
node	20056	160.000	  $R2	  $hr
node	20057	163.195	  $R2	  $hr
node	20058	166.390	  $R2	  $hr
node	20059	169.585	  $R2	  $hr
node	20060	172.780	  $R2	  $hr
node	20061	175.975	  $R2	  $hr
node	20062	179.170	  $R2	  $hr
node	20063	182.365	  $R2	  $hr
node	20064	185.560	  $R2	  $hr
node	20065	188.755	  $R2	  $hr
node	20066	191.950	  $R2	  $hr
node	20067	192.000	  $R2	  $hr
node	20068	195.195	  $R2	  $hr
node	20069	198.390	  $R2	  $hr
node	20070	201.585	  $R2	  $hr
node	20071	204.780	  $R2	  $hr
node	20072	207.975	  $R2	  $hr
node	20073	211.170	  $R2	  $hr
node	20074	214.365	  $R2	  $hr
node	20075	217.560	  $R2	  $hr
node	20076	220.755	  $R2	  $hr
node	20077	223.950	  $R2	  $hr
node	20078	224.000	  $R2	  $hr
node	20079	227.195	  $R2	  $hr
node	20080	230.390	  $R2	  $hr
node	20081	233.585	  $R2	  $hr
node	20082	236.780	  $R2	  $hr
node	20083	239.975	  $R2	  $hr
node	20084	243.170	  $R2	  $hr
node	20085	246.365	  $R2	  $hr
node	20086	249.560	  $R2	  $hr
node	20087	252.755	  $R2	  $hr
node	20088	255.950	  $R2	  $hr
node	20089	256.000	  $R2	  $hr
node	20090	259.195	  $R2	  $hr
node	20091	262.390	  $R2	  $hr
node	20092	265.585	  $R2	  $hr
node	20093	268.780	  $R2	  $hr
node	20094	271.975	  $R2	  $hr
node	20095	275.170	  $R2	  $hr
node	20096	278.365	  $R2	  $hr
node	20097	281.560	  $R2	  $hr
node	20098	284.755	  $R2	  $hr
node	20099	287.950	  $R2	  $hr
node	20100	288.000	  $R2	  $hr
node	20101	291.195	  $R2	  $hr
node	20102	294.390	  $R2	  $hr
node	20103	297.585	  $R2	  $hr
node	20104	300.780	  $R2	  $hr
node	20105	303.975	  $R2	  $hr
node	20106	307.170	  $R2	  $hr
node	20107	310.365	  $R2	  $hr
node	20108	313.560	  $R2	  $hr
node	20109	316.755	  $R2	  $hr
node	20110	319.950	  $R2	  $hr

# Rail 2 Copy
#	   nodeTag	   (x)	  (y)     (z)
node	21001	  0.000	  $R2	  $hr
node	21002	  3.195	  $R2	  $hr
node	21003	  6.390	  $R2	  $hr
node	21004	  9.585	  $R2	  $hr
node	21005	 12.780	  $R2	  $hr
node	21006	 15.975	  $R2	  $hr
node	21007	 19.170	  $R2	  $hr
node	21008	 22.365	  $R2	  $hr
node	21009	 25.560	  $R2	  $hr
node	21010	 28.755	  $R2	  $hr
node	21011	 31.950	  $R2	  $hr
node	21012	 32.000	  $R2	  $hr
node	21013	 35.195	  $R2	  $hr
node	21014	 38.390	  $R2	  $hr
node	21015	 41.585	  $R2	  $hr
node	21016	 44.780	  $R2	  $hr
node	21017	 47.975	  $R2	  $hr
node	21018	 51.170	  $R2	  $hr
node	21019	 54.365	  $R2	  $hr
node	21020	 57.560	  $R2	  $hr
node	21021	 60.755	  $R2	  $hr
node	21022	 63.950	  $R2	  $hr
node	21023	 64.000	  $R2	  $hr
node	21024	 67.195	  $R2	  $hr
node	21025	 70.390	  $R2	  $hr
node	21026	 73.585	  $R2	  $hr
node	21027	 76.780	  $R2	  $hr
node	21028	 79.975	  $R2	  $hr
node	21029	 83.170	  $R2	  $hr
node	21030	 86.365	  $R2	  $hr
node	21031	 89.560	  $R2	  $hr
node	21032	 92.755	  $R2	  $hr
node	21033	 95.950	  $R2	  $hr
node	21034	 96.000	  $R2	  $hr
node	21035	 99.195	  $R2	  $hr
node	21036	102.390	  $R2	  $hr
node	21037	105.585	  $R2	  $hr
node	21038	108.780	  $R2	  $hr
node	21039	111.975	  $R2	  $hr
node	21040	115.170	  $R2	  $hr
node	21041	118.365	  $R2	  $hr
node	21042	121.560	  $R2	  $hr
node	21043	124.755	  $R2	  $hr
node	21044	127.950	  $R2	  $hr
node	21045	128.000	  $R2	  $hr
node	21046	131.195	  $R2	  $hr
node	21047	134.390	  $R2	  $hr
node	21048	137.585	  $R2	  $hr
node	21049	140.780	  $R2	  $hr
node	21050	143.975	  $R2	  $hr
node	21051	147.170	  $R2	  $hr
node	21052	150.365	  $R2	  $hr
node	21053	153.560	  $R2	  $hr
node	21054	156.755	  $R2	  $hr
node	21055	159.950	  $R2	  $hr
node	21056	160.000	  $R2	  $hr
node	21057	163.195	  $R2	  $hr
node	21058	166.390	  $R2	  $hr
node	21059	169.585	  $R2	  $hr
node	21060	172.780	  $R2	  $hr
node	21061	175.975	  $R2	  $hr
node	21062	179.170	  $R2	  $hr
node	21063	182.365	  $R2	  $hr
node	21064	185.560	  $R2	  $hr
node	21065	188.755	  $R2	  $hr
node	21066	191.950	  $R2	  $hr
node	21067	192.000	  $R2	  $hr
node	21068	195.195	  $R2	  $hr
node	21069	198.390	  $R2	  $hr
node	21070	201.585	  $R2	  $hr
node	21071	204.780	  $R2	  $hr
node	21072	207.975	  $R2	  $hr
node	21073	211.170	  $R2	  $hr
node	21074	214.365	  $R2	  $hr
node	21075	217.560	  $R2	  $hr
node	21076	220.755	  $R2	  $hr
node	21077	223.950	  $R2	  $hr
node	21078	224.000	  $R2	  $hr
node	21079	227.195	  $R2	  $hr
node	21080	230.390	  $R2	  $hr
node	21081	233.585	  $R2	  $hr
node	21082	236.780	  $R2	  $hr
node	21083	239.975	  $R2	  $hr
node	21084	243.170	  $R2	  $hr
node	21085	246.365	  $R2	  $hr
node	21086	249.560	  $R2	  $hr
node	21087	252.755	  $R2	  $hr
node	21088	255.950	  $R2	  $hr
node	21089	256.000	  $R2	  $hr
node	21090	259.195	  $R2	  $hr
node	21091	262.390	  $R2	  $hr
node	21092	265.585	  $R2	  $hr
node	21093	268.780	  $R2	  $hr
node	21094	271.975	  $R2	  $hr
node	21095	275.170	  $R2	  $hr
node	21096	278.365	  $R2	  $hr
node	21097	281.560	  $R2	  $hr
node	21098	284.755	  $R2	  $hr
node	21099	287.950	  $R2	  $hr
node	21100	288.000	  $R2	  $hr
node	21101	291.195	  $R2	  $hr
node	21102	294.390	  $R2	  $hr
node	21103	297.585	  $R2	  $hr
node	21104	300.780	  $R2	  $hr
node	21105	303.975	  $R2	  $hr
node	21106	307.170	  $R2	  $hr
node	21107	310.365	  $R2	  $hr
node	21108	313.560	  $R2	  $hr
node	21109	316.755	  $R2	  $hr
node	21110	319.950	  $R2	  $hr

# Rail 3
#	   nodeTag	   (x)	  (y)     (z)
node	30001	  0.000	  $R3	  $hr
node	30002	  3.195	  $R3	  $hr
node	30003	  6.390	  $R3	  $hr
node	30004	  9.585	  $R3	  $hr
node	30005	 12.780	  $R3	  $hr
node	30006	 15.975	  $R3	  $hr
node	30007	 19.170	  $R3	  $hr
node	30008	 22.365	  $R3	  $hr
node	30009	 25.560	  $R3	  $hr
node	30010	 28.755	  $R3	  $hr
node	30011	 31.950	  $R3	  $hr
node	30012	 32.000	  $R3	  $hr
node	30013	 35.195	  $R3	  $hr
node	30014	 38.390	  $R3	  $hr
node	30015	 41.585	  $R3	  $hr
node	30016	 44.780	  $R3	  $hr
node	30017	 47.975	  $R3	  $hr
node	30018	 51.170	  $R3	  $hr
node	30019	 54.365	  $R3	  $hr
node	30020	 57.560	  $R3	  $hr
node	30021	 60.755	  $R3	  $hr
node	30022	 63.950	  $R3	  $hr
node	30023	 64.000	  $R3	  $hr
node	30024	 67.195	  $R3	  $hr
node	30025	 70.390	  $R3	  $hr
node	30026	 73.585	  $R3	  $hr
node	30027	 76.780	  $R3	  $hr
node	30028	 79.975	  $R3	  $hr
node	30029	 83.170	  $R3	  $hr
node	30030	 86.365	  $R3	  $hr
node	30031	 89.560	  $R3	  $hr
node	30032	 92.755	  $R3	  $hr
node	30033	 95.950	  $R3	  $hr
node	30034	 96.000	  $R3	  $hr
node	30035	 99.195	  $R3	  $hr
node	30036	102.390	  $R3	  $hr
node	30037	105.585	  $R3	  $hr
node	30038	108.780	  $R3	  $hr
node	30039	111.975	  $R3	  $hr
node	30040	115.170	  $R3	  $hr
node	30041	118.365	  $R3	  $hr
node	30042	121.560	  $R3	  $hr
node	30043	124.755	  $R3	  $hr
node	30044	127.950	  $R3	  $hr
node	30045	128.000	  $R3	  $hr
node	30046	131.195	  $R3	  $hr
node	30047	134.390	  $R3	  $hr
node	30048	137.585	  $R3	  $hr
node	30049	140.780	  $R3	  $hr
node	30050	143.975	  $R3	  $hr
node	30051	147.170	  $R3	  $hr
node	30052	150.365	  $R3	  $hr
node	30053	153.560	  $R3	  $hr
node	30054	156.755	  $R3	  $hr
node	30055	159.950	  $R3	  $hr
node	30056	160.000	  $R3	  $hr
node	30057	163.195	  $R3	  $hr
node	30058	166.390	  $R3	  $hr
node	30059	169.585	  $R3	  $hr
node	30060	172.780	  $R3	  $hr
node	30061	175.975	  $R3	  $hr
node	30062	179.170	  $R3	  $hr
node	30063	182.365	  $R3	  $hr
node	30064	185.560	  $R3	  $hr
node	30065	188.755	  $R3	  $hr
node	30066	191.950	  $R3	  $hr
node	30067	192.000	  $R3	  $hr
node	30068	195.195	  $R3	  $hr
node	30069	198.390	  $R3	  $hr
node	30070	201.585	  $R3	  $hr
node	30071	204.780	  $R3	  $hr
node	30072	207.975	  $R3	  $hr
node	30073	211.170	  $R3	  $hr
node	30074	214.365	  $R3	  $hr
node	30075	217.560	  $R3	  $hr
node	30076	220.755	  $R3	  $hr
node	30077	223.950	  $R3	  $hr
node	30078	224.000	  $R3	  $hr
node	30079	227.195	  $R3	  $hr
node	30080	230.390	  $R3	  $hr
node	30081	233.585	  $R3	  $hr
node	30082	236.780	  $R3	  $hr
node	30083	239.975	  $R3	  $hr
node	30084	243.170	  $R3	  $hr
node	30085	246.365	  $R3	  $hr
node	30086	249.560	  $R3	  $hr
node	30087	252.755	  $R3	  $hr
node	30088	255.950	  $R3	  $hr
node	30089	256.000	  $R3	  $hr
node	30090	259.195	  $R3	  $hr
node	30091	262.390	  $R3	  $hr
node	30092	265.585	  $R3	  $hr
node	30093	268.780	  $R3	  $hr
node	30094	271.975	  $R3	  $hr
node	30095	275.170	  $R3	  $hr
node	30096	278.365	  $R3	  $hr
node	30097	281.560	  $R3	  $hr
node	30098	284.755	  $R3	  $hr
node	30099	287.950	  $R3	  $hr
node	30100	288.000	  $R3	  $hr
node	30101	291.195	  $R3	  $hr
node	30102	294.390	  $R3	  $hr
node	30103	297.585	  $R3	  $hr
node	30104	300.780	  $R3	  $hr
node	30105	303.975	  $R3	  $hr
node	30106	307.170	  $R3	  $hr
node	30107	310.365	  $R3	  $hr
node	30108	313.560	  $R3	  $hr
node	30109	316.755	  $R3	  $hr
node	30110	319.950	  $R3	  $hr

# Rail 3 Copy
#	   nodeTag	   (x)	  (y)     (z)
node	31001	  0.000	  $R3	  $hr
node	31002	  3.195	  $R3	  $hr
node	31003	  6.390	  $R3	  $hr
node	31004	  9.585	  $R3	  $hr
node	31005	 12.780	  $R3	  $hr
node	31006	 15.975	  $R3	  $hr
node	31007	 19.170	  $R3	  $hr
node	31008	 22.365	  $R3	  $hr
node	31009	 25.560	  $R3	  $hr
node	31010	 28.755	  $R3	  $hr
node	31011	 31.950	  $R3	  $hr
node	31012	 32.000	  $R3	  $hr
node	31013	 35.195	  $R3	  $hr
node	31014	 38.390	  $R3	  $hr
node	31015	 41.585	  $R3	  $hr
node	31016	 44.780	  $R3	  $hr
node	31017	 47.975	  $R3	  $hr
node	31018	 51.170	  $R3	  $hr
node	31019	 54.365	  $R3	  $hr
node	31020	 57.560	  $R3	  $hr
node	31021	 60.755	  $R3	  $hr
node	31022	 63.950	  $R3	  $hr
node	31023	 64.000	  $R3	  $hr
node	31024	 67.195	  $R3	  $hr
node	31025	 70.390	  $R3	  $hr
node	31026	 73.585	  $R3	  $hr
node	31027	 76.780	  $R3	  $hr
node	31028	 79.975	  $R3	  $hr
node	31029	 83.170	  $R3	  $hr
node	31030	 86.365	  $R3	  $hr
node	31031	 89.560	  $R3	  $hr
node	31032	 92.755	  $R3	  $hr
node	31033	 95.950	  $R3	  $hr
node	31034	 96.000	  $R3	  $hr
node	31035	 99.195	  $R3	  $hr
node	31036	102.390	  $R3	  $hr
node	31037	105.585	  $R3	  $hr
node	31038	108.780	  $R3	  $hr
node	31039	111.975	  $R3	  $hr
node	31040	115.170	  $R3	  $hr
node	31041	118.365	  $R3	  $hr
node	31042	121.560	  $R3	  $hr
node	31043	124.755	  $R3	  $hr
node	31044	127.950	  $R3	  $hr
node	31045	128.000	  $R3	  $hr
node	31046	131.195	  $R3	  $hr
node	31047	134.390	  $R3	  $hr
node	31048	137.585	  $R3	  $hr
node	31049	140.780	  $R3	  $hr
node	31050	143.975	  $R3	  $hr
node	31051	147.170	  $R3	  $hr
node	31052	150.365	  $R3	  $hr
node	31053	153.560	  $R3	  $hr
node	31054	156.755	  $R3	  $hr
node	31055	159.950	  $R3	  $hr
node	31056	160.000	  $R3	  $hr
node	31057	163.195	  $R3	  $hr
node	31058	166.390	  $R3	  $hr
node	31059	169.585	  $R3	  $hr
node	31060	172.780	  $R3	  $hr
node	31061	175.975	  $R3	  $hr
node	31062	179.170	  $R3	  $hr
node	31063	182.365	  $R3	  $hr
node	31064	185.560	  $R3	  $hr
node	31065	188.755	  $R3	  $hr
node	31066	191.950	  $R3	  $hr
node	31067	192.000	  $R3	  $hr
node	31068	195.195	  $R3	  $hr
node	31069	198.390	  $R3	  $hr
node	31070	201.585	  $R3	  $hr
node	31071	204.780	  $R3	  $hr
node	31072	207.975	  $R3	  $hr
node	31073	211.170	  $R3	  $hr
node	31074	214.365	  $R3	  $hr
node	31075	217.560	  $R3	  $hr
node	31076	220.755	  $R3	  $hr
node	31077	223.950	  $R3	  $hr
node	31078	224.000	  $R3	  $hr
node	31079	227.195	  $R3	  $hr
node	31080	230.390	  $R3	  $hr
node	31081	233.585	  $R3	  $hr
node	31082	236.780	  $R3	  $hr
node	31083	239.975	  $R3	  $hr
node	31084	243.170	  $R3	  $hr
node	31085	246.365	  $R3	  $hr
node	31086	249.560	  $R3	  $hr
node	31087	252.755	  $R3	  $hr
node	31088	255.950	  $R3	  $hr
node	31089	256.000	  $R3	  $hr
node	31090	259.195	  $R3	  $hr
node	31091	262.390	  $R3	  $hr
node	31092	265.585	  $R3	  $hr
node	31093	268.780	  $R3	  $hr
node	31094	271.975	  $R3	  $hr
node	31095	275.170	  $R3	  $hr
node	31096	278.365	  $R3	  $hr
node	31097	281.560	  $R3	  $hr
node	31098	284.755	  $R3	  $hr
node	31099	287.950	  $R3	  $hr
node	31100	288.000	  $R3	  $hr
node	31101	291.195	  $R3	  $hr
node	31102	294.390	  $R3	  $hr
node	31103	297.585	  $R3	  $hr
node	31104	300.780	  $R3	  $hr
node	31105	303.975	  $R3	  $hr
node	31106	307.170	  $R3	  $hr
node	31107	310.365	  $R3	  $hr
node	31108	313.560	  $R3	  $hr
node	31109	316.755	  $R3	  $hr
node	31110	319.950	  $R3	  $hr

# Rail 4
#	   nodeTag	   (x)	  (y)     (z)
node	40001	  0.000	  $R4	  $hr
node	40002	  3.195	  $R4	  $hr
node	40003	  6.390	  $R4	  $hr
node	40004	  9.585	  $R4	  $hr
node	40005	 12.780	  $R4	  $hr
node	40006	 15.975	  $R4	  $hr
node	40007	 19.170	  $R4	  $hr
node	40008	 22.365	  $R4	  $hr
node	40009	 25.560	  $R4	  $hr
node	40010	 28.755	  $R4	  $hr
node	40011	 31.950	  $R4	  $hr
node	40012	 32.000	  $R4	  $hr
node	40013	 35.195	  $R4	  $hr
node	40014	 38.390	  $R4	  $hr
node	40015	 41.585	  $R4	  $hr
node	40016	 44.780	  $R4	  $hr
node	40017	 47.975	  $R4	  $hr
node	40018	 51.170	  $R4	  $hr
node	40019	 54.365	  $R4	  $hr
node	40020	 57.560	  $R4	  $hr
node	40021	 60.755	  $R4	  $hr
node	40022	 63.950	  $R4	  $hr
node	40023	 64.000	  $R4	  $hr
node	40024	 67.195	  $R4	  $hr
node	40025	 70.390	  $R4	  $hr
node	40026	 73.585	  $R4	  $hr
node	40027	 76.780	  $R4	  $hr
node	40028	 79.975	  $R4	  $hr
node	40029	 83.170	  $R4	  $hr
node	40030	 86.365	  $R4	  $hr
node	40031	 89.560	  $R4	  $hr
node	40032	 92.755	  $R4	  $hr
node	40033	 95.950	  $R4	  $hr
node	40034	 96.000	  $R4	  $hr
node	40035	 99.195	  $R4	  $hr
node	40036	102.390	  $R4	  $hr
node	40037	105.585	  $R4	  $hr
node	40038	108.780	  $R4	  $hr
node	40039	111.975	  $R4	  $hr
node	40040	115.170	  $R4	  $hr
node	40041	118.365	  $R4	  $hr
node	40042	121.560	  $R4	  $hr
node	40043	124.755	  $R4	  $hr
node	40044	127.950	  $R4	  $hr
node	40045	128.000	  $R4	  $hr
node	40046	131.195	  $R4	  $hr
node	40047	134.390	  $R4	  $hr
node	40048	137.585	  $R4	  $hr
node	40049	140.780	  $R4	  $hr
node	40050	143.975	  $R4	  $hr
node	40051	147.170	  $R4	  $hr
node	40052	150.365	  $R4	  $hr
node	40053	153.560	  $R4	  $hr
node	40054	156.755	  $R4	  $hr
node	40055	159.950	  $R4	  $hr
node	40056	160.000	  $R4	  $hr
node	40057	163.195	  $R4	  $hr
node	40058	166.390	  $R4	  $hr
node	40059	169.585	  $R4	  $hr
node	40060	172.780	  $R4	  $hr
node	40061	175.975	  $R4	  $hr
node	40062	179.170	  $R4	  $hr
node	40063	182.365	  $R4	  $hr
node	40064	185.560	  $R4	  $hr
node	40065	188.755	  $R4	  $hr
node	40066	191.950	  $R4	  $hr
node	40067	192.000	  $R4	  $hr
node	40068	195.195	  $R4	  $hr
node	40069	198.390	  $R4	  $hr
node	40070	201.585	  $R4	  $hr
node	40071	204.780	  $R4	  $hr
node	40072	207.975	  $R4	  $hr
node	40073	211.170	  $R4	  $hr
node	40074	214.365	  $R4	  $hr
node	40075	217.560	  $R4	  $hr
node	40076	220.755	  $R4	  $hr
node	40077	223.950	  $R4	  $hr
node	40078	224.000	  $R4	  $hr
node	40079	227.195	  $R4	  $hr
node	40080	230.390	  $R4	  $hr
node	40081	233.585	  $R4	  $hr
node	40082	236.780	  $R4	  $hr
node	40083	239.975	  $R4	  $hr
node	40084	243.170	  $R4	  $hr
node	40085	246.365	  $R4	  $hr
node	40086	249.560	  $R4	  $hr
node	40087	252.755	  $R4	  $hr
node	40088	255.950	  $R4	  $hr
node	40089	256.000	  $R4	  $hr
node	40090	259.195	  $R4	  $hr
node	40091	262.390	  $R4	  $hr
node	40092	265.585	  $R4	  $hr
node	40093	268.780	  $R4	  $hr
node	40094	271.975	  $R4	  $hr
node	40095	275.170	  $R4	  $hr
node	40096	278.365	  $R4	  $hr
node	40097	281.560	  $R4	  $hr
node	40098	284.755	  $R4	  $hr
node	40099	287.950	  $R4	  $hr
node	40100	288.000	  $R4	  $hr
node	40101	291.195	  $R4	  $hr
node	40102	294.390	  $R4	  $hr
node	40103	297.585	  $R4	  $hr
node	40104	300.780	  $R4	  $hr
node	40105	303.975	  $R4	  $hr
node	40106	307.170	  $R4	  $hr
node	40107	310.365	  $R4	  $hr
node	40108	313.560	  $R4	  $hr
node	40109	316.755	  $R4	  $hr
node	40110	319.950	  $R4	  $hr

# Rail 4 Copy
#	   nodeTag	   (x)	  (y)     (z)
node	41001	  0.000	  $R4	  $hr
node	41002	  3.195	  $R4	  $hr
node	41003	  6.390	  $R4	  $hr
node	41004	  9.585	  $R4	  $hr
node	41005	 12.780	  $R4	  $hr
node	41006	 15.975	  $R4	  $hr
node	41007	 19.170	  $R4	  $hr
node	41008	 22.365	  $R4	  $hr
node	41009	 25.560	  $R4	  $hr
node	41010	 28.755	  $R4	  $hr
node	41011	 31.950	  $R4	  $hr
node	41012	 32.000	  $R4	  $hr
node	41013	 35.195	  $R4	  $hr
node	41014	 38.390	  $R4	  $hr
node	41015	 41.585	  $R4	  $hr
node	41016	 44.780	  $R4	  $hr
node	41017	 47.975	  $R4	  $hr
node	41018	 51.170	  $R4	  $hr
node	41019	 54.365	  $R4	  $hr
node	41020	 57.560	  $R4	  $hr
node	41021	 60.755	  $R4	  $hr
node	41022	 63.950	  $R4	  $hr
node	41023	 64.000	  $R4	  $hr
node	41024	 67.195	  $R4	  $hr
node	41025	 70.390	  $R4	  $hr
node	41026	 73.585	  $R4	  $hr
node	41027	 76.780	  $R4	  $hr
node	41028	 79.975	  $R4	  $hr
node	41029 	 83.170	  $R4	  $hr
node	41030	 86.365	  $R4	  $hr
node	41031	 89.560	  $R4	  $hr
node	41032	 92.755	  $R4	  $hr
node	41033	 95.950	  $R4	  $hr
node	41034	 96.000	  $R4	  $hr
node	41035	 99.195	  $R4	  $hr
node	41036	102.390	  $R4	  $hr
node	41037	105.585	  $R4	  $hr
node	41038	108.780	  $R4	  $hr
node	41039	111.975	  $R4	  $hr
node	41040	115.170	  $R4	  $hr
node	41041	118.365	  $R4	  $hr
node	41042	121.560	  $R4	  $hr
node	41043	124.755	  $R4	  $hr
node	41044	127.950	  $R4	  $hr
node	41045	128.000	  $R4	  $hr
node	41046	131.195	  $R4	  $hr
node	41047	134.390	  $R4	  $hr
node	41048	137.585	  $R4	  $hr
node	41049	140.780	  $R4	  $hr
node	41050	143.975	  $R4	  $hr
node	41051	147.170	  $R4	  $hr
node	41052	150.365	  $R4	  $hr
node	41053	153.560	  $R4	  $hr
node	41054	156.755	  $R4	  $hr
node	41055	159.950	  $R4	  $hr
node	41056	160.000	  $R4	  $hr
node	41057	163.195	  $R4	  $hr
node	41058	166.390	  $R4	  $hr
node	41059	169.585	  $R4	  $hr
node	41060	172.780	  $R4	  $hr
node	41061	175.975	  $R4	  $hr
node	41062	179.170	  $R4	  $hr
node	41063	182.365	  $R4	  $hr
node	41064	185.560	  $R4	  $hr
node	41065	188.755	  $R4	  $hr
node	41066	191.950	  $R4	  $hr
node	41067	192.000	  $R4	  $hr
node	41068	195.195	  $R4	  $hr
node	41069	198.390	  $R4	  $hr
node	41070	201.585	  $R4	  $hr
node	41071	204.780	  $R4	  $hr
node	41072	207.975	  $R4	  $hr
node	41073	211.170	  $R4	  $hr
node	41074	214.365	  $R4	  $hr
node	41075	217.560	  $R4	  $hr
node	41076	220.755	  $R4	  $hr
node	41077	223.950	  $R4	  $hr
node	41078	224.000	  $R4	  $hr
node	41079	227.195	  $R4	  $hr
node	41080	230.390	  $R4	  $hr
node	41081	233.585	  $R4	  $hr
node	41082	236.780	  $R4	  $hr
node	41083	239.975	  $R4	  $hr
node	41084	243.170	  $R4	  $hr
node	41085	246.365	  $R4	  $hr
node	41086	249.560	  $R4	  $hr
node	41087	252.755	  $R4	  $hr
node	41088	255.950	  $R4	  $hr
node	41089	256.000	  $R4	  $hr
node	41090	259.195	  $R4	  $hr
node	41091	262.390	  $R4	  $hr
node	41092	265.585	  $R4	  $hr
node	41093	268.780	  $R4	  $hr
node	41094	271.975	  $R4	  $hr
node	41095	275.170	  $R4	  $hr
node	41096	278.365	  $R4	  $hr
node	41097	281.560	  $R4	  $hr
node	41098	284.755	  $R4	  $hr
node	41099	287.950	  $R4	  $hr
node	41100	288.000	  $R4	  $hr
node	41101	291.195	  $R4	  $hr
node	41102	294.390	  $R4	  $hr
node	41103	297.585	  $R4	  $hr
node	41104	300.780	  $R4	  $hr
node	41105	303.975	  $R4	  $hr
node	41106	307.170	  $R4	  $hr
node	41107	310.365	  $R4	  $hr
node	41108	313.560	  $R4	  $hr
node	41109	316.755	  $R4	  $hr
node	41110	319.950	  $R4	  $hr

# Constraining DOF for Fasteners
equalDOF	10001	11001	3	4	5	6
equalDOF	10002	11002	3	4	5	6
equalDOF	10003	11003	3	4	5	6
equalDOF	10004	11004	3	4	5	6
equalDOF	10005	11005	3	4	5	6
equalDOF	10006	11006	3	4	5	6
equalDOF	10007	11007	3	4	5	6
equalDOF	10008	11008	3	4	5	6
equalDOF	10009	11009	3	4	5	6
equalDOF	10010	11010	3	4	5	6
equalDOF	10011	11011	3	4	5	6
equalDOF	10012	11012	3	4	5	6
equalDOF	10013	11013	3	4	5	6
equalDOF	10014	11014	3	4	5	6
equalDOF	10015	11015	3	4	5	6
equalDOF	10016	11016	3	4	5	6
equalDOF	10017	11017	3	4	5	6
equalDOF	10018	11018	3	4	5	6
equalDOF	10019	11019	3	4	5	6
equalDOF	10020	11020	3	4	5	6
equalDOF	10021	11021	3	4	5	6
equalDOF	10022	11022	3	4	5	6
equalDOF	10023	11023	3	4	5	6
equalDOF	10024	11024	3	4	5	6
equalDOF	10025	11025	3	4	5	6
equalDOF	10026	11026	3	4	5	6
equalDOF	10027	11027	3	4	5	6
equalDOF	10028	11028	3	4	5	6
equalDOF	10029	11029	3	4	5	6
equalDOF	10030	11030	3	4	5	6
equalDOF	10031	11031	3	4	5	6
equalDOF	10032	11032	3	4	5	6
equalDOF	10033	11033	3	4	5	6
equalDOF	10034	11034	3	4	5	6
equalDOF	10035	11035	3	4	5	6
equalDOF	10036	11036	3	4	5	6
equalDOF	10037	11037	3	4	5	6
equalDOF	10038	11038	3	4	5	6
equalDOF	10039	11039	3	4	5	6
equalDOF	10040	11040	3	4	5	6
equalDOF	10041	11041	3	4	5	6
equalDOF	10042	11042	3	4	5	6
equalDOF	10043	11043	3	4	5	6
equalDOF	10044	11044	3	4	5	6
equalDOF	10045	11045	3	4	5	6
equalDOF	10046	11046	3	4	5	6
equalDOF	10047	11047	3	4	5	6
equalDOF	10048	11048	3	4	5	6
equalDOF	10049	11049	3	4	5	6
equalDOF	10050	11050	3	4	5	6
equalDOF	10051	11051	3	4	5	6
equalDOF	10052	11052	3	4	5	6
equalDOF	10053	11053	3	4	5	6
equalDOF	10054	11054	3	4	5	6
equalDOF	10055	11055	3	4	5	6
equalDOF	10056	11056	3	4	5	6
equalDOF	10057	11057	3	4	5	6
equalDOF	10058	11058	3	4	5	6
equalDOF	10059	11059	3	4	5	6
equalDOF	10060	11060	3	4	5	6
equalDOF	10061	11061	3	4	5	6
equalDOF	10062	11062	3	4	5	6
equalDOF	10063	11063	3	4	5	6
equalDOF	10064	11064	3	4	5	6
equalDOF	10065	11065	3	4	5	6
equalDOF	10066	11066	3	4	5	6
equalDOF	10067	11067	3	4	5	6
equalDOF	10068	11068	3	4	5	6
equalDOF	10069	11069	3	4	5	6
equalDOF	10070	11070	3	4	5	6
equalDOF	10071	11071	3	4	5	6
equalDOF	10072	11072	3	4	5	6
equalDOF	10073	11073	3	4	5	6
equalDOF	10074	11074	3	4	5	6
equalDOF	10075	11075	3	4	5	6
equalDOF	10076	11076	3	4	5	6
equalDOF	10077	11077	3	4	5	6
equalDOF	10078	11078	3	4	5	6
equalDOF	10079	11079	3	4	5	6
equalDOF	10080	11080	3	4	5	6
equalDOF	10081	11081	3	4	5	6
equalDOF	10082	11082	3	4	5	6
equalDOF	10083	11083	3	4	5	6
equalDOF	10084	11084	3	4	5	6
equalDOF	10085	11085	3	4	5	6
equalDOF	10086	11086	3	4	5	6
equalDOF	10087	11087	3	4	5	6
equalDOF	10088	11088	3	4	5	6
equalDOF	10089	11089	3	4	5	6
equalDOF	10090	11090	3	4	5	6
equalDOF	10091	11091	3	4	5	6
equalDOF	10092	11092	3	4	5	6
equalDOF	10093	11093	3	4	5	6
equalDOF	10094	11094	3	4	5	6
equalDOF	10095	11095	3	4	5	6
equalDOF	10096	11096	3	4	5	6
equalDOF	10097	11097	3	4	5	6
equalDOF	10098	11098	3	4	5	6
equalDOF	10099	11099	3	4	5	6
equalDOF	10100	11100	3	4	5	6
equalDOF	10101	11101	3	4	5	6
equalDOF	10102	11102	3	4	5	6
equalDOF	10103	11103	3	4	5	6
equalDOF	10104	11104	3	4	5	6
equalDOF	10105	11105	3	4	5	6
equalDOF	10106	11106	3	4	5	6
equalDOF	10107	11107	3	4	5	6
equalDOF	10108	11108	3	4	5	6
equalDOF	10109	11109	3	4	5	6
equalDOF	10110	11110	3	4	5	6

equalDOF	20001	21001	3	4	5	6
equalDOF	20002	21002	3	4	5	6
equalDOF	20003	21003	3	4	5	6
equalDOF	20004	21004	3	4	5	6
equalDOF	20005	21005	3	4	5	6
equalDOF	20006	21006	3	4	5	6
equalDOF	20007	21007	3	4	5	6
equalDOF	20008	21008	3	4	5	6
equalDOF	20009	21009	3	4	5	6
equalDOF	20010	21010	3	4	5	6
equalDOF	20011	21011	3	4	5	6
equalDOF	20012	21012	3	4	5	6
equalDOF	20013	21013	3	4	5	6
equalDOF	20014	21014	3	4	5	6
equalDOF	20015	21015	3	4	5	6
equalDOF	20016	21016	3	4	5	6
equalDOF	20017	21017	3	4	5	6
equalDOF	20018	21018	3	4	5	6
equalDOF	20019	21019	3	4	5	6
equalDOF	20020	21020	3	4	5	6
equalDOF	20021	21021	3	4	5	6
equalDOF	20022	21022	3	4	5	6
equalDOF	20023	21023	3	4	5	6
equalDOF	20024	21024	3	4	5	6
equalDOF	20025	21025	3	4	5	6
equalDOF	20026	21026	3	4	5	6
equalDOF	20027	21027	3	4	5	6
equalDOF	20028	21028	3	4	5	6
equalDOF	20029	21029	3	4	5	6
equalDOF	20030	21030	3	4	5	6
equalDOF	20031	21031	3	4	5	6
equalDOF	20032	21032	3	4	5	6
equalDOF	20033	21033	3	4	5	6
equalDOF	20034	21034	3	4	5	6
equalDOF	20035	21035	3	4	5	6
equalDOF	20036	21036	3	4	5	6
equalDOF	20037	21037	3	4	5	6
equalDOF	20038	21038	3	4	5	6
equalDOF	20039	21039	3	4	5	6
equalDOF	20040	21040	3	4	5	6
equalDOF	20041	21041	3	4	5	6
equalDOF	20042	21042	3	4	5	6
equalDOF	20043	21043	3	4	5	6
equalDOF	20044	21044	3	4	5	6
equalDOF	20045	21045	3	4	5	6
equalDOF	20046	21046	3	4	5	6
equalDOF	20047	21047	3	4	5	6
equalDOF	20048	21048	3	4	5	6
equalDOF	20049	21049	3	4	5	6
equalDOF	20050	21050	3	4	5	6
equalDOF	20051	21051	3	4	5	6
equalDOF	20052	21052	3	4	5	6
equalDOF	20053	21053	3	4	5	6
equalDOF	20054	21054	3	4	5	6
equalDOF	20055	21055	3	4	5	6
equalDOF	20056	21056	3	4	5	6
equalDOF	20057	21057	3	4	5	6
equalDOF	20058	21058	3	4	5	6
equalDOF	20059	21059	3	4	5	6
equalDOF	20060	21060	3	4	5	6
equalDOF	20061	21061	3	4	5	6
equalDOF	20062	21062	3	4	5	6
equalDOF	20063	21063	3	4	5	6
equalDOF	20064	21064	3	4	5	6
equalDOF	20065	21065	3	4	5	6
equalDOF	20066	21066	3	4	5	6
equalDOF	20067	21067	3	4	5	6
equalDOF	20068	21068	3	4	5	6
equalDOF	20069	21069	3	4	5	6
equalDOF	20070	21070	3	4	5	6
equalDOF	20071	21071	3	4	5	6
equalDOF	20072	21072	3	4	5	6
equalDOF	20073	21073	3	4	5	6
equalDOF	20074	21074	3	4	5	6
equalDOF	20075	21075	3	4	5	6
equalDOF	20076	21076	3	4	5	6
equalDOF	20077	21077	3	4	5	6
equalDOF	20078	21078	3	4	5	6
equalDOF	20079	21079	3	4	5	6
equalDOF	20080	21080	3	4	5	6
equalDOF	20081	21081	3	4	5	6
equalDOF	20082	21082	3	4	5	6
equalDOF	20083	21083	3	4	5	6
equalDOF	20084	21084	3	4	5	6
equalDOF	20085	21085	3	4	5	6
equalDOF	20086	21086	3	4	5	6
equalDOF	20087	21087	3	4	5	6
equalDOF	20088	21088	3	4	5	6
equalDOF	20089	21089	3	4	5	6
equalDOF	20090	21090	3	4	5	6
equalDOF	20091	21091	3	4	5	6
equalDOF	20092	21092	3	4	5	6
equalDOF	20093	21093	3	4	5	6
equalDOF	20094	21094	3	4	5	6
equalDOF	20095	21095	3	4	5	6
equalDOF	20096	21096	3	4	5	6
equalDOF	20097	21097	3	4	5	6
equalDOF	20098	21098	3	4	5	6
equalDOF	20099	21099	3	4	5	6
equalDOF	20100	21100	3	4	5	6
equalDOF	20101	21101	3	4	5	6
equalDOF	20102	21102	3	4	5	6
equalDOF	20103	21103	3	4	5	6
equalDOF	20104	21104	3	4	5	6
equalDOF	20105	21105	3	4	5	6
equalDOF	20106	21106	3	4	5	6
equalDOF	20107	21107	3	4	5	6
equalDOF	20108	21108	3	4	5	6
equalDOF	20109	21109	3	4	5	6
equalDOF	20110	21110	3	4	5	6

equalDOF	30001	31001	3	4	5	6
equalDOF	30002	31002	3	4	5	6
equalDOF	30003	31003	3	4	5	6
equalDOF	30004	31004	3	4	5	6
equalDOF	30005	31005	3	4	5	6
equalDOF	30006	31006	3	4	5	6
equalDOF	30007	31007	3	4	5	6
equalDOF	30008	31008	3	4	5	6
equalDOF	30009	31009	3	4	5	6
equalDOF	30010	31010	3	4	5	6
equalDOF	30011	31011	3	4	5	6
equalDOF	30012	31012	3	4	5	6
equalDOF	30013	31013	3	4	5	6
equalDOF	30014	31014	3	4	5	6
equalDOF	30015	31015	3	4	5	6
equalDOF	30016	31016	3	4	5	6
equalDOF	30017	31017	3	4	5	6
equalDOF	30018	31018	3	4	5	6
equalDOF	30019	31019	3	4	5	6
equalDOF	30020	31020	3	4	5	6
equalDOF	30021	31021	3	4	5	6
equalDOF	30022	31022	3	4	5	6
equalDOF	30023	31023	3	4	5	6
equalDOF	30024	31024	3	4	5	6
equalDOF	30025	31025	3	4	5	6
equalDOF	30026	31026	3	4	5	6
equalDOF	30027	31027	3	4	5	6
equalDOF	30028	31028	3	4	5	6
equalDOF	30029	31029	3	4	5	6
equalDOF	30030	31030	3	4	5	6
equalDOF	30031	31031	3	4	5	6
equalDOF	30032	31032	3	4	5	6
equalDOF	30033	31033	3	4	5	6
equalDOF	30034	31034	3	4	5	6
equalDOF	30035	31035	3	4	5	6
equalDOF	30036	31036	3	4	5	6
equalDOF	30037	31037	3	4	5	6
equalDOF	30038	31038	3	4	5	6
equalDOF	30039	31039	3	4	5	6
equalDOF	30040	31040	3	4	5	6
equalDOF	30041	31041	3	4	5	6
equalDOF	30042	31042	3	4	5	6
equalDOF	30043	31043	3	4	5	6
equalDOF	30044	31044	3	4	5	6
equalDOF	30045	31045	3	4	5	6
equalDOF	30046	31046	3	4	5	6
equalDOF	30047	31047	3	4	5	6
equalDOF	30048	31048	3	4	5	6
equalDOF	30049	31049	3	4	5	6
equalDOF	30050	31050	3	4	5	6
equalDOF	30051	31051	3	4	5	6
equalDOF	30052	31052	3	4	5	6
equalDOF	30053	31053	3	4	5	6
equalDOF	30054	31054	3	4	5	6
equalDOF	30055	31055	3	4	5	6
equalDOF	30056	31056	3	4	5	6
equalDOF	30057	31057	3	4	5	6
equalDOF	30058	31058	3	4	5	6
equalDOF	30059	31059	3	4	5	6
equalDOF	30060	31060	3	4	5	6
equalDOF	30061	31061	3	4	5	6
equalDOF	30062	31062	3	4	5	6
equalDOF	30063	31063	3	4	5	6
equalDOF	30064	31064	3	4	5	6
equalDOF	30065	31065	3	4	5	6
equalDOF	30066	31066	3	4	5	6
equalDOF	30067	31067	3	4	5	6
equalDOF	30068	31068	3	4	5	6
equalDOF	30069	31069	3	4	5	6
equalDOF	30070	31070	3	4	5	6
equalDOF	30071	31071	3	4	5	6
equalDOF	30072	31072	3	4	5	6
equalDOF	30073	31073	3	4	5	6
equalDOF	30074	31074	3	4	5	6
equalDOF	30075	31075	3	4	5	6
equalDOF	30076	31076	3	4	5	6
equalDOF	30077	31077	3	4	5	6
equalDOF	30078	31078	3	4	5	6
equalDOF	30079	31079	3	4	5	6
equalDOF	30080	31080	3	4	5	6
equalDOF	30081	31081	3	4	5	6
equalDOF	30082	31082	3	4	5	6
equalDOF	30083	31083	3	4	5	6
equalDOF	30084	31084	3	4	5	6
equalDOF	30085	31085	3	4	5	6
equalDOF	30086	31086	3	4	5	6
equalDOF	30087	31087	3	4	5	6
equalDOF	30088	31088	3	4	5	6
equalDOF	30089	31089	3	4	5	6
equalDOF	30090	31090	3	4	5	6
equalDOF	30091	31091	3	4	5	6
equalDOF	30092	31092	3	4	5	6
equalDOF	30093	31093	3	4	5	6
equalDOF	30094	31094	3	4	5	6
equalDOF	30095	31095	3	4	5	6
equalDOF	30096	31096	3	4	5	6
equalDOF	30097	31097	3	4	5	6
equalDOF	30098	31098	3	4	5	6
equalDOF	30099	31099	3	4	5	6
equalDOF	30100	31100	3	4	5	6
equalDOF	30101	31101	3	4	5	6
equalDOF	30102	31102	3	4	5	6
equalDOF	30103	31103	3	4	5	6
equalDOF	30104	31104	3	4	5	6
equalDOF	30105	31105	3	4	5	6
equalDOF	30106	31106	3	4	5	6
equalDOF	30107	31107	3	4	5	6
equalDOF	30108	31108	3	4	5	6
equalDOF	30109	31109	3	4	5	6
equalDOF	30110	31110	3	4	5	6

equalDOF	40001	41001	3	4	5	6
equalDOF	40002	41002	3	4	5	6
equalDOF	40003	41003	3	4	5	6
equalDOF	40004	41004	3	4	5	6
equalDOF	40005	41005	3	4	5	6
equalDOF	40006	41006	3	4	5	6
equalDOF	40007	41007	3	4	5	6
equalDOF	40008	41008	3	4	5	6
equalDOF	40009	41009	3	4	5	6
equalDOF	40010	41010	3	4	5	6
equalDOF	40011	41011	3	4	5	6
equalDOF	40012	41012	3	4	5	6
equalDOF	40013	41013	3	4	5	6
equalDOF	40014	41014	3	4	5	6
equalDOF	40015	41015	3	4	5	6
equalDOF	40016	41016	3	4	5	6
equalDOF	40017	41017	3	4	5	6
equalDOF	40018	41018	3	4	5	6
equalDOF	40019	41019	3	4	5	6
equalDOF	40020	41020	3	4	5	6
equalDOF	40021	41021	3	4	5	6
equalDOF	40022	41022	3	4	5	6
equalDOF	40023	41023	3	4	5	6
equalDOF	40024	41024	3	4	5	6
equalDOF	40025	41025	3	4	5	6
equalDOF	40026	41026	3	4	5	6
equalDOF	40027	41027	3	4	5	6
equalDOF	40028	41028	3	4	5	6
equalDOF	40029	41029	3	4	5	6
equalDOF	40030	41030	3	4	5	6
equalDOF	40031	41031	3	4	5	6
equalDOF	40032	41032	3	4	5	6
equalDOF	40033	41033	3	4	5	6
equalDOF	40034	41034	3	4	5	6
equalDOF	40035	41035	3	4	5	6
equalDOF	40036	41036	3	4	5	6
equalDOF	40037	41037	3	4	5	6
equalDOF	40038	41038	3	4	5	6
equalDOF	40039	41039	3	4	5	6
equalDOF	40040	41040	3	4	5	6
equalDOF	40041	41041	3	4	5	6
equalDOF	40042	41042	3	4	5	6
equalDOF	40043	41043	3	4	5	6
equalDOF	40044	41044	3	4	5	6
equalDOF	40045	41045	3	4	5	6
equalDOF	40046	41046	3	4	5	6
equalDOF	40047	41047	3	4	5	6
equalDOF	40048	41048	3	4	5	6
equalDOF	40049	41049	3	4	5	6
equalDOF	40050	41050	3	4	5	6
equalDOF	40051	41051	3	4	5	6
equalDOF	40052	41052	3	4	5	6
equalDOF	40053	41053	3	4	5	6
equalDOF	40054	41054	3	4	5	6
equalDOF	40055	41055	3	4	5	6
equalDOF	40056	41056	3	4	5	6
equalDOF	40057	41057	3	4	5	6
equalDOF	40058	41058	3	4	5	6
equalDOF	40059	41059	3	4	5	6
equalDOF	40060	41060	3	4	5	6
equalDOF	40061	41061	3	4	5	6
equalDOF	40062	41062	3	4	5	6
equalDOF	40063	41063	3	4	5	6
equalDOF	40064	41064	3	4	5	6
equalDOF	40065	41065	3	4	5	6
equalDOF	40066	41066	3	4	5	6
equalDOF	40067	41067	3	4	5	6
equalDOF	40068	41068	3	4	5	6
equalDOF	40069	41069	3	4	5	6
equalDOF	40070	41070	3	4	5	6
equalDOF	40071	41071	3	4	5	6
equalDOF	40072	41072	3	4	5	6
equalDOF	40073	41073	3	4	5	6
equalDOF	40074	41074	3	4	5	6
equalDOF	40075	41075	3	4	5	6
equalDOF	40076	41076	3	4	5	6
equalDOF	40077	41077	3	4	5	6
equalDOF	40078	41078	3	4	5	6
equalDOF	40079	41079	3	4	5	6
equalDOF	40080	41080	3	4	5	6
equalDOF	40081	41081	3	4	5	6
equalDOF	40082	41082	3	4	5	6
equalDOF	40083	41083	3	4	5	6
equalDOF	40084	41084	3	4	5	6
equalDOF	40085	41085	3	4	5	6
equalDOF	40086	41086	3	4	5	6
equalDOF	40087	41087	3	4	5	6
equalDOF	40088	41088	3	4	5	6
equalDOF	40089	41089	3	4	5	6
equalDOF	40090	41090	3	4	5	6
equalDOF	40091	41091	3	4	5	6
equalDOF	40092	41092	3	4	5	6
equalDOF	40093	41093	3	4	5	6
equalDOF	40094	41094	3	4	5	6
equalDOF	40095	41095	3	4	5	6
equalDOF	40096	41096	3	4	5	6
equalDOF	40097	41097	3	4	5	6
equalDOF	40098	41098	3	4	5	6
equalDOF	40099	41099	3	4	5	6
equalDOF	40100	41100	3	4	5	6
equalDOF	40101	41101	3	4	5	6
equalDOF	40102	41102	3	4	5	6
equalDOF	40103	41103	3	4	5	6
equalDOF	40104	41104	3	4	5	6
equalDOF	40105	41105	3	4	5	6
equalDOF	40106	41106	3	4	5	6
equalDOF	40107	41107	3	4	5	6
equalDOF	40108	41108	3	4	5	6
equalDOF	40109	41109	3	4	5	6
equalDOF	40110	41110	3	4	5	6

#=========================================================
#               BASE PLATE NODES
#=========================================================
# Track 1 Base Plate
#	   nodeTag	   (x)	  (y)     (z)
node	51001	  0.000	  $R	  $hr
node	51002	  3.195	  $R	  $hr
node	51003	  6.390	  $R	  $hr
node	51004	  9.585	  $R	  $hr
node	51005	 12.780	  $R	  $hr
node	51006	 15.975	  $R	  $hr
node	51007	 19.170	  $R	  $hr
node	51008	 22.365	  $R	  $hr
node	51009	 25.560	  $R	  $hr
node	51010	 28.755	  $R	  $hr
node	51011	 31.950	  $R	  $hr
node	51012	 32.000	  $R	  $hr
node	51013	 35.195	  $R	  $hr
node	51014	 38.390	  $R	  $hr
node	51015	 41.585	  $R	  $hr
node	51016	 44.780	  $R	  $hr
node	51017	 47.975	  $R	  $hr
node	51018	 51.170	  $R	  $hr
node	51019	 54.365	  $R	  $hr
node	51020	 57.560	  $R	  $hr
node	51021	 60.755	  $R	  $hr
node	51022	 63.950	  $R	  $hr
node	51023	 64.000	  $R	  $hr
node	51024	 67.195	  $R	  $hr
node	51025	 70.390	  $R	  $hr
node	51026	 73.585	  $R	  $hr
node	51027	 76.780	  $R	  $hr
node	51028	 79.975	  $R	  $hr
node	51029	 83.170	  $R	  $hr
node	51030	 86.365	  $R	  $hr
node	51031	 89.560	  $R	  $hr
node	51032	 92.755	  $R	  $hr
node	51033	 95.950	  $R	  $hr
node	51034	 96.000	  $R	  $hr
node	51035	 99.195	  $R	  $hr
node	51036	102.390	  $R	  $hr
node	51037	105.585	  $R	  $hr
node	51038	108.780	  $R	  $hr
node	51039	111.975	  $R	  $hr
node	51040	115.170	  $R	  $hr
node	51041	118.365	  $R	  $hr
node	51042	121.560	  $R	  $hr
node	51043	124.755	  $R	  $hr
node	51044	127.950	  $R	  $hr
node	51045	128.000	  $R	  $hr
node	51046	131.195	  $R	  $hr
node	51047	134.390	  $R	  $hr
node	51048	137.585	  $R	  $hr
node	51049	140.780	  $R	  $hr
node	51050	143.975	  $R	  $hr
node	51051	147.170	  $R	  $hr
node	51052	150.365	  $R	  $hr
node	51053	153.560	  $R	  $hr
node	51054	156.755	  $R	  $hr
node	51055	159.950	  $R	  $hr
node	51056	160.000	  $R	  $hr
node	51057	163.195	  $R	  $hr
node	51058	166.390	  $R	  $hr
node	51059	169.585	  $R	  $hr
node	51060	172.780	  $R	  $hr
node	51061	175.975	  $R	  $hr
node	51062	179.170	  $R	  $hr
node	51063	182.365	  $R	  $hr
node	51064	185.560	  $R	  $hr
node	51065	188.755	  $R	  $hr
node	51066	191.950	  $R	  $hr
node	51067	192.000	  $R	  $hr
node	51068	195.195	  $R	  $hr
node	51069	198.390	  $R	  $hr
node	51070	201.585	  $R	  $hr
node	51071	204.780	  $R	  $hr
node	51072	207.975	  $R	  $hr
node	51073	211.170	  $R	  $hr
node	51074	214.365	  $R	  $hr
node	51075	217.560	  $R	  $hr
node	51076	220.755	  $R	  $hr
node	51077	223.950	  $R	  $hr
node	51078	224.000	  $R	  $hr
node	51079	227.195	  $R	  $hr
node	51080	230.390	  $R	  $hr
node	51081	233.585	  $R	  $hr
node	51082	236.780	  $R	  $hr
node	51083	239.975	  $R	  $hr
node	51084	243.170	  $R	  $hr
node	51085	246.365	  $R	  $hr
node	51086	249.560	  $R	  $hr
node	51087	252.755	  $R	  $hr
node	51088	255.950	  $R	  $hr
node	51089	256.000	  $R	  $hr
node	51090	259.195	  $R	  $hr
node	51091	262.390	  $R	  $hr
node	51092	265.585	  $R	  $hr
node	51093	268.780	  $R	  $hr
node	51094	271.975	  $R	  $hr
node	51095	275.170	  $R	  $hr
node	51096	278.365	  $R	  $hr
node	51097	281.560	  $R	  $hr
node	51098	284.755	  $R	  $hr
node	51099	287.950	  $R	  $hr
node	51100	288.000	  $R	  $hr
node	51101	291.195	  $R	  $hr
node	51102	294.390	  $R	  $hr
node	51103	297.585	  $R	  $hr
node	51104	300.780	  $R	  $hr
node	51105	303.975	  $R	  $hr
node	51106	307.170	  $R	  $hr
node	51107	310.365	  $R	  $hr
node	51108	313.560	  $R	  $hr
node	51109	316.755	  $R	  $hr
node	51110	319.950	  $R	  $hr

# Track 2 Base Plate
#	   nodeTag	   (x)	  (y)     (z)
node	61001	  0.000	  $L	  $hr
node	61002	  3.195	  $L	  $hr
node	61003	  6.390	  $L	  $hr
node	61004	  9.585	  $L	  $hr
node	61005	 12.780	  $L	  $hr
node	61006	 15.975	  $L	  $hr
node	61007	 19.170	  $L	  $hr
node	61008	 22.365	  $L	  $hr
node	61009	 25.560	  $L	  $hr
node	61010	 28.755	  $L	  $hr
node	61011	 31.950	  $L	  $hr
node	61012	 32.000	  $L	  $hr
node	61013	 35.195	  $L	  $hr
node	61014	 38.390	  $L	  $hr
node	61015	 41.585	  $L	  $hr
node	61016	 44.780	  $L	  $hr
node	61017	 47.975	  $L	  $hr
node	61018	 51.170	  $L	  $hr
node	61019	 54.365	  $L	  $hr
node	61020	 57.560	  $L	  $hr
node	61021	 60.755	  $L	  $hr
node	61022	 63.950	  $L	  $hr
node	61023	 64.000	  $L	  $hr
node	61024	 67.195	  $L	  $hr
node	61025	 70.390	  $L	  $hr
node	61026	 73.585	  $L	  $hr
node	61027	 76.780	  $L	  $hr
node	61028	 79.975	  $L	  $hr
node	61029	 83.170	  $L	  $hr
node	61030	 86.365	  $L	  $hr
node	61031	 89.560	  $L	  $hr
node	61032	 92.755	  $L	  $hr
node	61033	 95.950	  $L	  $hr
node	61034	 96.000	  $L	  $hr
node	61035	 99.195	  $L	  $hr
node	61036	102.390	  $L	  $hr
node	61037	105.585	  $L	  $hr
node	61038	108.780	  $L	  $hr
node	61039	111.975	  $L	  $hr
node	61040	115.170	  $L	  $hr
node	61041	118.365	  $L	  $hr
node	61042	121.560	  $L	  $hr
node	61043	124.755	  $L	  $hr
node	61044	127.950	  $L	  $hr
node	61045	128.000	  $L	  $hr
node	61046	131.195	  $L	  $hr
node	61047	134.390	  $L	  $hr
node	61048	137.585	  $L	  $hr
node	61049	140.780	  $L	  $hr
node	61050	143.975	  $L	  $hr
node	61051	147.170	  $L	  $hr
node	61052	150.365	  $L	  $hr
node	61053	153.560	  $L	  $hr
node	61054	156.755	  $L	  $hr
node	61055	159.950	  $L	  $hr
node	61056	160.000	  $L	  $hr
node	61057	163.195	  $L	  $hr
node	61058	166.390	  $L	  $hr
node	61059	169.585	  $L	  $hr
node	61060	172.780	  $L	  $hr
node	61061	175.975	  $L	  $hr
node	61062	179.170	  $L	  $hr
node	61063	182.365	  $L	  $hr
node	61064	185.560	  $L	  $hr
node	61065	188.755	  $L	  $hr
node	61066	191.950	  $L	  $hr
node	61067	192.000	  $L	  $hr
node	61068	195.195	  $L	  $hr
node	61069	198.390	  $L	  $hr
node	61070	201.585	  $L	  $hr
node	61071	204.780	  $L	  $hr
node	61072	207.975	  $L	  $hr
node	61073	211.170	  $L	  $hr
node	61074	214.365	  $L	  $hr
node	61075	217.560	  $L	  $hr
node	61076	220.755	  $L	  $hr
node	61077	223.950	  $L	  $hr
node	61078	224.000	  $L	  $hr
node	61079	227.195	  $L	  $hr
node	61080	230.390	  $L	  $hr
node	61081	233.585	  $L	  $hr
node	61082	236.780	  $L	  $hr
node	61083	239.975	  $L	  $hr
node	61084	243.170	  $L	  $hr
node	61085	246.365	  $L	  $hr
node	61086	249.560	  $L	  $hr
node	61087	252.755	  $L	  $hr
node	61088	255.950	  $L	  $hr
node	61089	256.000	  $L	  $hr
node	61090	259.195	  $L	  $hr
node	61091	262.390	  $L	  $hr
node	61092	265.585	  $L	  $hr
node	61093	268.780	  $L	  $hr
node	61094	271.975	  $L	  $hr
node	61095	275.170	  $L	  $hr
node	61096	278.365	  $L	  $hr
node	61097	281.560	  $L	  $hr
node	61098	284.755	  $L	  $hr
node	61099	287.950	  $L	  $hr
node	61100	288.000	  $L	  $hr
node	61101	291.195	  $L	  $hr
node	61102	294.390	  $L	  $hr
node	61103	297.585	  $L	  $hr
node	61104	300.780	  $L	  $hr
node	61105	303.975	  $L	  $hr
node	61106	307.170	  $L	  $hr
node	61107	310.365	  $L	  $hr
node	61108	313.560	  $L	  $hr
node	61109	316.755	  $L	  $hr
node	61110	319.950	  $L	  $hr

#=========================================================
#               TRACK PLATE NODES
#=========================================================

# Track 1 Track Plate
#	   nodeTag	   (x)	  (y)     (z)
node	52001	  0.000	  $R	  $hr
node	52002	  3.195	  $R	  $hr
node	52003	  6.390	  $R	  $hr
node	52004	  9.585	  $R	  $hr
node	52005	 12.780	  $R	  $hr
node	52006	 15.975	  $R	  $hr
node	52007	 19.170	  $R	  $hr
node	52008	 22.365	  $R	  $hr
node	52009	 25.560	  $R	  $hr
node	52010	 28.755	  $R	  $hr
node	52011	 31.950	  $R	  $hr
node	52012	 32.000	  $R	  $hr
node	52013	 35.195	  $R	  $hr
node	52014	 38.390	  $R	  $hr
node	52015	 41.585	  $R	  $hr
node	52016	 44.780	  $R	  $hr
node	52017	 47.975	  $R	  $hr
node	52018	 51.170	  $R	  $hr
node	52019	 54.365	  $R	  $hr
node	52020	 57.560	  $R	  $hr
node	52021	 60.755	  $R	  $hr
node	52022	 63.950	  $R	  $hr
node	52023	 64.000	  $R	  $hr
node	52024	 67.195	  $R	  $hr
node	52025	 70.390	  $R	  $hr
node	52026	 73.585	  $R	  $hr
node	52027	 76.780	  $R	  $hr
node	52028	 79.975	  $R	  $hr
node	52029	 83.170	  $R	  $hr
node	52030	 86.365	  $R	  $hr
node	52031	 89.560	  $R	  $hr
node	52032	 92.755	  $R	  $hr
node	52033	 95.950	  $R	  $hr
node	52034	 96.000	  $R	  $hr
node	52035	 99.195	  $R	  $hr
node	52036	102.390	  $R	  $hr
node	52037	105.585	  $R	  $hr
node	52038	108.780	  $R	  $hr
node	52039	111.975	  $R	  $hr
node	52040	115.170	  $R	  $hr
node	52041	118.365	  $R	  $hr
node	52042	121.560	  $R	  $hr
node	52043	124.755	  $R	  $hr
node	52044	127.950	  $R	  $hr
node	52045	128.000	  $R	  $hr
node	52046	131.195	  $R	  $hr
node	52047	134.390	  $R	  $hr
node	52048	137.585	  $R	  $hr
node	52049	140.780	  $R	  $hr
node	52050	143.975	  $R	  $hr
node	52051	147.170	  $R	  $hr
node	52052	150.365	  $R	  $hr
node	52053	153.560	  $R	  $hr
node	52054	156.755	  $R	  $hr
node	52055	159.950	  $R	  $hr
node	52056	160.000	  $R	  $hr
node	52057	163.195	  $R	  $hr
node	52058	166.390	  $R	  $hr
node	52059	169.585	  $R	  $hr
node	52060	172.780	  $R	  $hr
node	52061	175.975	  $R	  $hr
node	52062	179.170	  $R	  $hr
node	52063	182.365	  $R	  $hr
node	52064	185.560	  $R	  $hr
node	52065	188.755	  $R	  $hr
node	52066	191.950	  $R	  $hr
node	52067	192.000	  $R	  $hr
node	52068	195.195	  $R	  $hr
node	52069	198.390	  $R	  $hr
node	52070	201.585	  $R	  $hr
node	52071	204.780	  $R	  $hr
node	52072	207.975	  $R	  $hr
node	52073	211.170	  $R	  $hr
node	52074	214.365	  $R	  $hr
node	52075	217.560	  $R	  $hr
node	52076	220.755	  $R	  $hr
node	52077	223.950	  $R	  $hr
node	52078	224.000	  $R	  $hr
node	52079	227.195	  $R	  $hr
node	52080	230.390	  $R	  $hr
node	52081	233.585	  $R	  $hr
node	52082	236.780	  $R	  $hr
node	52083	239.975	  $R	  $hr
node	52084	243.170	  $R	  $hr
node	52085	246.365	  $R	  $hr
node	52086	249.560	  $R	  $hr
node	52087	252.755	  $R	  $hr
node	52088	255.950	  $R	  $hr
node	52089	256.000	  $R	  $hr
node	52090	259.195	  $R	  $hr
node	52091	262.390	  $R	  $hr
node	52092	265.585	  $R	  $hr
node	52093	268.780	  $R	  $hr
node	52094	271.975	  $R	  $hr
node	52095	275.170	  $R	  $hr
node	52096	278.365	  $R	  $hr
node	52097	281.560	  $R	  $hr
node	52098	284.755	  $R	  $hr
node	52099	287.950	  $R	  $hr
node	52100	288.000	  $R	  $hr
node	52101	291.195	  $R	  $hr
node	52102	294.390	  $R	  $hr
node	52103	297.585	  $R	  $hr
node	52104	300.780	  $R	  $hr
node	52105	303.975	  $R	  $hr
node	52106	307.170	  $R	  $hr
node	52107	310.365	  $R	  $hr
node	52108	313.560	  $R	  $hr
node	52109	316.755	  $R	  $hr
node	52110	319.950	  $R	  $hr

# Track 2 Track Plate
#	   nodeTag	   (x)	  (y)     (z)
node	62001	  0.000	  $L	  $hr
node	62002	  3.195	  $L	  $hr
node	62003	  6.390	  $L	  $hr
node	62004	  9.585	  $L	  $hr
node	62005	 12.780	  $L	  $hr
node	62006	 15.975	  $L	  $hr
node	62007	 19.170	  $L	  $hr
node	62008	 22.365	  $L	  $hr
node	62009	 25.560	  $L	  $hr
node	62010	 28.755	  $L	  $hr
node	62011	 31.950	  $L	  $hr
node	62012	 32.000	  $L	  $hr
node	62013	 35.195	  $L	  $hr
node	62014	 38.390	  $L	  $hr
node	62015	 41.585	  $L	  $hr
node	62016	 44.780	  $L	  $hr
node	62017	 47.975	  $L	  $hr
node	62018	 51.170	  $L	  $hr
node	62019	 54.365	  $L	  $hr
node	62020	 57.560	  $L	  $hr
node	62021	 60.755	  $L	  $hr
node	62022	 63.950	  $L	  $hr
node	62023	 64.000	  $L	  $hr
node	62024	 67.195	  $L	  $hr
node	62025	 70.390	  $L	  $hr
node	62026	 73.585	  $L	  $hr
node	62027	 76.780	  $L	  $hr
node	62028	 79.975	  $L	  $hr
node	62029	 83.170	  $L	  $hr
node	62030	 86.365	  $L	  $hr
node	62031	 89.560	  $L	  $hr
node	62032	 92.755	  $L	  $hr
node	62033	 95.950	  $L	  $hr
node	62034	 96.000	  $L	  $hr
node	62035	 99.195	  $L	  $hr
node	62036	102.390	  $L	  $hr
node	62037	105.585	  $L	  $hr
node	62038	108.780	  $L	  $hr
node	62039	111.975	  $L	  $hr
node	62040	115.170	  $L	  $hr
node	62041	118.365	  $L	  $hr
node	62042	121.560	  $L	  $hr
node	62043	124.755	  $L	  $hr
node	62044	127.950	  $L	  $hr
node	62045	128.000	  $L	  $hr
node	62046	131.195	  $L	  $hr
node	62047	134.390	  $L	  $hr
node	62048	137.585	  $L	  $hr
node	62049	140.780	  $L	  $hr
node	62050	143.975	  $L	  $hr
node	62051	147.170	  $L	  $hr
node	62052	150.365	  $L	  $hr
node	62053	153.560	  $L	  $hr
node	62054	156.755	  $L	  $hr
node	62055	159.950	  $L	  $hr
node	62056	160.000	  $L	  $hr
node	62057	163.195	  $L	  $hr
node	62058	166.390	  $L	  $hr
node	62059	169.585	  $L	  $hr
node	62060	172.780	  $L	  $hr
node	62061	175.975	  $L	  $hr
node	62062	179.170	  $L	  $hr
node	62063	182.365	  $L	  $hr
node	62064	185.560	  $L	  $hr
node	62065	188.755	  $L	  $hr
node	62066	191.950	  $L	  $hr
node	62067	192.000	  $L	  $hr
node	62068	195.195	  $L	  $hr
node	62069	198.390	  $L	  $hr
node	62070	201.585	  $L	  $hr
node	62071	204.780	  $L	  $hr
node	62072	207.975	  $L	  $hr
node	62073	211.170	  $L	  $hr
node	62074	214.365	  $L	  $hr
node	62075	217.560	  $L	  $hr
node	62076	220.755	  $L	  $hr
node	62077	223.950	  $L	  $hr
node	62078	224.000	  $L	  $hr
node	62079	227.195	  $L	  $hr
node	62080	230.390	  $L	  $hr
node	62081	233.585	  $L	  $hr
node	62082	236.780	  $L	  $hr
node	62083	239.975	  $L	  $hr
node	62084	243.170	  $L	  $hr
node	62085	246.365	  $L	  $hr
node	62086	249.560	  $L	  $hr
node	62087	252.755	  $L	  $hr
node	62088	255.950	  $L	  $hr
node	62089	256.000	  $L	  $hr
node	62090	259.195	  $L	  $hr
node	62091	262.390	  $L	  $hr
node	62092	265.585	  $L	  $hr
node	62093	268.780	  $L	  $hr
node	62094	271.975	  $L	  $hr
node	62095	275.170	  $L	  $hr
node	62096	278.365	  $L	  $hr
node	62097	281.560	  $L	  $hr
node	62098	284.755	  $L	  $hr
node	62099	287.950	  $L	  $hr
node	62100	288.000	  $L	  $hr
node	62101	291.195	  $L	  $hr
node	62102	294.390	  $L	  $hr
node	62103	297.585	  $L	  $hr
node	62104	300.780	  $L	  $hr
node	62105	303.975	  $L	  $hr
node	62106	307.170	  $L	  $hr
node	62107	310.365	  $L	  $hr
node	62108	313.560	  $L	  $hr
node	62109	316.755	  $L	  $hr
node	62110	319.950	  $L	  $hr

equalDOF	51001	52001	 2	 3	 4	 5	 6
equalDOF	51002	52002	 2	 3	 4	 5	 6
equalDOF	51003	52003	 2	 3	 4	 5	 6
equalDOF	51004	52004	 2	 3	 4	 5	 6
equalDOF	51005	52005	 2	 3	 4	 5	 6
equalDOF	51006	52006	 2	 3	 4	 5	 6
equalDOF	51007	52007	 2	 3	 4	 5	 6
equalDOF	51008	52008	 2	 3	 4	 5	 6
equalDOF	51009	52009	 2	 3	 4	 5	 6
equalDOF	51010	52010	 2	 3	 4	 5	 6
equalDOF	51011	52011	 2	 3	 4	 5	 6
equalDOF	51012	52012	 2	 3	 4	 5	 6
equalDOF	51013	52013	 2	 3	 4	 5	 6
equalDOF	51014	52014	 2	 3	 4	 5	 6
equalDOF	51015	52015	 2	 3	 4	 5	 6
equalDOF	51016	52016	 2	 3	 4	 5	 6
equalDOF	51017	52017	 2	 3	 4	 5	 6
equalDOF	51018	52018	 2	 3	 4	 5	 6
equalDOF	51019	52019	 2	 3	 4	 5	 6
equalDOF	51020	52020	 2	 3	 4	 5	 6
equalDOF	51021	52021	 2	 3	 4	 5	 6
equalDOF	51022	52022	 2	 3	 4	 5	 6
equalDOF	51023	52023	 2	 3	 4	 5	 6
equalDOF	51024	52024	 2	 3	 4	 5	 6
equalDOF	51025	52025	 2	 3	 4	 5	 6
equalDOF	51026	52026	 2	 3	 4	 5	 6
equalDOF	51027	52027	 2	 3	 4	 5	 6
equalDOF	51028	52028	 2	 3	 4	 5	 6
equalDOF	51029	52029	 2	 3	 4	 5	 6
equalDOF	51030	52030	 2	 3	 4	 5	 6
equalDOF	51031	52031	 2	 3	 4	 5	 6
equalDOF	51032	52032	 2	 3	 4	 5	 6
equalDOF	51033	52033	 2	 3	 4	 5	 6
equalDOF	51034	52034	 2	 3	 4	 5	 6
equalDOF	51035	52035	 2	 3	 4	 5	 6
equalDOF	51036	52036	 2	 3	 4	 5	 6
equalDOF	51037	52037	 2	 3	 4	 5	 6
equalDOF	51038	52038	 2	 3	 4	 5	 6
equalDOF	51039	52039	 2	 3	 4	 5	 6
equalDOF	51040	52040	 2	 3	 4	 5	 6
equalDOF	51041	52041	 2	 3	 4	 5	 6
equalDOF	51042	52042	 2	 3	 4	 5	 6
equalDOF	51043	52043	 2	 3	 4	 5	 6
equalDOF	51044	52044	 2	 3	 4	 5	 6
equalDOF	51045	52045	 2	 3	 4	 5	 6
equalDOF	51046	52046	 2	 3	 4	 5	 6
equalDOF	51047	52047	 2	 3	 4	 5	 6
equalDOF	51048	52048	 2	 3	 4	 5	 6
equalDOF	51049	52049	 2	 3	 4	 5	 6
equalDOF	51050	52050	 2	 3	 4	 5	 6
equalDOF	51051	52051	 2	 3	 4	 5	 6
equalDOF	51052	52052	 2	 3	 4	 5	 6
equalDOF	51053	52053	 2	 3	 4	 5	 6
equalDOF	51054	52054	 2	 3	 4	 5	 6
equalDOF	51055	52055	 2	 3	 4	 5	 6
equalDOF	51056	52056	 2	 3	 4	 5	 6
equalDOF	51057	52057	 2	 3	 4	 5	 6
equalDOF	51058	52058	 2	 3	 4	 5	 6
equalDOF	51059	52059	 2	 3	 4	 5	 6
equalDOF	51060	52060	 2	 3	 4	 5	 6
equalDOF	51061	52061	 2	 3	 4	 5	 6
equalDOF	51062	52062	 2	 3	 4	 5	 6
equalDOF	51063	52063	 2	 3	 4	 5	 6
equalDOF	51064	52064	 2	 3	 4	 5	 6
equalDOF	51065	52065	 2	 3	 4	 5	 6
equalDOF	51066	52066	 2	 3	 4	 5	 6
equalDOF	51067	52067	 2	 3	 4	 5	 6
equalDOF	51068	52068	 2	 3	 4	 5	 6
equalDOF	51069	52069	 2	 3	 4	 5	 6
equalDOF	51070	52070	 2	 3	 4	 5	 6
equalDOF	51071	52071	 2	 3	 4	 5	 6
equalDOF	51072	52072	 2	 3	 4	 5	 6
equalDOF	51073	52073	 2	 3	 4	 5	 6
equalDOF	51074	52074	 2	 3	 4	 5	 6
equalDOF	51075	52075	 2	 3	 4	 5	 6
equalDOF	51076	52076	 2	 3	 4	 5	 6
equalDOF	51077	52077	 2	 3	 4	 5	 6
equalDOF	51078	52078	 2	 3	 4	 5	 6
equalDOF	51079	52079	 2	 3	 4	 5	 6
equalDOF	51080	52080	 2	 3	 4	 5	 6
equalDOF	51081	52081	 2	 3	 4	 5	 6
equalDOF	51082	52082	 2	 3	 4	 5	 6
equalDOF	51083	52083	 2	 3	 4	 5	 6
equalDOF	51084	52084	 2	 3	 4	 5	 6
equalDOF	51085	52085	 2	 3	 4	 5	 6
equalDOF	51086	52086	 2	 3	 4	 5	 6
equalDOF	51087	52087	 2	 3	 4	 5	 6
equalDOF	51088	52088	 2	 3	 4	 5	 6
equalDOF	51089	52089	 2	 3	 4	 5	 6
equalDOF	51090	52090	 2	 3	 4	 5	 6
equalDOF	51091	52091	 2	 3	 4	 5	 6
equalDOF	51092	52092	 2	 3	 4	 5	 6
equalDOF	51093	52093	 2	 3	 4	 5	 6
equalDOF	51094	52094	 2	 3	 4	 5	 6
equalDOF	51095	52095	 2	 3	 4	 5	 6
equalDOF	51096	52096	 2	 3	 4	 5	 6
equalDOF	51097	52097	 2	 3	 4	 5	 6
equalDOF	51098	52098	 2	 3	 4	 5	 6
equalDOF	51099	52099	 2	 3	 4	 5	 6
equalDOF	51100	52100	 2	 3	 4	 5	 6
equalDOF	51101	52101	 2	 3	 4	 5	 6
equalDOF	51102	52102	 2	 3	 4	 5	 6
equalDOF	51103	52103	 2	 3	 4	 5	 6
equalDOF	51104	52104	 2	 3	 4	 5	 6
equalDOF	51105	52105	 2	 3	 4	 5	 6
equalDOF	51106	52106	 2	 3	 4	 5	 6
equalDOF	51107	52107	 2	 3	 4	 5	 6
equalDOF	51108	52108	 2	 3	 4	 5	 6
equalDOF	51109	52109	 2	 3	 4	 5	 6
equalDOF	51110	52110	 2	 3	 4	 5	 6

equalDOF	61001	62001	 2	 3	 4	 5	 6
equalDOF	61002	62002	 2	 3	 4	 5	 6
equalDOF	61003	62003	 2	 3	 4	 5	 6
equalDOF	61004	62004	 2	 3	 4	 5	 6
equalDOF	61005	62005	 2	 3	 4	 5	 6
equalDOF	61006	62006	 2	 3	 4	 5	 6
equalDOF	61007	62007	 2	 3	 4	 5	 6
equalDOF	61008	62008	 2	 3	 4	 5	 6
equalDOF	61009	62009	 2	 3	 4	 5	 6
equalDOF	61010	62010	 2	 3	 4	 5	 6
equalDOF	61011	62011	 2	 3	 4	 5	 6
equalDOF	61012	62012	 2	 3	 4	 5	 6
equalDOF	61013	62013	 2	 3	 4	 5	 6
equalDOF	61014	62014	 2	 3	 4	 5	 6
equalDOF	61015	62015	 2	 3	 4	 5	 6
equalDOF	61016	62016	 2	 3	 4	 5	 6
equalDOF	61017	62017	 2	 3	 4	 5	 6
equalDOF	61018	62018	 2	 3	 4	 5	 6
equalDOF	61019	62019	 2	 3	 4	 5	 6
equalDOF	61020	62020	 2	 3	 4	 5	 6
equalDOF	61021	62021	 2	 3	 4	 5	 6
equalDOF	61022	62022	 2	 3	 4	 5	 6
equalDOF	61023	62023	 2	 3	 4	 5	 6
equalDOF	61024	62024	 2	 3	 4	 5	 6
equalDOF	61025	62025	 2	 3	 4	 5	 6
equalDOF	61026	62026	 2	 3	 4	 5	 6
equalDOF	61027	62027	 2	 3	 4	 5	 6
equalDOF	61028	62028	 2	 3	 4	 5	 6
equalDOF	61029	62029	 2	 3	 4	 5	 6
equalDOF	61030	62030	 2	 3	 4	 5	 6
equalDOF	61031	62031	 2	 3	 4	 5	 6
equalDOF	61032	62032	 2	 3	 4	 5	 6
equalDOF	61033	62033	 2	 3	 4	 5	 6
equalDOF	61034	62034	 2	 3	 4	 5	 6
equalDOF	61035	62035	 2	 3	 4	 5	 6
equalDOF	61036	62036	 2	 3	 4	 5	 6
equalDOF	61037	62037	 2	 3	 4	 5	 6
equalDOF	61038	62038	 2	 3	 4	 5	 6
equalDOF	61039	62039	 2	 3	 4	 5	 6
equalDOF	61040	62040	 2	 3	 4	 5	 6
equalDOF	61041	62041	 2	 3	 4	 5	 6
equalDOF	61042	62042	 2	 3	 4	 5	 6
equalDOF	61043	62043	 2	 3	 4	 5	 6
equalDOF	61044	62044	 2	 3	 4	 5	 6
equalDOF	61045	62045	 2	 3	 4	 5	 6
equalDOF	61046	62046	 2	 3	 4	 5	 6
equalDOF	61047	62047	 2	 3	 4	 5	 6
equalDOF	61048	62048	 2	 3	 4	 5	 6
equalDOF	61049	62049	 2	 3	 4	 5	 6
equalDOF	61050	62050	 2	 3	 4	 5	 6
equalDOF	61051	62051	 2	 3	 4	 5	 6
equalDOF	61052	62052	 2	 3	 4	 5	 6
equalDOF	61053	62053	 2	 3	 4	 5	 6
equalDOF	61054	62054	 2	 3	 4	 5	 6
equalDOF	61055	62055	 2	 3	 4	 5	 6
equalDOF	61056	62056	 2	 3	 4	 5	 6
equalDOF	61057	62057	 2	 3	 4	 5	 6
equalDOF	61058	62058	 2	 3	 4	 5	 6
equalDOF	61059	62059	 2	 3	 4	 5	 6
equalDOF	61060	62060	 2	 3	 4	 5	 6
equalDOF	61061	62061	 2	 3	 4	 5	 6
equalDOF	61062	62062	 2	 3	 4	 5	 6
equalDOF	61063	62063	 2	 3	 4	 5	 6
equalDOF	61064	62064	 2	 3	 4	 5	 6
equalDOF	61065	62065	 2	 3	 4	 5	 6
equalDOF	61066	62066	 2	 3	 4	 5	 6
equalDOF	61067	62067	 2	 3	 4	 5	 6
equalDOF	61068	62068	 2	 3	 4	 5	 6
equalDOF	61069	62069	 2	 3	 4	 5	 6
equalDOF	61070	62070	 2	 3	 4	 5	 6
equalDOF	61071	62071	 2	 3	 4	 5	 6
equalDOF	61072	62072	 2	 3	 4	 5	 6
equalDOF	61073	62073	 2	 3	 4	 5	 6
equalDOF	61074	62074	 2	 3	 4	 5	 6
equalDOF	61075	62075	 2	 3	 4	 5	 6
equalDOF	61076	62076	 2	 3	 4	 5	 6
equalDOF	61077	62077	 2	 3	 4	 5	 6
equalDOF	61078	62078	 2	 3	 4	 5	 6
equalDOF	61079	62079	 2	 3	 4	 5	 6
equalDOF	61080	62080	 2	 3	 4	 5	 6
equalDOF	61081	62081	 2	 3	 4	 5	 6
equalDOF	61082	62082	 2	 3	 4	 5	 6
equalDOF	61083	62083	 2	 3	 4	 5	 6
equalDOF	61084	62084	 2	 3	 4	 5	 6
equalDOF	61085	62085	 2	 3	 4	 5	 6
equalDOF	61086	62086	 2	 3	 4	 5	 6
equalDOF	61087	62087	 2	 3	 4	 5	 6
equalDOF	61088	62088	 2	 3	 4	 5	 6
equalDOF	61089	62089	 2	 3	 4	 5	 6
equalDOF	61090	62090	 2	 3	 4	 5	 6
equalDOF	61091	62091	 2	 3	 4	 5	 6
equalDOF	61092	62092	 2	 3	 4	 5	 6
equalDOF	61093	62093	 2	 3	 4	 5	 6
equalDOF	61094	62094	 2	 3	 4	 5	 6
equalDOF	61095	62095	 2	 3	 4	 5	 6
equalDOF	61096	62096	 2	 3	 4	 5	 6
equalDOF	61097	62097	 2	 3	 4	 5	 6
equalDOF	61098	62098	 2	 3	 4	 5	 6
equalDOF	61099	62099	 2	 3	 4	 5	 6
equalDOF	61100	62100	 2	 3	 4	 5	 6
equalDOF	61101	62101	 2	 3	 4	 5	 6
equalDOF	61102	62102	 2	 3	 4	 5	 6
equalDOF	61103	62103	 2	 3	 4	 5	 6
equalDOF	61104	62104	 2	 3	 4	 5	 6
equalDOF	61105	62105	 2	 3	 4	 5	 6
equalDOF	61106	62106	 2	 3	 4	 5	 6
equalDOF	61107	62107	 2	 3	 4	 5	 6
equalDOF	61108	62108	 2	 3	 4	 5	 6
equalDOF	61109	62109	 2	 3	 4	 5	 6
equalDOF	61110	62110	 2	 3	 4	 5	 6

#=========================================================
#               GIRDER TRACK CONNECTION NODES
#=========================================================
#	   nodeTag	   (x)	  (y)     (z)
node	50001	  0.000	  $R	  $hr
node	50002	  3.195	  $R	  $hr
node	50003	  6.390	  $R	  $hr
node	50004	  9.585	  $R	  $hr
node	50005	 12.780	  $R	  $hr
node	50006	 15.975	  $R	  $hr
node	50007	 19.170	  $R	  $hr
node	50008	 22.365	  $R	  $hr
node	50009	 25.560	  $R	  $hr
node	50010	 28.755	  $R	  $hr
node	50011	 31.950	  $R	  $hr
node	50012	 32.000	  $R	  $hr
node	50013	 35.195	  $R	  $hr
node	50014	 38.390	  $R	  $hr
node	50015	 41.585	  $R	  $hr
node	50016	 44.780	  $R	  $hr
node	50017	 47.975	  $R	  $hr
node	50018	 51.170	  $R	  $hr
node	50019	 54.365	  $R	  $hr
node	50020	 57.560	  $R	  $hr
node	50021	 60.755	  $R	  $hr
node	50022	 63.950	  $R	  $hr
node	50023	 64.000	  $R	  $hr
node	50024	 67.195	  $R	  $hr
node	50025	 70.390	  $R	  $hr
node	50026	 73.585	  $R	  $hr
node	50027	 76.780	  $R	  $hr
node	50028	 79.975	  $R	  $hr
node	50029	 83.170	  $R	  $hr
node	50030	 86.365	  $R	  $hr
node	50031	 89.560	  $R	  $hr
node	50032	 92.755	  $R	  $hr
node	50033	 95.950	  $R	  $hr
node	50034	 96.000	  $R	  $hr
node	50035	 99.195	  $R	  $hr
node	50036	102.390	  $R	  $hr
node	50037	105.585	  $R	  $hr
node	50038	108.780	  $R	  $hr
node	50039	111.975	  $R	  $hr
node	50040	115.170	  $R	  $hr
node	50041	118.365	  $R	  $hr
node	50042	121.560	  $R	  $hr
node	50043	124.755	  $R	  $hr
node	50044	127.950	  $R	  $hr
node	50045	128.000	  $R	  $hr
node	50046	131.195	  $R	  $hr
node	50047	134.390	  $R	  $hr
node	50048	137.585	  $R	  $hr
node	50049	140.780	  $R	  $hr
node	50050	143.975	  $R	  $hr
node	50051	147.170	  $R	  $hr
node	50052	150.365	  $R	  $hr
node	50053	153.560	  $R	  $hr
node	50054	156.755	  $R	  $hr
node	50055	159.950	  $R	  $hr
node	50056	160.000	  $R	  $hr
node	50057	163.195	  $R	  $hr
node	50058	166.390	  $R	  $hr
node	50059	169.585	  $R	  $hr
node	50060	172.780	  $R	  $hr
node	50061	175.975	  $R	  $hr
node	50062	179.170	  $R	  $hr
node	50063	182.365	  $R	  $hr
node	50064	185.560	  $R	  $hr
node	50065	188.755	  $R	  $hr
node	50066	191.950	  $R	  $hr
node	50067	192.000	  $R	  $hr
node	50068	195.195	  $R	  $hr
node	50069	198.390	  $R	  $hr
node	50070	201.585	  $R	  $hr
node	50071	204.780	  $R	  $hr
node	50072	207.975	  $R	  $hr
node	50073	211.170	  $R	  $hr
node	50074	214.365	  $R	  $hr
node	50075	217.560	  $R	  $hr
node	50076	220.755	  $R	  $hr
node	50077	223.950	  $R	  $hr
node	50078	224.000	  $R	  $hr
node	50079	227.195	  $R	  $hr
node	50080	230.390	  $R	  $hr
node	50081	233.585	  $R	  $hr
node	50082	236.780	  $R	  $hr
node	50083	239.975	  $R	  $hr
node	50084	243.170	  $R	  $hr
node	50085	246.365	  $R	  $hr
node	50086	249.560	  $R	  $hr
node	50087	252.755	  $R	  $hr
node	50088	255.950	  $R	  $hr
node	50089	256.000	  $R	  $hr
node	50090	259.195	  $R	  $hr
node	50091	262.390	  $R	  $hr
node	50092	265.585	  $R	  $hr
node	50093	268.780	  $R	  $hr
node	50094	271.975	  $R	  $hr
node	50095	275.170	  $R	  $hr
node	50096	278.365	  $R	  $hr
node	50097	281.560	  $R	  $hr
node	50098	284.755	  $R	  $hr
node	50099	287.950	  $R	  $hr
node	50100	288.000	  $R	  $hr
node	50101	291.195	  $R	  $hr
node	50102	294.390	  $R	  $hr
node	50103	297.585	  $R	  $hr
node	50104	300.780	  $R	  $hr
node	50105	303.975	  $R	  $hr
node	50106	307.170	  $R	  $hr
node	50107	310.365	  $R	  $hr
node	50108	313.560	  $R	  $hr
node	50109	316.755	  $R	  $hr
node	50110	319.950	  $R	  $hr

# Farther side
node	60001	  0.000	  $L	  $hr
node	60002	  3.195	  $L	  $hr
node	60003	  6.390	  $L	  $hr
node	60004	  9.585	  $L	  $hr
node	60005	 12.780	  $L	  $hr
node	60006	 15.975	  $L	  $hr
node	60007	 19.170	  $L	  $hr
node	60008	 22.365	  $L	  $hr
node	60009	 25.560	  $L	  $hr
node	60010	 28.755	  $L	  $hr
node	60011	 31.950	  $L	  $hr
node	60012	 32.000	  $L	  $hr
node	60013	 35.195	  $L	  $hr
node	60014	 38.390	  $L	  $hr
node	60015	 41.585	  $L	  $hr
node	60016	 44.780	  $L	  $hr
node	60017	 47.975	  $L	  $hr
node	60018	 51.170	  $L	  $hr
node	60019	 54.365	  $L	  $hr
node	60020	 57.560	  $L	  $hr
node	60021	 60.755	  $L	  $hr
node	60022	 63.950	  $L	  $hr
node	60023	 64.000	  $L	  $hr
node	60024	 67.195	  $L	  $hr
node	60025	 70.390	  $L	  $hr
node	60026	 73.585	  $L	  $hr
node	60027	 76.780	  $L	  $hr
node	60028	 79.975	  $L	  $hr
node	60029	 83.170	  $L	  $hr
node	60030	 86.365	  $L	  $hr
node	60031	 89.560	  $L	  $hr
node	60032	 92.755	  $L	  $hr
node	60033	 95.950	  $L	  $hr
node	60034	 96.000	  $L	  $hr
node	60035	 99.195	  $L	  $hr
node	60036	102.390	  $L	  $hr
node	60037	105.585	  $L	  $hr
node	60038	108.780	  $L	  $hr
node	60039	111.975	  $L	  $hr
node	60040	115.170	  $L	  $hr
node	60041	118.365	  $L	  $hr
node	60042	121.560	  $L	  $hr
node	60043	124.755	  $L	  $hr
node	60044	127.950	  $L	  $hr
node	60045	128.000	  $L	  $hr
node	60046	131.195	  $L	  $hr
node	60047	134.390	  $L	  $hr
node	60048	137.585	  $L	  $hr
node	60049	140.780	  $L	  $hr
node	60050	143.975	  $L	  $hr
node	60051	147.170	  $L	  $hr
node	60052	150.365	  $L	  $hr
node	60053	153.560	  $L	  $hr
node	60054	156.755	  $L	  $hr
node	60055	159.950	  $L	  $hr
node	60056	160.000	  $L	  $hr
node	60057	163.195	  $L	  $hr
node	60058	166.390	  $L	  $hr
node	60059	169.585	  $L	  $hr
node	60060	172.780	  $L	  $hr
node	60061	175.975	  $L	  $hr
node	60062	179.170	  $L	  $hr
node	60063	182.365	  $L	  $hr
node	60064	185.560	  $L	  $hr
node	60065	188.755	  $L	  $hr
node	60066	191.950	  $L	  $hr
node	60067	192.000	  $L	  $hr
node	60068	195.195	  $L	  $hr
node	60069	198.390	  $L	  $hr
node	60070	201.585	  $L	  $hr
node	60071	204.780	  $L	  $hr
node	60072	207.975	  $L	  $hr
node	60073	211.170	  $L	  $hr
node	60074	214.365	  $L	  $hr
node	60075	217.560	  $L	  $hr
node	60076	220.755	  $L	  $hr
node	60077	223.950	  $L	  $hr
node	60078	224.000	  $L	  $hr
node	60079	227.195	  $L	  $hr
node	60080	230.390	  $L	  $hr
node	60081	233.585	  $L	  $hr
node	60082	236.780	  $L	  $hr
node	60083	239.975	  $L	  $hr
node	60084	243.170	  $L	  $hr
node	60085	246.365	  $L	  $hr
node	60086	249.560	  $L	  $hr
node	60087	252.755	  $L	  $hr
node	60088	255.950	  $L	  $hr
node	60089	256.000	  $L	  $hr
node	60090	259.195	  $L	  $hr
node	60091	262.390	  $L	  $hr
node	60092	265.585	  $L	  $hr
node	60093	268.780	  $L	  $hr
node	60094	271.975	  $L	  $hr
node	60095	275.170	  $L	  $hr
node	60096	278.365	  $L	  $hr
node	60097	281.560	  $L	  $hr
node	60098	284.755	  $L	  $hr
node	60099	287.950	  $L	  $hr
node	60100	288.000	  $L	  $hr
node	60101	291.195	  $L	  $hr
node	60102	294.390	  $L	  $hr
node	60103	297.585	  $L	  $hr
node	60104	300.780	  $L	  $hr
node	60105	303.975	  $L	  $hr
node	60106	307.170	  $L	  $hr
node	60107	310.365	  $L	  $hr
node	60108	313.560	  $L	  $hr
node	60109	316.755	  $L	  $hr
node	60110	319.950	  $L	  $hr

# Constraining DOF for Sliding Layer
equalDOF	50001	51001		3	4	5	6
equalDOF	50002	51002	2	3	4	5	6
equalDOF	50003	51003	2	3	4	5	6
equalDOF	50004	51004	2	3	4	5	6
equalDOF	50005	51005	2	3	4	5	6
equalDOF	50006	51006	2	3	4	5	6
equalDOF	50007	51007	2	3	4	5	6
equalDOF	50008	51008	2	3	4	5	6
equalDOF	50009	51009	2	3	4	5	6
equalDOF	50010	51010	2	3	4	5	6
equalDOF	50011	51011		3	4	5	6
equalDOF	50012	51012		3	4	5	6
equalDOF	50013	51013	2	3	4	5	6
equalDOF	50014	51014	2	3	4	5	6
equalDOF	50015	51015	2	3	4	5	6
equalDOF	50016	51016	2	3	4	5	6
equalDOF	50017	51017	2	3	4	5	6
equalDOF	50018	51018	2	3	4	5	6
equalDOF	50019	51019	2	3	4	5	6
equalDOF	50020	51020	2	3	4	5	6
equalDOF	50021	51021	2	3	4	5	6
equalDOF	50022	51022		3	4	5	6
equalDOF	50023	51023		3	4	5	6
equalDOF	50024	51024	2	3	4	5	6
equalDOF	50025	51025	2	3	4	5	6
equalDOF	50026	51026	2	3	4	5	6
equalDOF	50027	51027	2	3	4	5	6
equalDOF	50028	51028	2	3	4	5	6
equalDOF	50029	51029	2	3	4	5	6
equalDOF	50030	51030	2	3	4	5	6
equalDOF	50031	51031	2	3	4	5	6
equalDOF	50032	51032	2	3	4	5	6
equalDOF	50033	51033		3	4	5	6
equalDOF	50034	51034		3	4	5	6
equalDOF	50035	51035	2	3	4	5	6
equalDOF	50036	51036	2	3	4	5	6
equalDOF	50037	51037	2	3	4	5	6
equalDOF	50038	51038	2	3	4	5	6
equalDOF	50039	51039	2	3	4	5	6
equalDOF	50040	51040	2	3	4	5	6
equalDOF	50041	51041	2	3	4	5	6
equalDOF	50042	51042	2	3	4	5	6
equalDOF	50043	51043	2	3	4	5	6
equalDOF	50044	51044		3	4	5	6
equalDOF	50045	51045		3	4	5	6
equalDOF	50046	51046	2	3	4	5	6
equalDOF	50047	51047	2	3	4	5	6
equalDOF	50048	51048	2	3	4	5	6
equalDOF	50049	51049	2	3	4	5	6
equalDOF	50050	51050	2	3	4	5	6
equalDOF	50051	51051	2	3	4	5	6
equalDOF	50052	51052	2	3	4	5	6
equalDOF	50053	51053	2	3	4	5	6
equalDOF	50054	51054	2	3	4	5	6
equalDOF	50055	51055		3	4	5	6
equalDOF	50056	51056		3	4	5	6
equalDOF	50057	51057	2	3	4	5	6
equalDOF	50058	51058	2	3	4	5	6
equalDOF	50059	51059	2	3	4	5	6
equalDOF	50060	51060	2	3	4	5	6
equalDOF	50061	51061	2	3	4	5	6
equalDOF	50062	51062	2	3	4	5	6
equalDOF	50063	51063	2	3	4	5	6
equalDOF	50064	51064	2	3	4	5	6
equalDOF	50065	51065	2	3	4	5	6
equalDOF	50066	51066		3	4	5	6
equalDOF	50067	51067		3	4	5	6
equalDOF	50068	51068	2	3	4	5	6
equalDOF	50069	51069	2	3	4	5	6
equalDOF	50070	51070	2	3	4	5	6
equalDOF	50071	51071	2	3	4	5	6
equalDOF	50072	51072	2	3	4	5	6
equalDOF	50073	51073	2	3	4	5	6
equalDOF	50074	51074	2	3	4	5	6
equalDOF	50075	51075	2	3	4	5	6
equalDOF	50076	51076	2	3	4	5	6
equalDOF	50077	51077		3	4	5	6
equalDOF	50078	51078		3	4	5	6
equalDOF	50079	51079	2	3	4	5	6
equalDOF	50080	51080	2	3	4	5	6
equalDOF	50081	51081	2	3	4	5	6
equalDOF	50082	51082	2	3	4	5	6
equalDOF	50083	51083	2	3	4	5	6
equalDOF	50084	51084	2	3	4	5	6
equalDOF	50085	51085	2	3	4	5	6
equalDOF	50086	51086	2	3	4	5	6
equalDOF	50087	51087	2	3	4	5	6
equalDOF	50088	51088		3	4	5	6
equalDOF	50089	51089		3	4	5	6
equalDOF	50090	51090	2	3	4	5	6
equalDOF	50091	51091	2	3	4	5	6
equalDOF	50092	51092	2	3	4	5	6
equalDOF	50093	51093	2	3	4	5	6
equalDOF	50094	51094	2	3	4	5	6
equalDOF	50095	51095	2	3	4	5	6
equalDOF	50096	51096	2	3	4	5	6
equalDOF	50097	51097	2	3	4	5	6
equalDOF	50098	51098	2	3	4	5	6
equalDOF	50099	51099		3	4	5	6
equalDOF	50100	51100		3	4	5	6
equalDOF	50101	51101	2	3	4	5	6
equalDOF	50102	51102	2	3	4	5	6
equalDOF	50103	51103	2	3	4	5	6
equalDOF	50104	51104	2	3	4	5	6
equalDOF	50105	51105	2	3	4	5	6
equalDOF	50106	51106	2	3	4	5	6
equalDOF	50107	51107	2	3	4	5	6
equalDOF	50108	51108	2	3	4	5	6
equalDOF	50109	51109	2	3	4	5	6
equalDOF	50110	51110		3	4	5	6

equalDOF	60001	61001		3	4	5	6
equalDOF	60002	61002	2	3	4	5	6
equalDOF	60003	61003	2	3	4	5	6
equalDOF	60004	61004	2	3	4	5	6
equalDOF	60005	61005	2	3	4	5	6
equalDOF	60006	61006	2	3	4	5	6
equalDOF	60007	61007	2	3	4	5	6
equalDOF	60008	61008	2	3	4	5	6
equalDOF	60009	61009	2	3	4	5	6
equalDOF	60010	61010	2	3	4	5	6
equalDOF	60011	61011		3	4	5	6
equalDOF	60012	61012		3	4	5	6
equalDOF	60013	61013	2	3	4	5	6
equalDOF	60014	61014	2	3	4	5	6
equalDOF	60015	61015	2	3	4	5	6
equalDOF	60016	61016	2	3	4	5	6
equalDOF	60017	61017	2	3	4	5	6
equalDOF	60018	61018	2	3	4	5	6
equalDOF	60019	61019	2	3	4	5	6
equalDOF	60020	61020	2	3	4	5	6
equalDOF	60021	61021	2	3	4	5	6
equalDOF	60022	61022		3	4	5	6
equalDOF	60023	61023		3	4	5	6
equalDOF	60024	61024	2	3	4	5	6
equalDOF	60025	61025	2	3	4	5	6
equalDOF	60026	61026	2	3	4	5	6
equalDOF	60027	61027	2	3	4	5	6
equalDOF	60028	61028	2	3	4	5	6
equalDOF	60029	61029	2	3	4	5	6
equalDOF	60030	61030	2	3	4	5	6
equalDOF	60031	61031	2	3	4	5	6
equalDOF	60032	61032	2	3	4	5	6
equalDOF	60033	61033		3	4	5	6
equalDOF	60034	61034		3	4	5	6
equalDOF	60035	61035	2	3	4	5	6
equalDOF	60036	61036	2	3	4	5	6
equalDOF	60037	61037	2	3	4	5	6
equalDOF	60038	61038	2	3	4	5	6
equalDOF	60039	61039	2	3	4	5	6
equalDOF	60040	61040	2	3	4	5	6
equalDOF	60041	61041	2	3	4	5	6
equalDOF	60042	61042	2	3	4	5	6
equalDOF	60043	61043	2	3	4	5	6
equalDOF	60044	61044		3	4	5	6
equalDOF	60045	61045		3	4	5	6
equalDOF	60046	61046	2	3	4	5	6
equalDOF	60047	61047	2	3	4	5	6
equalDOF	60048	61048	2	3	4	5	6
equalDOF	60049	61049	2	3	4	5	6
equalDOF	60050	61050	2	3	4	5	6
equalDOF	60051	61051	2	3	4	5	6
equalDOF	60052	61052	2	3	4	5	6
equalDOF	60053	61053	2	3	4	5	6
equalDOF	60054	61054	2	3	4	5	6
equalDOF	60055	61055		3	4	5	6
equalDOF	60056	61056		3	4	5	6
equalDOF	60057	61057	2	3	4	5	6
equalDOF	60058	61058	2	3	4	5	6
equalDOF	60059	61059	2	3	4	5	6
equalDOF	60060	61060	2	3	4	5	6
equalDOF	60061	61061	2	3	4	5	6
equalDOF	60062	61062	2	3	4	5	6
equalDOF	60063	61063	2	3	4	5	6
equalDOF	60064	61064	2	3	4	5	6
equalDOF	60065	61065	2	3	4	5	6
equalDOF	60066	61066		3	4	5	6
equalDOF	60067	61067		3	4	5	6
equalDOF	60068	61068	2	3	4	5	6
equalDOF	60069	61069	2	3	4	5	6
equalDOF	60070	61070	2	3	4	5	6
equalDOF	60071	61071	2	3	4	5	6
equalDOF	60072	61072	2	3	4	5	6
equalDOF	60073	61073	2	3	4	5	6
equalDOF	60074	61074	2	3	4	5	6
equalDOF	60075	61075	2	3	4	5	6
equalDOF	60076	61076	2	3	4	5	6
equalDOF	60077	61077		3	4	5	6
equalDOF	60078	61078		3	4	5	6
equalDOF	60079	61079	2	3	4	5	6
equalDOF	60080	61080	2	3	4	5	6
equalDOF	60081	61081	2	3	4	5	6
equalDOF	60082	61082	2	3	4	5	6
equalDOF	60083	61083	2	3	4	5	6
equalDOF	60084	61084	2	3	4	5	6
equalDOF	60085	61085	2	3	4	5	6
equalDOF	60086	61086	2	3	4	5	6
equalDOF	60087	61087	2	3	4	5	6
equalDOF	60088	61088		3	4	5	6
equalDOF	60089	61089		3	4	5	6
equalDOF	60090	61090	2	3	4	5	6
equalDOF	60091	61091	2	3	4	5	6
equalDOF	60092	61092	2	3	4	5	6
equalDOF	60093	61093	2	3	4	5	6
equalDOF	60094	61094	2	3	4	5	6
equalDOF	60095	61095	2	3	4	5	6
equalDOF	60096	61096	2	3	4	5	6
equalDOF	60097	61097	2	3	4	5	6
equalDOF	60098	61098	2	3	4	5	6
equalDOF	60099	61099		3	4	5	6
equalDOF	60100	61100		3	4	5	6
equalDOF	60101	61101	2	3	4	5	6
equalDOF	60102	61102	2	3	4	5	6
equalDOF	60103	61103	2	3	4	5	6
equalDOF	60104	61104	2	3	4	5	6
equalDOF	60105	61105	2	3	4	5	6
equalDOF	60106	61106	2	3	4	5	6
equalDOF	60107	61107	2	3	4	5	6
equalDOF	60108	61108	2	3	4	5	6
equalDOF	60109	61109	2	3	4	5	6
equalDOF	60110	61110		3	4	5	6


#===========================================================================================================================================================================================
#                TRACK SYSTEM ELEMENTS
#===========================================================================================================================================================================================

#=========================================================
#                TRACK SYSTEM RIGID ELEMENTS
#=========================================================
set geomTransf   1
geomTransf Linear  $geomTransf  0 0 1 
set Ar     1e3
set Ir     1e5
set Er     1e8
set Gr     1e8
set Jr     1e6

# Track Plate to Fastener Connecting Elements 
# 							 eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	      1		52001		10001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn         2		52002		10002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  3		52003		10003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  4		52004		10004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  5		52005		10005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  6		52006		10006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  7		52007		10007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  8		52008		10008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		  9		52009		10009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 10		52010		10010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 11		52011		10011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 12		52012		10012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 13		52013		10013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 14		52014		10014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 15		52015		10015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 16		52016		10016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 17		52017		10017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 18		52018		10018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 19		52019		10019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 20		52020		10020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 21		52021		10021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 22		52022		10022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 23		52023		10023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 24		52024		10024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 25		52025		10025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 26		52026		10026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 27		52027		10027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 28		52028		10028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 29		52029		10029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 30		52030		10030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 31		52031		10031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 32		52032		10032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 33		52033		10033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 34		52034		10034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 35		52035		10035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 36		52036		10036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 37		52037		10037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 38		52038		10038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 39		52039		10039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 40		52040		10040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 41		52041		10041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 42		52042		10042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 43		52043		10043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 44		52044		10044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 45		52045		10045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 46		52046		10046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 47		52047		10047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 48		52048		10048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 49		52049		10049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 50		52050		10050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 51		52051		10051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 52		52052		10052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 53		52053		10053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 54		52054		10054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 55		52055		10055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 56		52056		10056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 57		52057		10057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 58		52058		10058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 59		52059		10059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 60		52060		10060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 61		52061		10061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 62		52062		10062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 63		52063		10063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 64		52064		10064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 65		52065		10065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 66		52066		10066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 67		52067		10067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 68		52068		10068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 69		52069		10069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 70		52070		10070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 71		52071		10071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 72		52072		10072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 73		52073		10073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 74		52074		10074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 75		52075		10075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 76		52076		10076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 77		52077		10077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 78		52078		10078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 79		52079		10079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 80		52080		10080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 81		52081		10081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 82		52082		10082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 83		52083		10083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 84		52084		10084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 85		52085		10085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 86		52086		10086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 87		52087		10087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 88		52088		10088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 89		52089		10089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 90		52090		10090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 91		52091		10091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 92		52092		10092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 93		52093		10093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 94		52094		10094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 95		52095		10095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 96		52096		10096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 97		52097		10097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 98		52098		10098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		 99		52099		10099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		100		52100		10100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		101		52101		10101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		102		52102		10102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		103		52103		10103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		104		52104		10104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		105		52105		10105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		106		52106		10106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		107		52107		10107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		108		52108		10108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		109		52109		10109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		110		52110		10110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

element	elasticBeamColumn		111		20001		52001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		112		20002		52002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		113		20003		52003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		114		20004		52004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		115		20005		52005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		116		20006		52006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		117		20007		52007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		118		20008		52008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		119		20009		52009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		120		20010		52010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		121		20011		52011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		122		20012		52012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		123		20013		52013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		124		20014		52014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		125		20015		52015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		126		20016		52016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		127		20017		52017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		128		20018		52018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		129		20019		52019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		130		20020		52020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		131		20021		52021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		132		20022		52022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		133		20023		52023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		134		20024		52024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		135		20025		52025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		136		20026		52026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		137		20027		52027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		138		20028		52028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		139		20029		52029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		140		20030		52030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		141		20031		52031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		142		20032		52032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		143		20033		52033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		144		20034		52034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		145		20035		52035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		146		20036		52036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		147		20037		52037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		148		20038		52038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		149		20039		52039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		150		20040		52040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		151		20041		52041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		152		20042		52042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		153		20043		52043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		154		20044		52044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		155		20045		52045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		156		20046		52046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		157		20047		52047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		158		20048		52048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		159		20049		52049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		160		20050		52050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		161		20051		52051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		162		20052		52052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		163		20053		52053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		164		20054		52054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		165		20055		52055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		166		20056		52056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		167		20057		52057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		168		20058		52058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		169		20059		52059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		170		20060		52060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		171		20061		52061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		172		20062		52062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		173		20063		52063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		174		20064		52064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		175		20065		52065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		176		20066		52066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		177		20067		52067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		178		20068		52068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		179		20069		52069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		180		20070		52070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		181		20071		52071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		182		20072		52072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		183		20073		52073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		184		20074		52074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		185		20075		52075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		186		20076		52076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		187		20077		52077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		188		20078		52078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		189		20079		52079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		190		20080		52080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		191		20081		52081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		192		20082		52082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		193		20083		52083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		194		20084		52084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		195		20085		52085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		196		20086		52086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		197		20087		52087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		198		20088		52088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		199		20089		52089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		200		20090		52090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		201		20091		52091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		202		20092		52092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		203		20093		52093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		204		20094		52094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		205		20095		52095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		206		20096		52096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		207		20097		52097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		208		20098		52098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		209		20099		52099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		210		20100		52100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		211		20101		52101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		212		20102		52102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		213		20103		52103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		214		20104		52104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		215		20105		52105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		216		20106		52106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		217		20107		52107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		218		20108		52108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		219		20109		52109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		220		20110		52110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

element	elasticBeamColumn		221		62001		30001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		222		62002		30002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		223		62003		30003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		224		62004		30004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		225		62005		30005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		226		62006		30006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		227		62007		30007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		228		62008		30008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		229		62009		30009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		230		62010		30010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		231		62011		30011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		232		62012		30012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		233		62013		30013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		234		62014		30014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		235		62015		30015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		236		62016		30016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		237		62017		30017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		238		62018		30018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		239		62019		30019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		240		62020		30020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		241		62021		30021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		242		62022		30022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		243		62023		30023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		244		62024		30024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		245		62025		30025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		246		62026		30026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		247		62027		30027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		248		62028		30028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		249		62029		30029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		250		62030		30030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		251		62031		30031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		252		62032		30032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		253		62033		30033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		254		62034		30034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		255		62035		30035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		256		62036		30036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		257		62037		30037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		258		62038		30038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		259		62039		30039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		260		62040		30040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		261		62041		30041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		262		62042		30042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		263		62043		30043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		264		62044		30044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		265		62045		30045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		266		62046		30046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		267		62047		30047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		268		62048		30048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		269		62049		30049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		270		62050		30050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		271		62051		30051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		272		62052		30052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		273		62053		30053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		274		62054		30054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		275		62055		30055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		276		62056		30056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		277		62057		30057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		278		62058		30058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		279		62059		30059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		280		62060		30060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		281		62061		30061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		282		62062		30062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		283		62063		30063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		284		62064		30064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		285		62065		30065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		286		62066		30066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		287		62067		30067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		288		62068		30068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		289		62069		30069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		290		62070		30070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		291		62071		30071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		292		62072		30072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		293		62073		30073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		294		62074		30074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		295		62075		30075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		296		62076		30076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		297		62077		30077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		298		62078		30078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		299		62079		30079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		300		62080		30080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		301		62081		30081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		302		62082		30082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		303		62083		30083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		304		62084		30084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		305		62085		30085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		306		62086		30086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		307		62087		30087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		308		62088		30088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		309		62089		30089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		310		62090		30090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		311		62091		30091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		312		62092		30092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		313		62093		30093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		314		62094		30094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		315		62095		30095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		316		62096		30096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		317		62097		30097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		318		62098		30098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		319		62099		30099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		320		62100		30100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		321		62101		30101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		322		62102		30102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		323		62103		30103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		324		62104		30104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		325		62105		30105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		326		62106		30106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		327		62107		30107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		328		62108		30108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		329		62109		30109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		330		62110		30110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

element	elasticBeamColumn		331		40001		62001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		332		40002		62002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		333		40003		62003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		334		40004		62004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		335		40005		62005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		336		40006		62006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		337		40007		62007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		338		40008		62008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		339		40009		62009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		340		40010		62010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		341		40011		62011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		342		40012		62012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		343		40013		62013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		344		40014		62014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		345		40015		62015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		346		40016		62016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		347		40017		62017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		348		40018		62018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		349		40019		62019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		350		40020		62020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		351		40021		62021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		352		40022		62022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		353		40023		62023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		354		40024		62024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		355		40025		62025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		356		40026		62026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		357		40027		62027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		358		40028		62028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		359		40029		62029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		360		40030		62030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		361		40031		62031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		362		40032		62032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		363		40033		62033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		364		40034		62034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		365		40035		62035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		366		40036		62036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		367		40037		62037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		368		40038		62038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		369		40039		62039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		370		40040		62040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		371		40041		62041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		372		40042		62042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		373		40043		62043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		374		40044		62044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		375		40045		62045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		376		40046		62046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		377		40047		62047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		378		40048		62048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		379		40049		62049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		380		40050		62050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		381		40051		62051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		382		40052		62052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		383		40053		62053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		384		40054		62054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		385		40055		62055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		386		40056		62056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		387		40057		62057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		388		40058		62058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		389		40059		62059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		390		40060		62060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		391		40061		62061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		392		40062		62062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		393		40063		62063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		394		40064		62064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		395		40065		62065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		396		40066		62066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		397		40067		62067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		398		40068		62068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		399		40069		62069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		400		40070		62070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		401		40071		62071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		402		40072		62072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		403		40073		62073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		404		40074		62074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		405		40075		62075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		406		40076		62076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		407		40077		62077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		408		40078		62078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		409		40079		62079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		410		40080		62080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		411		40081		62081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		412		40082		62082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		413		40083		62083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		414		40084		62084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		415		40085		62085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		416		40086		62086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		417		40087		62087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		418		40088		62088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		419		40089		62089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		420		40090		62090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		421		40091		62091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		422		40092		62092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		423		40093		62093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		424		40094		62094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		425		40095		62095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		426		40096		62096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		427		40097		62097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		428		40098		62098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		429		40099		62099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		430		40100		62100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		431		40101		62101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		432		40102		62102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		433		40103		62103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		434		40104		62104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		435		40105		62105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		436		40106		62106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		437		40107		62107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		438		40108		62108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		439		40109		62109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn		440		40110		62110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf


#=========================================================
#                  BASE PLATE ELEMENTS
#=========================================================
# Base Plate
set geomTransf   2
geomTransf Linear $geomTransf 0 1 0  
set Abp   5.61e-1
set Izbp  1.69e-3
set Iybp  4.06e-1
set Jbp   6.74e-3
set Gbp   1.25e7
set Ebp   3.00e7

# 							  eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn 		441			51001		51002		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		442			51002		51003		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		443			51003		51004		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		444			51004		51005		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		445			51005		51006		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		446			51006		51007		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		447			51007		51008		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		448			51008		51009		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		449			51009		51010		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		450			51010		51011		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		451			51011		51012		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		452			51012		51013		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		453			51013		51014		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		454			51014		51015		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		455			51015		51016		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		456			51016		51017		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		457			51017		51018		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		458			51018		51019		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		459			51019		51020		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		460			51020		51021		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		461			51021		51022		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		462			51022		51023		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		463			51023		51024		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		464			51024		51025		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		465			51025		51026		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		466			51026		51027		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		467			51027		51028		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		468			51028		51029		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		469			51029		51030		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		470			51030		51031		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		471			51031		51032		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		472			51032		51033		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		473			51033		51034		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		474			51034		51035		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		475			51035		51036		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		476			51036		51037		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		477			51037		51038		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		478			51038		51039		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		479			51039		51040		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		480			51040		51041		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		481			51041		51042		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		482			51042		51043		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		483			51043		51044		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		484			51044		51045		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		485			51045		51046		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		486			51046		51047		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		487			51047		51048		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		488			51048		51049		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		489			51049		51050		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		490			51050		51051		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		491			51051		51052		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		492			51052		51053		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		493			51053		51054		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		494			51054		51055		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		495			51055		51056		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		496			51056		51057		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		497			51057		51058		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		498			51058		51059		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		499			51059		51060		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		500			51060		51061		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		501			51061		51062		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		502			51062		51063		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		503			51063		51064		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		504			51064		51065		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		505			51065		51066		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		506			51066		51067		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		507			51067		51068		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		508			51068		51069		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		509			51069		51070		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		510			51070		51071		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		511			51071		51072		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		512			51072		51073		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		513			51073		51074		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		514			51074		51075		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		515			51075		51076		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		516			51076		51077		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		517			51077		51078		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		518			51078		51079		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		519			51079		51080		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		520			51080		51081		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		521			51081		51082		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		522			51082		51083		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		523			51083		51084		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		524			51084		51085		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		525			51085		51086		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		526			51086		51087		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		527			51087		51088		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		528			51088		51089		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		529			51089		51090		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		530			51090		51091		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		531			51091		51092		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		532			51092		51093		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		533			51093		51094		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		534			51094		51095		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		535			51095		51096		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		536			51096		51097		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		537			51097		51098		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		538			51098		51099		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		539			51099		51100		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		540			51100		51101		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		541			51101		51102		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		542			51102		51103		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		543			51103		51104		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		544			51104		51105		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		545			51105		51106		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		546			51106		51107		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		547			51107		51108		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		548			51108		51109		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		549			51109		51110		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf

element	elasticBeamColumn		550			61001		61002		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		551			61002		61003		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		552			61003		61004		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		553			61004		61005		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		554			61005		61006		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		555			61006		61007		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		556			61007		61008		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		557			61008		61009		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		558			61009		61010		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		559			61010		61011		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		560			61011		61012		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		561			61012		61013		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		562			61013		61014		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		563			61014		61015		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		564			61015		61016		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		565			61016		61017		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		566			61017		61018		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		567			61018		61019		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		568			61019		61020		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		569			61020		61021		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		570			61021		61022		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		571			61022		61023		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		572			61023		61024		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		573			61024		61025		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		574			61025		61026		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		575			61026		61027		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		576			61027		61028		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		577			61028		61029		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		578			61029		61030		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		579			61030		61031		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		580			61031		61032		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		581			61032		61033		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		582			61033		61034		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		583			61034		61035		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		584			61035		61036		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		585			61036		61037		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		586			61037		61038		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		587			61038		61039		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		588			61039		61040		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		589			61040		61041		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		590			61041		61042		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		591			61042		61043		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		592			61043		61044		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		593			61044		61045		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		594			61045		61046		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		595			61046		61047		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		596			61047		61048		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		597			61048		61049		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		598			61049		61050		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		599			61050		61051		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		600			61051		61052		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		601			61052		61053		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		602			61053		61054		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		603			61054		61055		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		604			61055		61056		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		605			61056		61057		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		606			61057		61058		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		607			61058		61059		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		608			61059		61060		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		609			61060		61061		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		610			61061		61062		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		611			61062		61063		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		612			61063		61064		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		613			61064		61065		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		614			61065		61066		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		615			61066		61067		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		616			61067		61068		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		617			61068		61069		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		618			61069		61070		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		619			61070		61071		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		620			61071		61072		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		621			61072		61073		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		622			61073		61074		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		623			61074		61075		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		624			61075		61076		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		625			61076		61077		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		626			61077		61078		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		627			61078		61079		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		628			61079		61080		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		629			61080		61081		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		630			61081		61082		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		631			61082		61083		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		632			61083		61084		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		633			61084		61085		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		634			61085		61086		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		635			61086		61087		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		636			61087		61088		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		637			61088		61089		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		638			61089		61090		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		639			61090		61091		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		640			61091		61092		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		641			61092		61093		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		642			61093		61094		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		643			61094		61095		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		644			61095		61096		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		645			61096		61097		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		646			61097		61098		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		647			61098		61099		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		648			61099		61100		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		649			61100		61101		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		650			61101		61102		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		651			61102		61103		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		652			61103		61104		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		653			61104		61105		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		654			61105		61106		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		655			61106		61107		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		656			61107		61108		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		657			61108		61109		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf
element	elasticBeamColumn		658			61109		61110		$Abp	$Ebp	$Gbp	$Jbp	$Iybp	$Izbp	$geomTransf


#=========================================================
#                  TRACK PLATE ELEMENTS
#=========================================================
# Track Plate
set geomTransf   3
geomTransf Linear $geomTransf 0 0 1  
set Atp   5.10e-1
set Iztp  1.70e3
set Iytp  2.76e-1
set Jtp   6.8e-3
set Gtp   1.48e7
set Etp   3.55e7

# 							  eleTag	iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn		659		52001		52002		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		660		52002		52003		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		661		52003		52004		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		662		52004		52005		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		663		52005		52006		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		664		52006		52007		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		665		52007		52008		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		666		52008		52009		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		667		52009		52010		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		668		52010		52011		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		669		52011		52012		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		670		52012		52013		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		671		52013		52014		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		672		52014		52015		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		673		52015		52016		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		674		52016		52017		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		675		52017		52018		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		676		52018		52019		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		677		52019		52020		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		678		52020		52021		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		679		52021		52022		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		680		52022		52023		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		681		52023		52024		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		682		52024		52025		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		683		52025		52026		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		684		52026		52027		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		685		52027		52028		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		686		52028		52029		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		687		52029		52030		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		688		52030		52031		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		689		52031		52032		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		690		52032		52033		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		691		52033		52034		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		692		52034		52035		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		693		52035		52036		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		694		52036		52037		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		695		52037		52038		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		696		52038		52039		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		697		52039		52040		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		698		52040		52041		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		699		52041		52042		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		700		52042		52043		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		701		52043		52044		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		702		52044		52045		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		703		52045		52046		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		704		52046		52047		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		705		52047		52048		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		706		52048		52049		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		707		52049		52050		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		708		52050		52051		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		709		52051		52052		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		710		52052		52053		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		711		52053		52054		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		712		52054		52055		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		713		52055		52056		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		714		52056		52057		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		715		52057		52058		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		716		52058		52059		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		717		52059		52060		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		718		52060		52061		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		719		52061		52062		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		720		52062		52063		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		721		52063		52064		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		722		52064		52065		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		723		52065		52066		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		724		52066		52067		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		725		52067		52068		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		726		52068		52069		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		727		52069		52070		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		728		52070		52071		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		729		52071		52072		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		730		52072		52073		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		731		52073		52074		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		732		52074		52075		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		733		52075		52076		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		734		52076		52077		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		735		52077		52078		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		736		52078		52079		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		737		52079		52080		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		738		52080		52081		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		739		52081		52082		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		740		52082		52083		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		741		52083		52084		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		742		52084		52085		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		743		52085		52086		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		744		52086		52087		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		745		52087		52088		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		746		52088		52089		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		747		52089		52090		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		748		52090		52091		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		749		52091		52092		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		750		52092		52093		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		751		52093		52094		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		752		52094		52095		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		753		52095		52096		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		754		52096		52097		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		755		52097		52098		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		756		52098		52099		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		757		52099		52100		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		758		52100		52101		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		759		52101		52102		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		760		52102		52103		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		761		52103		52104		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		762		52104		52105		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		763		52105		52106		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		764		52106		52107		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		765		52107		52108		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		766		52108		52109		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		767		52109		52110		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf

element	elasticBeamColumn		768		62001		62002		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		769		62002		62003		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		770		62003		62004		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		771		62004		62005		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		772		62005		62006		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		773		62006		62007		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		774		62007		62008		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		775		62008		62009		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		776		62009		62010		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		777		62010		62011		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		778		62011		62012		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		779		62012		62013		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		780		62013		62014		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		781		62014		62015		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		782		62015		62016		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		783		62016		62017		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		784		62017		62018		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		785		62018		62019		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		786		62019		62020		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		787		62020		62021		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		788		62021		62022		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		789		62022		62023		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		790		62023		62024		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		791		62024		62025		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		792		62025		62026		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		793		62026		62027		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		794		62027		62028		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		795		62028		62029		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		796		62029		62030		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		797		62030		62031		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		798		62031		62032		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		799		62032		62033		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		800		62033		62034		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		801		62034		62035		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		802		62035		62036		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		803		62036		62037		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		804		62037		62038		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		805		62038		62039		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		806		62039		62040		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		807		62040		62041		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		808		62041		62042		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		809		62042		62043		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		810		62043		62044		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		811		62044		62045		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		812		62045		62046		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		813		62046		62047		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		814		62047		62048		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		815		62048		62049		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		816		62049		62050		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		817		62050		62051		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		818		62051		62052		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		819		62052		62053		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		820		62053		62054		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		821		62054		62055		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		822		62055		62056		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		823		62056		62057		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		824		62057		62058		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		825		62058		62059		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		826		62059		62060		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		827		62060		62061		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		828		62061		62062		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		829		62062		62063		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		830		62063		62064		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		831		62064		62065		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		832		62065		62066		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		833		62066		62067		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		834		62067		62068		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		835		62068		62069		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		836		62069		62070		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		837		62070		62071		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		838		62071		62072		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		839		62072		62073		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		840		62073		62074		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		841		62074		62075		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		842		62075		62076		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		843		62076		62077		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		844		62077		62078		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		845		62078		62079		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		846		62079		62080		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		847		62080		62081		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		848		62081		62082		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		849		62082		62083		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		850		62083		62084		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		851		62084		62085		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		852		62085		62086		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		853		62086		62087		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		854		62087		62088		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		855		62088		62089		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		856		62089		62090		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		857		62090		62091		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		858		62091		62092		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		859		62092		62093		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		860		62093		62094		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		861		62094		62095		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		862		62095		62096		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		863		62096		62097		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		864		62097		62098		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		865		62098		62099		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		866		62099		62100		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		867		62100		62101		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		868		62101		62102		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		869		62102		62103		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		870		62103		62104		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		871		62104		62105		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		872		62105		62106		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		873		62106		62107		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		874		62107		62108		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		875		62108		62109		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf
element	elasticBeamColumn		876		62109		62110		$Atp	$Etp	$Gtp	$Jtp	$Iytp	$Iztp	$geomTransf


#=========================================================
#                  RAIL ELEMENTS
#=========================================================
# Rail
set geomTransf   4
geomTransf Linear $geomTransf 0 1 0  
set Ar   7.75e-3
set Izr  3.20e-5
set Iyr  5e-6
set Jr   2e-6
set Gr   8.05e6
set Er   2.06e8

# 							   eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn		9000		31001		31002		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9001		31002		31003		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9002		31003		31004		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9003		31004		31005		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9004		31005		31006		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9005		31006		31007		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9006		31007		31008		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9007		31008		31009		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9008		31009		31010		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9009		31010		31011		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9010		31011		31012		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9011		31012		31013		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9012		31013		31014		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9013		31014		31015		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9014		31015		31016		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9015		31016		31017		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9016		31017		31018		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9017		31018		31019		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9018		31019		31020		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9019		31020		31021		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9020		31021		31022		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9021		31022		31023		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9022		31023		31024		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9023		31024		31025		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9024		31025		31026		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9025		31026		31027		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9026		31027		31028		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9027		31028		31029		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9028		31029		31030		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9029		31030		31031		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9030		31031		31032		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9031		31032		31033		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9032		31033		31034		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9033		31034		31035		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9034		31035		31036		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9035		31036		31037		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9036		31037		31038		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9037		31038		31039		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9038		31039		31040		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9039		31040		31041		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9040		31041		31042		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9041		31042		31043		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9042		31043		31044		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9043		31044		31045		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9044		31045		31046		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9045		31046		31047		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9046		31047		31048		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9047		31048		31049		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9048		31049		31050		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9049		31050		31051		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9050		31051		31052		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9051		31052		31053		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9052		31053		31054		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9053		31054		31055		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9054		31055		31056		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9055		31056		31057		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9056		31057		31058		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9057		31058		31059		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9058		31059		31060		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9059		31060		31061		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9060		31061		31062		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9061		31062		31063		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9062		31063		31064		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9063		31064		31065		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9064		31065		31066		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9065		31066		31067		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9066		31067		31068		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9067		31068		31069		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9068		31069		31070		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9069		31070		31071		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9070		31071		31072		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9071		31072		31073		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9072		31073		31074		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9073		31074		31075		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9074		31075		31076		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9075		31076		31077		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9076		31077		31078		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9077		31078		31079		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9078		31079		31080		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9079		31080		31081		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9080		31081		31082		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9081		31082		31083		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9082		31083		31084		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9083		31084		31085		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9084		31085		31086		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9085		31086		31087		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9086		31087		31088		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9087		31088		31089		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9088		31089		31090		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9089		31090		31091		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9090		31091		31092		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9091		31092		31093		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9092		31093		31094		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9093		31094		31095		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9094		31095		31096		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9095		31096		31097		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9096		31097		31098		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9097		31098		31099		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9098		31099		31100		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9099		31100		31101		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9100		31101		31102		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9101		31102		31103		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9102		31103		31104		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9103		31104		31105		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9104		31105		31106		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9105		31106		31107		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9106		31107		31108		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9107		31108		31109		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9108		31109		31110		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf

element	elasticBeamColumn		9109		41001		41002		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9110		41002		41003		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9111		41003		41004		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9112		41004		41005		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9113		41005		41006		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9114		41006		41007		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9115		41007		41008		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9116		41008		41009		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9117		41009		41010		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9118		41010		41011		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9119		41011		41012		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9120		41012		41013		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9121		41013		41014		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9122		41014		41015		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9123		41015		41016		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9124		41016		41017		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9125		41017		41018		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9126		41018		41019		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9127		41019		41020		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9128		41020		41021		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9129		41021		41022		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9130		41022		41023		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9131		41023		41024		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9132		41024		41025		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9133		41025		41026		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9134		41026		41027		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9135		41027		41028		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9136		41028		41029		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9137		41029		41030		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9138		41030		41031		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9139		41031		41032		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9140		41032		41033		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9141		41033		41034		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9142		41034		41035		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9143		41035		41036		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9144		41036		41037		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9145		41037		41038		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9146		41038		41039		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9147		41039		41040		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9148		41040		41041		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9149		41041		41042		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9150		41042		41043		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9151		41043		41044		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9152		41044		41045		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9153		41045		41046		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9154		41046		41047		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9155		41047		41048		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9156		41048		41049		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9157		41049		41050		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9158		41050		41051		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9159		41051		41052		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9160		41052		41053		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9161		41053		41054		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9162		41054		41055		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9163		41055		41056		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9164		41056		41057		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9165		41057		41058		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9166		41058		41059		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9167		41059		41060		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9168		41060		41061		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9169		41061		41062		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9170		41062		41063		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9171		41063		41064		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9172		41064		41065		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9173		41065		41066		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9174		41066		41067		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9175		41067		41068		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9176		41068		41069		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9177		41069		41070		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9178		41070		41071		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9179		41071		41072		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9180		41072		41073		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9181		41073		41074		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9182		41074		41075		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9183		41075		41076		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9184		41076		41077		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9185		41077		41078		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9186		41078		41079		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9187		41079		41080		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9188		41080		41081		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9189		41081		41082		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9190		41082		41083		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9191		41083		41084		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9192		41084		41085		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9193		41085		41086		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9194		41086		41087		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9195		41087		41088		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9196		41088		41089		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9197		41089		41090		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9198		41090		41091		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9199		41091		41092		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9200		41092		41093		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9201		41093		41094		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9202		41094		41095		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9203		41095		41096		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9204		41096		41097		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9205		41097		41098		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9206		41098		41099		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9207		41099		41100		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9208		41100		41101		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9209		41101		41102		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9210		41102		41103		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9211		41103		41104		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9212		41104		41105		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9213		41105		41106		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9214		41106		41107		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9215		41107		41108		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9216		41108		41109		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf
element	elasticBeamColumn		9217		41109		41110		$Ar		$Er		$Gr	 	$Jr     $Iyr     $Izr	$geomTransf


#===========================================================================================================================================================================================
#                  TRACK ZERO LENGTH ELEMENTS
#===========================================================================================================================================================================================
#=========================================================
#                  SLIDING LAYER ELEMENTS
#=========================================================
# Sliding Layer
set Fys   6
set dys   0.0005
set K1s  [expr $Fys/$dys]

uniaxialMaterial Steel01 700 $Fys $K1s 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element	zeroLength		877		50001	51001	  -mat	700	        -dir  1	 
element	zeroLength	    878		50002	51002	  -mat	700	        -dir  1	 
element	zeroLength		879		50003	51003	  -mat	700	        -dir  1	
element	zeroLength		880		50004	51004	  -mat	700	        -dir  1	
element	zeroLength		881		50005	51005	  -mat	700	        -dir  1	
element	zeroLength		882		50006	51006	  -mat	700	        -dir  1	
element	zeroLength		883		50007	51007	  -mat	700	        -dir  1	
element	zeroLength		884		50008	51008	  -mat	700	        -dir  1	
element	zeroLength		885		50009	51009	  -mat	700	        -dir  1	
element	zeroLength		886		50010	51010	  -mat	700	        -dir  1	
element	zeroLength		887		50011	51011	  -mat	700	        -dir  1	
element	zeroLength		888		50012	51012	  -mat	700	        -dir  1	
element	zeroLength		889		50013	51013	  -mat	700	        -dir  1	
element	zeroLength		890		50014	51014	  -mat	700	        -dir  1	
element	zeroLength		891		50015	51015	  -mat	700	        -dir  1	
element	zeroLength		892		50016	51016	  -mat	700	        -dir  1	
element	zeroLength		893		50017	51017	  -mat	700	        -dir  1	
element	zeroLength		894		50018	51018	  -mat	700	        -dir  1	
element	zeroLength		895		50019	51019	  -mat	700	        -dir  1	
element	zeroLength		896		50020	51020	  -mat	700	        -dir  1	
element	zeroLength		897		50021	51021	  -mat	700	        -dir  1	
element	zeroLength		898		50022	51022	  -mat	700	        -dir  1	
element	zeroLength		899		50023	51023	  -mat	700	        -dir  1	
element	zeroLength		900		50024	51024	  -mat	700	        -dir  1	
element	zeroLength		901		50025	51025	  -mat	700	        -dir  1	
element	zeroLength		902		50026	51026	  -mat	700	        -dir  1	
element	zeroLength		903		50027	51027	  -mat	700	        -dir  1	
element	zeroLength		904		50028	51028	  -mat	700	        -dir  1	
element	zeroLength		905		50029	51029	  -mat	700	        -dir  1	
element	zeroLength		906		50030	51030	  -mat	700	        -dir  1	
element	zeroLength		907		50031	51031	  -mat	700	        -dir  1	
element	zeroLength		908		50032	51032	  -mat	700	        -dir  1	
element	zeroLength		909		50033	51033	  -mat	700	        -dir  1	
element	zeroLength		910		50034	51034	  -mat	700	        -dir  1	
element	zeroLength		911		50035	51035	  -mat	700	        -dir  1	
element	zeroLength		912		50036	51036	  -mat	700	        -dir  1	
element	zeroLength		913		50037	51037	  -mat	700	        -dir  1	
element	zeroLength		914		50038	51038	  -mat	700	        -dir  1	
element	zeroLength		915		50039	51039	  -mat	700	        -dir  1	
element	zeroLength		916		50040	51040	  -mat	700	        -dir  1	
element	zeroLength		917		50041	51041	  -mat	700	        -dir  1	
element	zeroLength		918		50042	51042	  -mat	700	        -dir  1	
element	zeroLength		919		50043	51043	  -mat	700	        -dir  1	
element	zeroLength		920		50044	51044	  -mat	700	        -dir  1	
element	zeroLength		921		50045	51045	  -mat	700	        -dir  1	
element	zeroLength		922		50046	51046	  -mat	700	        -dir  1	
element	zeroLength		923		50047	51047	  -mat	700	        -dir  1	
element	zeroLength		924		50048	51048	  -mat	700	        -dir  1	
element	zeroLength		925		50049	51049	  -mat	700	        -dir  1	
element	zeroLength		926		50050	51050	  -mat	700	        -dir  1	
element	zeroLength		927		50051	51051	  -mat	700	        -dir  1	
element	zeroLength		928		50052	51052	  -mat	700	        -dir  1	
element	zeroLength		929		50053	51053	  -mat	700	        -dir  1	
element	zeroLength		930		50054	51054	  -mat	700	        -dir  1	
element	zeroLength		931		50055	51055	  -mat	700	        -dir  1	
element	zeroLength		932		50056	51056	  -mat	700	        -dir  1	
element	zeroLength		933		50057	51057	  -mat	700	        -dir  1	
element	zeroLength		934		50058	51058	  -mat	700	        -dir  1	
element	zeroLength		935		50059	51059	  -mat	700	        -dir  1	
element	zeroLength		936		50060	51060	  -mat	700	        -dir  1	
element	zeroLength		937		50061	51061	  -mat	700	        -dir  1	
element	zeroLength		938		50062	51062	  -mat	700	        -dir  1	
element	zeroLength		939		50063	51063	  -mat	700	        -dir  1	
element	zeroLength		940		50064	51064	  -mat	700	        -dir  1	
element	zeroLength		941		50065	51065	  -mat	700	        -dir  1	
element	zeroLength		942		50066	51066	  -mat	700	        -dir  1	
element	zeroLength		943		50067	51067	  -mat	700	        -dir  1	
element	zeroLength		944		50068	51068	  -mat	700	        -dir  1	
element	zeroLength		945		50069	51069	  -mat	700	        -dir  1	
element	zeroLength		946		50070	51070	  -mat	700	        -dir  1	
element	zeroLength		947		50071	51071	  -mat	700	        -dir  1	
element	zeroLength		948		50072	51072	  -mat	700	        -dir  1	
element	zeroLength		949		50073	51073	  -mat	700	        -dir  1	
element	zeroLength		950		50074	51074	  -mat	700	        -dir  1	
element	zeroLength		951		50075	51075	  -mat	700	        -dir  1	
element	zeroLength		952		50076	51076	  -mat	700	        -dir  1	
element	zeroLength		953		50077	51077	  -mat	700	        -dir  1	
element	zeroLength		954		50078	51078	  -mat	700	        -dir  1	
element	zeroLength		955		50079	51079	  -mat	700	        -dir  1	
element	zeroLength		956		50080	51080	  -mat	700	        -dir  1	
element	zeroLength		957		50081	51081	  -mat	700	        -dir  1	
element	zeroLength		958		50082	51082	  -mat	700	        -dir  1	
element	zeroLength		959		50083	51083	  -mat	700	        -dir  1	
element	zeroLength		960		50084	51084	  -mat	700	        -dir  1	
element	zeroLength		961		50085	51085	  -mat	700	        -dir  1	
element	zeroLength		962		50086	51086	  -mat	700	        -dir  1	
element	zeroLength		963		50087	51087	  -mat	700	        -dir  1	
element	zeroLength		964		50088	51088	  -mat	700	        -dir  1	
element	zeroLength		965		50089	51089	  -mat	700	        -dir  1	
element	zeroLength		966		50090	51090	  -mat	700	        -dir  1	
element	zeroLength		967		50091	51091	  -mat	700	        -dir  1	
element	zeroLength		968		50092	51092	  -mat	700	        -dir  1	
element	zeroLength		969		50093	51093	  -mat	700	        -dir  1	
element	zeroLength		970		50094	51094	  -mat	700	        -dir  1	
element	zeroLength		971		50095	51095	  -mat	700	        -dir  1	
element	zeroLength		972		50096	51096	  -mat	700	        -dir  1	
element	zeroLength		973		50097	51097	  -mat	700	        -dir  1	
element	zeroLength		974		50098	51098	  -mat	700	        -dir  1	
element	zeroLength		975		50099	51099	  -mat	700	        -dir  1	
element	zeroLength		976		50100	51100	  -mat	700	        -dir  1	
element	zeroLength		977		50101	51101	  -mat	700	        -dir  1	
element	zeroLength		978		50102	51102	  -mat	700	        -dir  1	
element	zeroLength		979		50103	51103	  -mat	700	        -dir  1	
element	zeroLength		980		50104	51104	  -mat	700	        -dir  1	
element	zeroLength		981		50105	51105	  -mat	700	        -dir  1	
element	zeroLength		982		50106	51106	  -mat	700	        -dir  1	
element	zeroLength		983		50107	51107	  -mat	700	        -dir  1	
element	zeroLength		984		50108	51108	  -mat	700	        -dir  1	
element	zeroLength		985		50109	51109	  -mat	700	        -dir  1	
element	zeroLength		986		50110	51110	  -mat	700	        -dir  1	

element	zeroLength		987		60001	61001	  -mat	700	        -dir  1	
element	zeroLength		988		60002	61002	  -mat	700	        -dir  1	
element	zeroLength		989		60003	61003	  -mat	700	        -dir  1	
element	zeroLength		990		60004	61004	  -mat	700	        -dir  1	
element	zeroLength		991		60005	61005	  -mat	700	        -dir  1	
element	zeroLength		992		60006	61006	  -mat	700	        -dir  1	
element	zeroLength		993		60007	61007	  -mat	700	        -dir  1	
element	zeroLength		994		60008	61008	  -mat	700	        -dir  1	
element	zeroLength		995		60009	61009	  -mat	700	        -dir  1	
element	zeroLength		996		60010	61010	  -mat	700	        -dir  1	
element	zeroLength		997		60011	61011	  -mat	700	        -dir  1	
element	zeroLength		998		60012	61012	  -mat	700	        -dir  1	
element	zeroLength		999		60013	61013	  -mat	700	        -dir  1	
element	zeroLength		1000	60014	61014	  -mat	700	        -dir  1	
element	zeroLength		1001	60015	61015	  -mat	700	        -dir  1	
element	zeroLength		1002	60016	61016	  -mat	700	        -dir  1	
element	zeroLength		1003	60017	61017	  -mat	700	        -dir  1	
element	zeroLength		1004	60018	61018	  -mat	700	        -dir  1	
element	zeroLength		1005	60019	61019	  -mat	700	        -dir  1	
element	zeroLength		1006	60020	61020	  -mat	700	        -dir  1	
element	zeroLength		1007	60021	61021	  -mat	700	        -dir  1	
element	zeroLength		1008	60022	61022	  -mat	700	        -dir  1	
element	zeroLength		1009	60023	61023	  -mat	700	        -dir  1	
element	zeroLength		1010	60024	61024	  -mat	700	        -dir  1	
element	zeroLength		1011	60025	61025	  -mat	700	        -dir  1	
element	zeroLength		1012	60026	61026	  -mat	700	        -dir  1	
element	zeroLength		1013	60027	61027	  -mat	700	        -dir  1	
element	zeroLength		1014	60028	61028	  -mat	700	        -dir  1	
element	zeroLength		1015	60029	61029	  -mat	700	        -dir  1	
element	zeroLength		1016	60030	61030	  -mat	700	        -dir  1	
element	zeroLength		1017	60031	61031	  -mat	700	        -dir  1	
element	zeroLength		1018	60032	61032	  -mat	700	        -dir  1	
element	zeroLength		1019	60033	61033	  -mat	700	        -dir  1	
element	zeroLength		1020	60034	61034	  -mat	700	        -dir  1	
element	zeroLength		1021	60035	61035	  -mat	700	        -dir  1	
element	zeroLength		1022	60036	61036	  -mat	700	        -dir  1	
element	zeroLength		1023	60037	61037	  -mat	700	        -dir  1	
element	zeroLength		1024	60038	61038	  -mat	700	        -dir  1	
element	zeroLength		1025	60039	61039	  -mat	700	        -dir  1	
element	zeroLength		1026	60040	61040	  -mat	700	        -dir  1	
element	zeroLength		1027	60041	61041	  -mat	700	        -dir  1	
element	zeroLength		1028	60042	61042	  -mat	700	        -dir  1	
element	zeroLength		1029	60043	61043	  -mat	700	        -dir  1	
element	zeroLength		1030	60044	61044	  -mat	700	        -dir  1	
element	zeroLength		1031	60045	61045	  -mat	700	        -dir  1	
element	zeroLength		1032	60046	61046	  -mat	700	        -dir  1	
element	zeroLength		1033	60047	61047	  -mat	700	        -dir  1	
element	zeroLength		1034	60048	61048	  -mat	700	        -dir  1	
element	zeroLength		1035	60049	61049	  -mat	700	        -dir  1	
element	zeroLength		1036	60050	61050	  -mat	700	        -dir  1	
element	zeroLength		1037	60051	61051	  -mat	700	        -dir  1	
element	zeroLength		1038	60052	61052	  -mat	700	        -dir  1	
element	zeroLength		1039	60053	61053	  -mat	700	        -dir  1	
element	zeroLength		1040	60054	61054	  -mat	700	        -dir  1	
element	zeroLength		1041	60055	61055	  -mat	700	        -dir  1	
element	zeroLength		1042	60056	61056	  -mat	700	        -dir  1	
element	zeroLength		1043	60057	61057	  -mat	700	        -dir  1	
element	zeroLength		1044	60058	61058	  -mat	700	        -dir  1	
element	zeroLength		1045	60059	61059	  -mat	700	        -dir  1	
element	zeroLength		1046	60060	61060	  -mat	700	        -dir  1	
element	zeroLength		1047	60061	61061	  -mat	700	        -dir  1	
element	zeroLength		1048	60062	61062	  -mat	700	        -dir  1	
element	zeroLength		1049	60063	61063	  -mat	700	        -dir  1	
element	zeroLength		1050	60064	61064	  -mat	700	        -dir  1	
element	zeroLength		1051	60065	61065	  -mat	700	        -dir  1	
element	zeroLength		1052	60066	61066	  -mat	700	        -dir  1	
element	zeroLength		1053	60067	61067	  -mat	700	        -dir  1	
element	zeroLength		1054	60068	61068	  -mat	700	        -dir  1	
element	zeroLength		1055	60069	61069	  -mat	700	        -dir  1	
element	zeroLength		1056	60070	61070	  -mat	700	        -dir  1	
element	zeroLength		1057	60071	61071	  -mat	700	        -dir  1	
element	zeroLength		1058	60072	61072	  -mat	700	        -dir  1	
element	zeroLength		1059	60073	61073	  -mat	700	        -dir  1	
element	zeroLength		1060	60074	61074	  -mat	700	        -dir  1	
element	zeroLength		1061	60075	61075	  -mat	700	        -dir  1	
element	zeroLength		1062	60076	61076	  -mat	700	        -dir  1	
element	zeroLength		1063	60077	61077	  -mat	700	        -dir  1	
element	zeroLength		1064	60078	61078	  -mat	700	        -dir  1	
element	zeroLength		1065	60079	61079	  -mat	700	        -dir  1	
element	zeroLength		1066	60080	61080	  -mat	700	        -dir  1	
element	zeroLength		1067	60081	61081	  -mat	700	        -dir  1	
element	zeroLength		1068	60082	61082	  -mat	700	        -dir  1	
element	zeroLength		1069	60083	61083	  -mat	700	        -dir  1	
element	zeroLength		1070	60084	61084	  -mat	700	        -dir  1	
element	zeroLength		1071	60085	61085	  -mat	700	        -dir  1	
element	zeroLength		1072	60086	61086	  -mat	700	        -dir  1	
element	zeroLength		1073	60087	61087	  -mat	700	        -dir  1	
element	zeroLength		1074	60088	61088	  -mat	700	        -dir  1	
element	zeroLength		1075	60089	61089	  -mat	700	        -dir  1	
element	zeroLength		1076	60090	61090	  -mat	700	        -dir  1	
element	zeroLength		1077	60091	61091	  -mat	700	        -dir  1	
element	zeroLength		1078	60092	61092	  -mat	700	        -dir  1	
element	zeroLength		1079	60093	61093	  -mat	700	        -dir  1	
element	zeroLength		1080	60094	61094	  -mat	700	        -dir  1	
element	zeroLength		1081	60095	61095	  -mat	700	        -dir  1	
element	zeroLength		1082	60096	61096	  -mat	700	        -dir  1	
element	zeroLength		1083	60097	61097	  -mat	700	        -dir  1	
element	zeroLength		1084	60098	61098	  -mat	700	        -dir  1	
element	zeroLength		1085	60099	61099	  -mat	700	        -dir  1	
element	zeroLength		1086	60100	61100	  -mat	700	        -dir  1	
element	zeroLength		1087	60101	61101	  -mat	700	        -dir  1	
element	zeroLength		1088	60102	61102	  -mat	700	        -dir  1	
element	zeroLength		1089	60103	61103	  -mat	700	        -dir  1	
element	zeroLength		1090	60104	61104	  -mat	700	        -dir  1	
element	zeroLength		1091	60105	61105	  -mat	700	        -dir  1	
element	zeroLength		1092	60106	61106	  -mat	700	        -dir  1	
element	zeroLength		1093	60107	61107	  -mat	700	        -dir  1	
element	zeroLength		1094	60108	61108	  -mat	700	        -dir  1	
element	zeroLength		1095	60109	61109	  -mat	700	        -dir  1	
element	zeroLength		1096	60110	61110	  -mat	700	        -dir  1	


#=========================================================
#                  CA MORTAR LAYER ELEMENTS
#=========================================================
# Acts as a cushion layer to play important roles such as supporting, adjusting, load transferring, vibration absorption 
# and shock insulation, etc., and improve the durability of the track structure as well as the ride safety and 
# comfort level of the high-speed trains

# CA Mortar Layer
set Fyca  41.5
set dyca  0.0005
set K1ca  [expr $Fyca/$dyca]

uniaxialMaterial Steel01 500 $Fyca $K1ca 0.0 

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element	zeroLength		1097	51001	52001	  -mat	500			-dir  1	 
element	zeroLength		1098	51002	52002	  -mat	500			-dir  1	 
element	zeroLength		1099	51003	52003	  -mat	500			-dir  1	 
element	zeroLength		1100	51004	52004	  -mat	500			-dir  1	 
element	zeroLength		1101	51005	52005	  -mat	500			-dir  1	 
element	zeroLength		1102	51006	52006	  -mat	500			-dir  1	 
element	zeroLength		1103	51007	52007	  -mat	500			-dir  1	 
element	zeroLength		1104	51008	52008	  -mat	500			-dir  1	 
element	zeroLength		1105	51009	52009	  -mat	500			-dir  1	 
element	zeroLength		1106	51010	52010	  -mat	500			-dir  1	 
element	zeroLength		1107	51011	52011	  -mat	500			-dir  1	 
element	zeroLength		1108	51012	52012	  -mat	500			-dir  1	 
element	zeroLength		1109	51013	52013	  -mat	500			-dir  1	 
element	zeroLength		1110	51014	52014	  -mat	500			-dir  1	 
element	zeroLength		1111	51015	52015	  -mat	500			-dir  1	 
element	zeroLength		1112	51016	52016	  -mat	500			-dir  1	 
element	zeroLength		1113	51017	52017	  -mat	500			-dir  1	 
element	zeroLength		1114	51018	52018	  -mat	500			-dir  1	 
element	zeroLength		1115	51019	52019	  -mat	500			-dir  1	 
element	zeroLength		1116	51020	52020	  -mat	500			-dir  1	 
element	zeroLength		1117	51021	52021	  -mat	500			-dir  1	 
element	zeroLength		1118	51022	52022	  -mat	500			-dir  1	 
element	zeroLength		1119	51023	52023	  -mat	500			-dir  1	 
element	zeroLength		1120	51024	52024	  -mat	500			-dir  1	 
element	zeroLength		1121	51025	52025	  -mat	500			-dir  1	 
element	zeroLength		1122	51026	52026	  -mat	500			-dir  1	 
element	zeroLength		1123	51027	52027	  -mat	500			-dir  1	 
element	zeroLength		1124	51028	52028	  -mat	500			-dir  1	 
element	zeroLength		1125	51029	52029	  -mat	500			-dir  1	 
element	zeroLength		1126	51030	52030	  -mat	500			-dir  1	 
element	zeroLength		1127	51031	52031	  -mat	500			-dir  1	 
element	zeroLength		1128	51032	52032	  -mat	500			-dir  1	 
element	zeroLength		1129	51033	52033	  -mat	500			-dir  1	 
element	zeroLength		1130	51034	52034	  -mat	500			-dir  1	 
element	zeroLength		1131	51035	52035	  -mat	500			-dir  1	 
element	zeroLength		1132	51036	52036	  -mat	500			-dir  1	 
element	zeroLength		1133	51037	52037	  -mat	500			-dir  1	 
element	zeroLength		1134	51038	52038	  -mat	500			-dir  1	 
element	zeroLength		1135	51039	52039	  -mat	500			-dir  1	 
element	zeroLength		1136	51040	52040	  -mat	500			-dir  1	 
element	zeroLength		1137	51041	52041	  -mat	500			-dir  1	 
element	zeroLength		1138	51042	52042	  -mat	500			-dir  1	 
element	zeroLength		1139	51043	52043	  -mat	500			-dir  1	 
element	zeroLength		1140	51044	52044	  -mat	500			-dir  1	 
element	zeroLength		1141	51045	52045	  -mat	500			-dir  1	 
element	zeroLength		1142	51046	52046	  -mat	500			-dir  1	 
element	zeroLength		1143	51047	52047	  -mat	500			-dir  1	 
element	zeroLength		1144	51048	52048	  -mat	500			-dir  1	 
element	zeroLength		1145	51049	52049	  -mat	500			-dir  1	 
element	zeroLength		1146	51050	52050	  -mat	500			-dir  1	 
element	zeroLength		1147	51051	52051	  -mat	500			-dir  1	 
element	zeroLength		1148	51052	52052	  -mat	500			-dir  1	 
element	zeroLength		1149	51053	52053	  -mat	500			-dir  1	 
element	zeroLength		1150	51054	52054	  -mat	500			-dir  1	 
element	zeroLength		1151	51055	52055	  -mat	500			-dir  1	 
element	zeroLength		1152	51056	52056	  -mat	500			-dir  1	 
element	zeroLength		1153	51057	52057	  -mat	500			-dir  1	 
element	zeroLength		1154	51058	52058	  -mat	500			-dir  1	 
element	zeroLength		1155	51059	52059	  -mat	500			-dir  1	 
element	zeroLength		1156	51060	52060	  -mat	500			-dir  1	 
element	zeroLength		1157	51061	52061	  -mat	500			-dir  1	 
element	zeroLength		1158	51062	52062	  -mat	500			-dir  1	 
element	zeroLength		1159	51063	52063	  -mat	500			-dir  1	 
element	zeroLength		1160	51064	52064	  -mat	500			-dir  1	 
element	zeroLength		1161	51065	52065	  -mat	500			-dir  1	 
element	zeroLength		1162	51066	52066	  -mat	500			-dir  1	 
element	zeroLength		1163	51067	52067	  -mat	500			-dir  1	 
element	zeroLength		1164	51068	52068	  -mat	500			-dir  1	 
element	zeroLength		1165	51069	52069	  -mat	500			-dir  1	 
element	zeroLength		1166	51070	52070	  -mat	500			-dir  1	 
element	zeroLength		1167	51071	52071	  -mat	500			-dir  1	 
element	zeroLength		1168	51072	52072	  -mat	500			-dir  1	 
element	zeroLength		1169	51073	52073	  -mat	500			-dir  1	 
element	zeroLength		1170	51074	52074	  -mat	500			-dir  1	 
element	zeroLength		1171	51075	52075	  -mat	500			-dir  1	 
element	zeroLength		1172	51076	52076	  -mat	500			-dir  1	 
element	zeroLength		1173	51077	52077	  -mat	500			-dir  1	 
element	zeroLength		1174	51078	52078	  -mat	500			-dir  1	 
element	zeroLength		1175	51079	52079	  -mat	500			-dir  1	 
element	zeroLength		1176	51080	52080	  -mat	500			-dir  1	 
element	zeroLength		1177	51081	52081	  -mat	500			-dir  1	 
element	zeroLength		1178	51082	52082	  -mat	500			-dir  1	 
element	zeroLength		1179	51083	52083	  -mat	500			-dir  1	 
element	zeroLength		1180	51084	52084	  -mat	500			-dir  1	 
element	zeroLength		1181	51085	52085	  -mat	500			-dir  1	 
element	zeroLength		1182	51086	52086	  -mat	500			-dir  1	 
element	zeroLength		1183	51087	52087	  -mat	500			-dir  1	 
element	zeroLength		1184	51088	52088	  -mat	500			-dir  1	 
element	zeroLength		1185	51089	52089	  -mat	500			-dir  1	 
element	zeroLength		1186	51090	52090	  -mat	500			-dir  1	 
element	zeroLength		1187	51091	52091	  -mat	500			-dir  1	 
element	zeroLength		1188	51092	52092	  -mat	500			-dir  1	 
element	zeroLength		1189	51093	52093	  -mat	500			-dir  1	 
element	zeroLength		1190	51094	52094	  -mat	500			-dir  1	 
element	zeroLength		1191	51095	52095	  -mat	500			-dir  1	 
element	zeroLength		1192	51096	52096	  -mat	500			-dir  1	 
element	zeroLength		1193	51097	52097	  -mat	500			-dir  1	 
element	zeroLength		1194	51098	52098	  -mat	500			-dir  1	 
element	zeroLength		1195	51099	52099	  -mat	500			-dir  1	 
element	zeroLength		1196	51100	52100	  -mat	500			-dir  1	 
element	zeroLength		1197	51101	52101	  -mat	500			-dir  1	 
element	zeroLength		1198	51102	52102	  -mat	500			-dir  1	 
element	zeroLength		1199	51103	52103	  -mat	500			-dir  1	 
element	zeroLength		1200	51104	52104	  -mat	500			-dir  1	 
element	zeroLength		1201	51105	52105	  -mat	500			-dir  1	 
element	zeroLength		1202	51106	52106	  -mat	500			-dir  1	 
element	zeroLength		1203	51107	52107	  -mat	500			-dir  1	 
element	zeroLength		1204	51108	52108	  -mat	500			-dir  1	 
element	zeroLength		1205	51109	52109	  -mat	500			-dir  1	 
element	zeroLength		1206	51110	52110	  -mat	500			-dir  1	 

element	zeroLength		1207	61001	62001	  -mat	500			-dir  1	 
element	zeroLength		1208	61002	62002	  -mat	500			-dir  1	 
element	zeroLength		1209	61003	62003	  -mat	500			-dir  1	 
element	zeroLength		1210	61004	62004	  -mat	500			-dir  1	 
element	zeroLength		1211	61005	62005	  -mat	500			-dir  1	 
element	zeroLength		1212	61006	62006	  -mat	500			-dir  1	 
element	zeroLength		1213	61007	62007	  -mat	500			-dir  1	 
element	zeroLength		1214	61008	62008	  -mat	500			-dir  1	 
element	zeroLength		1215	61009	62009	  -mat	500			-dir  1	 
element	zeroLength		1216	61010	62010	  -mat	500			-dir  1	 
element	zeroLength		1217	61011	62011	  -mat	500			-dir  1	 
element	zeroLength		1218	61012	62012	  -mat	500			-dir  1	 
element	zeroLength		1219	61013	62013	  -mat	500			-dir  1	 
element	zeroLength		1220	61014	62014	  -mat	500			-dir  1	 
element	zeroLength		1221	61015	62015	  -mat	500			-dir  1	 
element	zeroLength		1222	61016	62016	  -mat	500			-dir  1	 
element	zeroLength		1223	61017	62017	  -mat	500			-dir  1	 
element	zeroLength		1224	61018	62018	  -mat	500			-dir  1	 
element	zeroLength		1225	61019	62019	  -mat	500			-dir  1	 
element	zeroLength		1226	61020	62020	  -mat	500			-dir  1	 
element	zeroLength		1227	61021	62021	  -mat	500			-dir  1	 
element	zeroLength		1228	61022	62022	  -mat	500			-dir  1	 
element	zeroLength		1229	61023	62023	  -mat	500			-dir  1	 
element	zeroLength		1230	61024	62024	  -mat	500			-dir  1	 
element	zeroLength		1231	61025	62025	  -mat	500			-dir  1	 
element	zeroLength		1232	61026	62026	  -mat	500			-dir  1	 
element	zeroLength		1233	61027	62027	  -mat	500			-dir  1	 
element	zeroLength		1234	61028	62028	  -mat	500			-dir  1	 
element	zeroLength		1235	61029	62029	  -mat	500			-dir  1	 
element	zeroLength		1236	61030	62030	  -mat	500			-dir  1	 
element	zeroLength		1237	61031	62031	  -mat	500			-dir  1	 
element	zeroLength		1238	61032	62032	  -mat	500			-dir  1	 
element	zeroLength		1239	61033	62033	  -mat	500			-dir  1	 
element	zeroLength		1240	61034	62034	  -mat	500			-dir  1	 
element	zeroLength		1241	61035	62035	  -mat	500			-dir  1	 
element	zeroLength		1242	61036	62036	  -mat	500			-dir  1	 
element	zeroLength		1243	61037	62037	  -mat	500			-dir  1	 
element	zeroLength		1244	61038	62038	  -mat	500			-dir  1	 
element	zeroLength		1245	61039	62039	  -mat	500			-dir  1	 
element	zeroLength		1246	61040	62040	  -mat	500			-dir  1	 
element	zeroLength		1247	61041	62041	  -mat	500			-dir  1	 
element	zeroLength		1248	61042	62042	  -mat	500			-dir  1	 
element	zeroLength		1249	61043	62043	  -mat	500			-dir  1	 
element	zeroLength		1250	61044	62044	  -mat	500			-dir  1	 
element	zeroLength		1251	61045	62045	  -mat	500			-dir  1	 
element	zeroLength		1252	61046	62046	  -mat	500			-dir  1	 
element	zeroLength		1253	61047	62047	  -mat	500			-dir  1	 
element	zeroLength		1254	61048	62048	  -mat	500			-dir  1	 
element	zeroLength		1255	61049	62049	  -mat	500			-dir  1	 
element	zeroLength		1256	61050	62050	  -mat	500			-dir  1	 
element	zeroLength		1257	61051	62051	  -mat	500			-dir  1	 
element	zeroLength		1258	61052	62052	  -mat	500			-dir  1	 
element	zeroLength		1259	61053	62053	  -mat	500			-dir  1	 
element	zeroLength		1260	61054	62054	  -mat	500			-dir  1	 
element	zeroLength		1261	61055	62055	  -mat	500			-dir  1	 
element	zeroLength		1262	61056	62056	  -mat	500			-dir  1	 
element	zeroLength		1263	61057	62057	  -mat	500			-dir  1	 
element	zeroLength		1264	61058	62058	  -mat	500			-dir  1	 
element	zeroLength		1265	61059	62059	  -mat	500			-dir  1	 
element	zeroLength		1266	61060	62060	  -mat	500			-dir  1	 
element	zeroLength		1267	61061	62061	  -mat	500			-dir  1	 
element	zeroLength		1268	61062	62062	  -mat	500			-dir  1	 
element	zeroLength		1269	61063	62063	  -mat	500			-dir  1	 
element	zeroLength		1270	61064	62064	  -mat	500			-dir  1	 
element	zeroLength		1271	61065	62065	  -mat	500			-dir  1	 
element	zeroLength		1272	61066	62066	  -mat	500			-dir  1	 
element	zeroLength		1273	61067	62067	  -mat	500			-dir  1	 
element	zeroLength		1274	61068	62068	  -mat	500			-dir  1	 
element	zeroLength		1275	61069	62069	  -mat	500			-dir  1	 
element	zeroLength		1276	61070	62070	  -mat	500			-dir  1	 
element	zeroLength		1277	61071	62071	  -mat	500			-dir  1	 
element	zeroLength		1278	61072	62072	  -mat	500			-dir  1	 
element	zeroLength		1279	61073	62073	  -mat	500			-dir  1	 
element	zeroLength		1280	61074	62074	  -mat	500			-dir  1	 
element	zeroLength		1281	61075	62075	  -mat	500			-dir  1	 
element	zeroLength		1282	61076	62076	  -mat	500			-dir  1	 
element	zeroLength		1283	61077	62077	  -mat	500			-dir  1	 
element	zeroLength		1284	61078	62078	  -mat	500			-dir  1	 
element	zeroLength		1285	61079	62079	  -mat	500			-dir  1	 
element	zeroLength		1286	61080	62080	  -mat	500			-dir  1	 
element	zeroLength		1287	61081	62081	  -mat	500			-dir  1	 
element	zeroLength		1288	61082	62082	  -mat	500			-dir  1	 
element	zeroLength		1289	61083	62083	  -mat	500			-dir  1	 
element	zeroLength		1290	61084	62084	  -mat	500			-dir  1	 
element	zeroLength		1291	61085	62085	  -mat	500			-dir  1	 
element	zeroLength		1292	61086	62086	  -mat	500			-dir  1	 
element	zeroLength		1293	61087	62087	  -mat	500			-dir  1	 
element	zeroLength		1294	61088	62088	  -mat	500			-dir  1	 
element	zeroLength		1295	61089	62089	  -mat	500			-dir  1	 
element	zeroLength		1296	61090	62090	  -mat	500			-dir  1	 
element	zeroLength		1297	61091	62091	  -mat	500			-dir  1	 
element	zeroLength		1298	61092	62092	  -mat	500			-dir  1	 
element	zeroLength		1299	61093	62093	  -mat	500			-dir  1	 
element	zeroLength		1300	61094	62094	  -mat	500			-dir  1	 
element	zeroLength		1301	61095	62095	  -mat	500			-dir  1	 
element	zeroLength		1302	61096	62096	  -mat	500			-dir  1	 
element	zeroLength		1303	61097	62097	  -mat	500			-dir  1	 
element	zeroLength		1304	61098	62098	  -mat	500			-dir  1	 
element	zeroLength		1305	61099	62099	  -mat	500			-dir  1	 
element	zeroLength		1306	61100	62100	  -mat	500			-dir  1	 
element	zeroLength		1307	61101	62101	  -mat	500			-dir  1	 
element	zeroLength		1308	61102	62102	  -mat	500			-dir  1	 
element	zeroLength		1309	61103	62103	  -mat	500			-dir  1	 
element	zeroLength		1310	61104	62104	  -mat	500			-dir  1	 
element	zeroLength		1311	61105	62105	  -mat	500			-dir  1	 
element	zeroLength		1312	61106	62106	  -mat	500			-dir  1	 
element	zeroLength		1313	61107	62107	  -mat	500			-dir  1	 
element	zeroLength		1314	61108	62108	  -mat	500			-dir  1	 
element	zeroLength		1315	61109	62109	  -mat	500			-dir  1	 
element	zeroLength		1316	61110	62110	  -mat	500			-dir  1	 


#=========================================================
#                  FASTENER ELEMENTS
#=========================================================
# Fastener
set Fyf  15
set dyf  0.002
set K1f  [expr $Fyf/$dyf]

uniaxialMaterial Steel01 600 $Fyf $K1f 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element	zeroLength		1317	10001	11001	  -mat	600			-dir  1	 	
element	zeroLength		1318	10002	11002	  -mat	600			-dir  1	 	
element	zeroLength		1319	10003	11003	  -mat	600			-dir  1	 		
element	zeroLength		1320	10004	11004	  -mat	600			-dir  1	 		
element	zeroLength		1321	10005	11005	  -mat	600			-dir  1	 		
element	zeroLength		1322	10006	11006	  -mat	600			-dir  1	 		
element	zeroLength		1323	10007	11007	  -mat	600			-dir  1	 		
element	zeroLength		1324	10008	11008	  -mat	600			-dir  1	 		
element	zeroLength		1325	10009	11009	  -mat	600			-dir  1	 		
element	zeroLength		1326	10010	11010	  -mat	600			-dir  1	 		
element	zeroLength		1327	10011	11011	  -mat	600			-dir  1	 		
element	zeroLength		1328	10012	11012	  -mat	600			-dir  1	 		
element	zeroLength		1329	10013	11013	  -mat	600			-dir  1	 		
element	zeroLength		1330	10014	11014	  -mat	600			-dir  1	 		
element	zeroLength		1331	10015	11015	  -mat	600			-dir  1	 		
element	zeroLength		1332	10016	11016	  -mat	600			-dir  1	 		
element	zeroLength		1333	10017	11017	  -mat	600			-dir  1	 		
element	zeroLength		1334	10018	11018	  -mat	600			-dir  1	 		
element	zeroLength		1335	10019	11019	  -mat	600			-dir  1	 		
element	zeroLength		1336	10020	11020	  -mat	600			-dir  1	 		
element	zeroLength		1337	10021	11021	  -mat	600			-dir  1	 		
element	zeroLength		1338	10022	11022	  -mat	600			-dir  1	 		
element	zeroLength		1339	10023	11023	  -mat	600			-dir  1	 		
element	zeroLength		1340	10024	11024	  -mat	600			-dir  1	 		
element	zeroLength		1341	10025	11025	  -mat	600			-dir  1	 		
element	zeroLength		1342	10026	11026	  -mat	600			-dir  1	 		
element	zeroLength		1343	10027	11027	  -mat	600			-dir  1	 		
element	zeroLength		1344	10028	11028	  -mat	600			-dir  1	 		
element	zeroLength		1345	10029	11029	  -mat	600			-dir  1	 		
element	zeroLength		1346	10030	11030	  -mat	600			-dir  1	 		
element	zeroLength		1347	10031	11031	  -mat	600			-dir  1	 		
element	zeroLength		1348	10032	11032	  -mat	600			-dir  1	 		
element	zeroLength		1349	10033	11033	  -mat	600			-dir  1	 		
element	zeroLength		1350	10034	11034	  -mat	600			-dir  1	 		
element	zeroLength		1351	10035	11035	  -mat	600			-dir  1	 		
element	zeroLength		1352	10036	11036	  -mat	600			-dir  1	 		
element	zeroLength		1353	10037	11037	  -mat	600			-dir  1	 		
element	zeroLength		1354	10038	11038	  -mat	600			-dir  1	 		
element	zeroLength		1355	10039	11039	  -mat	600			-dir  1	 		
element	zeroLength		1356	10040	11040	  -mat	600			-dir  1	 		
element	zeroLength		1357	10041	11041	  -mat	600			-dir  1	 		
element	zeroLength		1358	10042	11042	  -mat	600			-dir  1	 		
element	zeroLength		1359	10043	11043	  -mat	600			-dir  1	 		
element	zeroLength		1360	10044	11044	  -mat	600			-dir  1	 		
element	zeroLength		1361	10045	11045	  -mat	600			-dir  1	 		
element	zeroLength		1362	10046	11046	  -mat	600			-dir  1	 		
element	zeroLength		1363	10047	11047	  -mat	600			-dir  1	 		
element	zeroLength		1364	10048	11048	  -mat	600			-dir  1	 		
element	zeroLength		1365	10049	11049	  -mat	600			-dir  1	 		
element	zeroLength		1366	10050	11050	  -mat	600			-dir  1	 		
element	zeroLength		1367	10051	11051	  -mat	600			-dir  1	 		
element	zeroLength		1368	10052	11052	  -mat	600			-dir  1	 		
element	zeroLength		1369	10053	11053	  -mat	600			-dir  1	 		
element	zeroLength		1370	10054	11054	  -mat	600			-dir  1	 		
element	zeroLength		1371	10055	11055	  -mat	600			-dir  1	 		
element	zeroLength		1372	10056	11056	  -mat	600			-dir  1	 		
element	zeroLength		1373	10057	11057	  -mat	600			-dir  1	 		
element	zeroLength		1374	10058	11058	  -mat	600			-dir  1	 		
element	zeroLength		1375	10059	11059	  -mat	600			-dir  1	 		
element	zeroLength		1376	10060	11060	  -mat	600			-dir  1	 		
element	zeroLength		1377	10061	11061	  -mat	600			-dir  1	 		
element	zeroLength		1378	10062	11062	  -mat	600			-dir  1	 		
element	zeroLength		1379	10063	11063	  -mat	600			-dir  1	 		
element	zeroLength		1380	10064	11064	  -mat	600			-dir  1	 		
element	zeroLength		1381	10065	11065	  -mat	600			-dir  1	 		
element	zeroLength		1382	10066	11066	  -mat	600			-dir  1	 		
element	zeroLength		1383	10067	11067	  -mat	600			-dir  1	 		
element	zeroLength		1384	10068	11068	  -mat	600			-dir  1	 		
element	zeroLength		1385	10069	11069	  -mat	600			-dir  1	 		
element	zeroLength		1386	10070	11070	  -mat	600			-dir  1	 		
element	zeroLength		1387	10071	11071	  -mat	600			-dir  1	 		
element	zeroLength		1388	10072	11072	  -mat	600			-dir  1	 		
element	zeroLength		1389	10073	11073	  -mat	600			-dir  1	 		
element	zeroLength		1390	10074	11074	  -mat	600			-dir  1	 		
element	zeroLength		1391	10075	11075	  -mat	600			-dir  1	 		
element	zeroLength		1392	10076	11076	  -mat	600			-dir  1	 		
element	zeroLength		1393	10077	11077	  -mat	600			-dir  1	 		
element	zeroLength		1394	10078	11078	  -mat	600			-dir  1	 		
element	zeroLength		1395	10079	11079	  -mat	600			-dir  1	 		
element	zeroLength		1396	10080	11080	  -mat	600			-dir  1	 		
element	zeroLength		1397	10081	11081	  -mat	600			-dir  1	 		
element	zeroLength		1398	10082	11082	  -mat	600			-dir  1	 		
element	zeroLength		1399	10083	11083	  -mat	600			-dir  1	 		
element	zeroLength		1400	10084	11084	  -mat	600			-dir  1	 		
element	zeroLength		1401	10085	11085	  -mat	600			-dir  1	 		
element	zeroLength		1402	10086	11086	  -mat	600			-dir  1	 		
element	zeroLength		1403	10087	11087	  -mat	600			-dir  1	 		
element	zeroLength		1404	10088	11088	  -mat	600			-dir  1	 		
element	zeroLength		1405	10089	11089	  -mat	600			-dir  1	 		
element	zeroLength		1406	10090	11090	  -mat	600			-dir  1	 		
element	zeroLength		1407	10091	11091	  -mat	600			-dir  1	 		
element	zeroLength		1408	10092	11092	  -mat	600			-dir  1	 		
element	zeroLength		1409	10093	11093	  -mat	600			-dir  1	 		
element	zeroLength		1410	10094	11094	  -mat	600			-dir  1	 		
element	zeroLength		1411	10095	11095	  -mat	600			-dir  1	 		
element	zeroLength		1412	10096	11096	  -mat	600			-dir  1	 		
element	zeroLength		1413	10097	11097	  -mat	600			-dir  1	 		
element	zeroLength		1414	10098	11098	  -mat	600			-dir  1	 		
element	zeroLength		1415	10099	11099	  -mat	600			-dir  1	 		
element	zeroLength		1416	10100	11100	  -mat	600			-dir  1	 		
element	zeroLength		1417	10101	11101	  -mat	600			-dir  1	 		
element	zeroLength		1418	10102	11102	  -mat	600			-dir  1	 		
element	zeroLength		1419	10103	11103	  -mat	600			-dir  1	 		
element	zeroLength		1420	10104	11104	  -mat	600			-dir  1	 		
element	zeroLength		1421	10105	11105	  -mat	600			-dir  1	 		
element	zeroLength		1422	10106	11106	  -mat	600			-dir  1	 		
element	zeroLength		1423	10107	11107	  -mat	600			-dir  1	 		
element	zeroLength		1424	10108	11108	  -mat	600			-dir  1	 		
element	zeroLength		1425	10109	11109	  -mat	600			-dir  1	 		
element	zeroLength		1426	10110	11110	  -mat	600			-dir  1	 		

element	zeroLength		1427	20001	21001	  -mat	600			-dir  1	 	
element	zeroLength		1428	20002	21002	  -mat	600			-dir  1	 	
element	zeroLength		1429	20003	21003	  -mat	600			-dir  1	 	
element	zeroLength		1430	20004	21004	  -mat	600			-dir  1	 	
element	zeroLength		1431	20005	21005	  -mat	600			-dir  1	 	
element	zeroLength		1432	20006	21006	  -mat	600			-dir  1	 	
element	zeroLength		1433	20007	21007	  -mat	600			-dir  1	 	
element	zeroLength		1434	20008	21008	  -mat	600			-dir  1	 	
element	zeroLength		1435	20009	21009	  -mat	600			-dir  1	 	
element	zeroLength		1436	20010	21010	  -mat	600			-dir  1	 	
element	zeroLength		1437	20011	21011	  -mat	600			-dir  1	 	
element	zeroLength		1438	20012	21012	  -mat	600			-dir  1	 	
element	zeroLength		1439	20013	21013	  -mat	600			-dir  1	 	
element	zeroLength		1440	20014	21014	  -mat	600			-dir  1	 	
element	zeroLength		1441	20015	21015	  -mat	600			-dir  1	 	
element	zeroLength		1442	20016	21016	  -mat	600			-dir  1	 	
element	zeroLength		1443	20017	21017	  -mat	600			-dir  1	 	
element	zeroLength		1444	20018	21018	  -mat	600			-dir  1	 	
element	zeroLength		1445	20019	21019	  -mat	600			-dir  1	 	
element	zeroLength		1446	20020	21020	  -mat	600			-dir  1	 	
element	zeroLength		1447	20021	21021	  -mat	600			-dir  1	 	
element	zeroLength		1448	20022	21022	  -mat	600			-dir  1	 	
element	zeroLength		1449	20023	21023	  -mat	600			-dir  1	 	
element	zeroLength		1450	20024	21024	  -mat	600			-dir  1	 	
element	zeroLength		1451	20025	21025	  -mat	600			-dir  1	 	
element	zeroLength		1452	20026	21026	  -mat	600			-dir  1	 	
element	zeroLength		1453	20027	21027	  -mat	600			-dir  1	 	
element	zeroLength		1454	20028	21028	  -mat	600			-dir  1	 	
element	zeroLength		1455	20029	21029	  -mat	600			-dir  1	 	
element	zeroLength		1456	20030	21030	  -mat	600			-dir  1	 	
element	zeroLength		1457	20031	21031	  -mat	600			-dir  1	 	
element	zeroLength		1458	20032	21032	  -mat	600			-dir  1	 	
element	zeroLength		1459	20033	21033	  -mat	600			-dir  1	 	
element	zeroLength		1460	20034	21034	  -mat	600			-dir  1	 	
element	zeroLength		1461	20035	21035	  -mat	600			-dir  1	 	
element	zeroLength		1462	20036	21036	  -mat	600			-dir  1	 	
element	zeroLength		1463	20037	21037	  -mat	600			-dir  1	 	
element	zeroLength		1464	20038	21038	  -mat	600			-dir  1	 	
element	zeroLength		1465	20039	21039	  -mat	600			-dir  1	 	
element	zeroLength		1466	20040	21040	  -mat	600			-dir  1	 	
element	zeroLength		1467	20041	21041	  -mat	600			-dir  1	 	
element	zeroLength		1468	20042	21042	  -mat	600			-dir  1	 	
element	zeroLength		1469	20043	21043	  -mat	600			-dir  1	 	
element	zeroLength		1470	20044	21044	  -mat	600			-dir  1	 	
element	zeroLength		1471	20045	21045	  -mat	600			-dir  1	 	
element	zeroLength		1472	20046	21046	  -mat	600			-dir  1	 	
element	zeroLength		1473	20047	21047	  -mat	600			-dir  1	 	
element	zeroLength		1474	20048	21048	  -mat	600			-dir  1	 	
element	zeroLength		1475	20049	21049	  -mat	600			-dir  1	 	
element	zeroLength		1476	20050	21050	  -mat	600			-dir  1	 	
element	zeroLength		1477	20051	21051	  -mat	600			-dir  1	 	
element	zeroLength		1478	20052	21052	  -mat	600			-dir  1	 	
element	zeroLength		1479	20053	21053	  -mat	600			-dir  1	 	
element	zeroLength		1480	20054	21054	  -mat	600			-dir  1	 	
element	zeroLength		1481	20055	21055	  -mat	600			-dir  1	 	
element	zeroLength		1482	20056	21056	  -mat	600			-dir  1	 	
element	zeroLength		1483	20057	21057	  -mat	600			-dir  1	 	
element	zeroLength		1484	20058	21058	  -mat	600			-dir  1	 	
element	zeroLength		1485	20059	21059	  -mat	600			-dir  1	 	
element	zeroLength		1486	20060	21060	  -mat	600			-dir  1	 	
element	zeroLength		1487	20061	21061	  -mat	600			-dir  1	 	
element	zeroLength		1488	20062	21062	  -mat	600			-dir  1	 	
element	zeroLength		1489	20063	21063	  -mat	600			-dir  1	 	
element	zeroLength		1490	20064	21064	  -mat	600			-dir  1	 	
element	zeroLength		1491	20065	21065	  -mat	600			-dir  1	 	
element	zeroLength		1492	20066	21066	  -mat	600			-dir  1	 	
element	zeroLength		1493	20067	21067	  -mat	600			-dir  1	 	
element	zeroLength		1494	20068	21068	  -mat	600			-dir  1	 	
element	zeroLength		1495	20069	21069	  -mat	600			-dir  1	 	
element	zeroLength		1496	20070	21070	  -mat	600			-dir  1	 	
element	zeroLength		1497	20071	21071	  -mat	600			-dir  1	 	
element	zeroLength		1498	20072	21072	  -mat	600			-dir  1	 	
element	zeroLength		1499	20073	21073	  -mat	600			-dir  1	 	
element	zeroLength		1500	20074	21074	  -mat	600			-dir  1	 	
element	zeroLength		1501	20075	21075	  -mat	600			-dir  1	 	
element	zeroLength		1502	20076	21076	  -mat	600			-dir  1	 	
element	zeroLength		1503	20077	21077	  -mat	600			-dir  1	 	
element	zeroLength		1504	20078	21078	  -mat	600			-dir  1	 	
element	zeroLength		1505	20079	21079	  -mat	600			-dir  1	 	
element	zeroLength		1506	20080	21080	  -mat	600			-dir  1	 	
element	zeroLength		1507	20081	21081	  -mat	600			-dir  1	 	
element	zeroLength		1508	20082	21082	  -mat	600			-dir  1	 	
element	zeroLength		1509	20083	21083	  -mat	600			-dir  1	 	
element	zeroLength		1510	20084	21084	  -mat	600			-dir  1	 	
element	zeroLength		1511	20085	21085	  -mat	600			-dir  1	 	
element	zeroLength		1512	20086	21086	  -mat	600			-dir  1	 	
element	zeroLength		1513	20087	21087	  -mat	600			-dir  1	 	
element	zeroLength		1514	20088	21088	  -mat	600			-dir  1	 	
element	zeroLength		1515	20089	21089	  -mat	600			-dir  1	 	
element	zeroLength		1516	20090	21090	  -mat	600			-dir  1	 	
element	zeroLength		1517	20091	21091	  -mat	600			-dir  1	 	
element	zeroLength		1518	20092	21092	  -mat	600			-dir  1	 	
element	zeroLength		1519	20093	21093	  -mat	600			-dir  1	 	
element	zeroLength		1520	20094	21094	  -mat	600			-dir  1	 	
element	zeroLength		1521	20095	21095	  -mat	600			-dir  1	 	
element	zeroLength		1522	20096	21096	  -mat	600			-dir  1	 	
element	zeroLength		1523	20097	21097	  -mat	600			-dir  1	 	
element	zeroLength		1524	20098	21098	  -mat	600			-dir  1	 	
element	zeroLength		1525	20099	21099	  -mat	600			-dir  1	 	
element	zeroLength		1526	20100	21100	  -mat	600			-dir  1	 	
element	zeroLength		1527	20101	21101	  -mat	600			-dir  1	 	
element	zeroLength		1528	20102	21102	  -mat	600			-dir  1	 	
element	zeroLength		1529	20103	21103	  -mat	600			-dir  1	 	
element	zeroLength		1530	20104	21104	  -mat	600			-dir  1	 	
element	zeroLength		1531	20105	21105	  -mat	600			-dir  1	 	
element	zeroLength		1532	20106	21106	  -mat	600			-dir  1	 	
element	zeroLength		1533	20107	21107	  -mat	600			-dir  1	 	
element	zeroLength		1534	20108	21108	  -mat	600			-dir  1	 	
element	zeroLength		1535	20109	21109	  -mat	600			-dir  1	 	
element	zeroLength		1536	20110	21110	  -mat	600			-dir  1	 	

element	zeroLength		1537	30001	31001	  -mat	600			-dir  1	 		
element	zeroLength		1538	30002	31002	  -mat	600			-dir  1	 		
element	zeroLength		1539	30003	31003	  -mat	600			-dir  1	 		
element	zeroLength		1540	30004	31004	  -mat	600			-dir  1	 		
element	zeroLength		1541	30005	31005	  -mat	600			-dir  1	 		
element	zeroLength		1542	30006	31006	  -mat	600			-dir  1	 		
element	zeroLength		1543	30007	31007	  -mat	600			-dir  1	 		
element	zeroLength		1544	30008	31008	  -mat	600			-dir  1	 		
element	zeroLength		1545	30009	31009	  -mat	600			-dir  1	 		
element	zeroLength		1546	30010	31010	  -mat	600			-dir  1	 		
element	zeroLength		1547	30011	31011	  -mat	600			-dir  1	 		
element	zeroLength		1548	30012	31012	  -mat	600			-dir  1	 		
element	zeroLength		1549	30013	31013	  -mat	600			-dir  1	 		
element	zeroLength		1550	30014	31014	  -mat	600			-dir  1	 		
element	zeroLength		1551	30015	31015	  -mat	600			-dir  1	 		
element	zeroLength		1552	30016	31016	  -mat	600			-dir  1	 		
element	zeroLength		1553	30017	31017	  -mat	600			-dir  1	 		
element	zeroLength		1554	30018	31018	  -mat	600			-dir  1	 		
element	zeroLength		1555	30019	31019	  -mat	600			-dir  1	 		
element	zeroLength		1556	30020	31020	  -mat	600			-dir  1	 		
element	zeroLength		1557	30021	31021	  -mat	600			-dir  1	 		
element	zeroLength		1558	30022	31022	  -mat	600			-dir  1	 		
element	zeroLength		1559	30023	31023	  -mat	600			-dir  1	 		
element	zeroLength		1560	30024	31024	  -mat	600			-dir  1	 		
element	zeroLength		1561	30025	31025	  -mat	600			-dir  1	 		
element	zeroLength		1562	30026	31026	  -mat	600			-dir  1	 		
element	zeroLength		1563	30027	31027	  -mat	600			-dir  1	 		
element	zeroLength		1564	30028	31028	  -mat	600			-dir  1	 		
element	zeroLength		1565	30029	31029	  -mat	600			-dir  1	 		
element	zeroLength		1566	30030	31030	  -mat	600			-dir  1	 		
element	zeroLength		1567	30031	31031	  -mat	600			-dir  1	 		
element	zeroLength		1568	30032	31032	  -mat	600			-dir  1	 		
element	zeroLength		1569	30033	31033	  -mat	600			-dir  1	 		
element	zeroLength		1570	30034	31034	  -mat	600			-dir  1	 		
element	zeroLength		1571	30035	31035	  -mat	600			-dir  1	 		
element	zeroLength		1572	30036	31036	  -mat	600			-dir  1	 		
element	zeroLength		1573	30037	31037	  -mat	600			-dir  1	 		
element	zeroLength		1574	30038	31038	  -mat	600			-dir  1	 		
element	zeroLength		1575	30039	31039	  -mat	600			-dir  1	 		
element	zeroLength		1576	30040	31040	  -mat	600			-dir  1	 		
element	zeroLength		1577	30041	31041	  -mat	600			-dir  1	 		
element	zeroLength		1578	30042	31042	  -mat	600			-dir  1	 		
element	zeroLength		1579	30043	31043	  -mat	600			-dir  1	 		
element	zeroLength		1580	30044	31044	  -mat	600			-dir  1	 		
element	zeroLength		1581	30045	31045	  -mat	600			-dir  1	 		
element	zeroLength		1582	30046	31046	  -mat	600			-dir  1	 		
element	zeroLength		1583	30047	31047	  -mat	600			-dir  1	 		
element	zeroLength		1584	30048	31048	  -mat	600			-dir  1	 		
element	zeroLength		1585	30049	31049	  -mat	600			-dir  1	 		
element	zeroLength		1586	30050	31050	  -mat	600			-dir  1	 		
element	zeroLength		1587	30051	31051	  -mat	600			-dir  1	 		
element	zeroLength		1588	30052	31052	  -mat	600			-dir  1	 		
element	zeroLength		1589	30053	31053	  -mat	600			-dir  1	 		
element	zeroLength		1590	30054	31054	  -mat	600			-dir  1	 		
element	zeroLength		1591	30055	31055	  -mat	600			-dir  1	 		
element	zeroLength		1592	30056	31056	  -mat	600			-dir  1	 		
element	zeroLength		1593	30057	31057	  -mat	600			-dir  1	 		
element	zeroLength		1594	30058	31058	  -mat	600			-dir  1	 		
element	zeroLength		1595	30059	31059	  -mat	600			-dir  1	 		
element	zeroLength		1596	30060	31060	  -mat	600			-dir  1	 		
element	zeroLength		1597	30061	31061	  -mat	600			-dir  1	 		
element	zeroLength		1598	30062	31062	  -mat	600			-dir  1	 		
element	zeroLength		1599	30063	31063	  -mat	600			-dir  1	 		
element	zeroLength		1600	30064	31064	  -mat	600			-dir  1	 		
element	zeroLength		1601	30065	31065	  -mat	600			-dir  1	 		
element	zeroLength		1602	30066	31066	  -mat	600			-dir  1	 		
element	zeroLength		1603	30067	31067	  -mat	600			-dir  1	 		
element	zeroLength		1604	30068	31068	  -mat	600			-dir  1	 		
element	zeroLength		1605	30069	31069	  -mat	600			-dir  1	 		
element	zeroLength		1606	30070	31070	  -mat	600			-dir  1	 		
element	zeroLength		1607	30071	31071	  -mat	600			-dir  1	 		
element	zeroLength		1608	30072	31072	  -mat	600			-dir  1	 		
element	zeroLength		1609	30073	31073	  -mat	600			-dir  1	 		
element	zeroLength		1610	30074	31074	  -mat	600			-dir  1	 		
element	zeroLength		1611	30075	31075	  -mat	600			-dir  1	 		
element	zeroLength		1612	30076	31076	  -mat	600			-dir  1	 		
element	zeroLength		1613	30077	31077	  -mat	600			-dir  1	 		
element	zeroLength		1614	30078	31078	  -mat	600			-dir  1	 		
element	zeroLength		1615	30079	31079	  -mat	600			-dir  1	 		
element	zeroLength		1616	30080	31080	  -mat	600			-dir  1	 		
element	zeroLength		1617	30081	31081	  -mat	600			-dir  1	 		
element	zeroLength		1618	30082	31082	  -mat	600			-dir  1	 		
element	zeroLength		1619	30083	31083	  -mat	600			-dir  1	 		
element	zeroLength		1620	30084	31084	  -mat	600			-dir  1	 		
element	zeroLength		1621	30085	31085	  -mat	600			-dir  1	 		
element	zeroLength		1622	30086	31086	  -mat	600			-dir  1	 		
element	zeroLength		1623	30087	31087	  -mat	600			-dir  1	 		
element	zeroLength		1624	30088	31088	  -mat	600			-dir  1	 		
element	zeroLength		1625	30089	31089	  -mat	600			-dir  1	 		
element	zeroLength		1626	30090	31090	  -mat	600			-dir  1	 		
element	zeroLength		1627	30091	31091	  -mat	600			-dir  1	 		
element	zeroLength		1628	30092	31092	  -mat	600			-dir  1	 		
element	zeroLength		1629	30093	31093	  -mat	600			-dir  1	 		
element	zeroLength		1630	30094	31094	  -mat	600			-dir  1	 		
element	zeroLength		1631	30095	31095	  -mat	600			-dir  1	 		
element	zeroLength		1632	30096	31096	  -mat	600			-dir  1	 		
element	zeroLength		1633	30097	31097	  -mat	600			-dir  1	 		
element	zeroLength		1634	30098	31098	  -mat	600			-dir  1	 		
element	zeroLength		1635	30099	31099	  -mat	600			-dir  1	 		
element	zeroLength		1636	30100	31100	  -mat	600			-dir  1	 		
element	zeroLength		1637	30101	31101	  -mat	600			-dir  1	 		
element	zeroLength		1638	30102	31102	  -mat	600			-dir  1	 		
element	zeroLength		1639	30103	31103	  -mat	600			-dir  1	 		
element	zeroLength		1640	30104	31104	  -mat	600			-dir  1	 		
element	zeroLength		1641	30105	31105	  -mat	600			-dir  1	 		
element	zeroLength		1642	30106	31106	  -mat	600			-dir  1	 		
element	zeroLength		1643	30107	31107	  -mat	600			-dir  1	 		
element	zeroLength		1644	30108	31108	  -mat	600			-dir  1	 		
element	zeroLength		1645	30109	31109	  -mat	600			-dir  1	 		
element	zeroLength		1646	30110	31110	  -mat	600			-dir  1	 		

element	zeroLength		1647	40001	41001	  -mat	600			-dir  1	 		
element	zeroLength		1648	40002	41002	  -mat	600			-dir  1	 		
element	zeroLength		1649	40003	41003	  -mat	600			-dir  1	 		
element	zeroLength		1650	40004	41004	  -mat	600			-dir  1	 		
element	zeroLength		1651	40005	41005	  -mat	600			-dir  1	 		
element	zeroLength		1652	40006	41006	  -mat	600			-dir  1	 		
element	zeroLength		1653	40007	41007	  -mat	600			-dir  1	 		
element	zeroLength		1654	40008	41008	  -mat	600			-dir  1	 		
element	zeroLength		1655	40009	41009	  -mat	600			-dir  1	 		
element	zeroLength		1656	40010	41010	  -mat	600			-dir  1	 		
element	zeroLength		1657	40011	41011	  -mat	600			-dir  1	 		
element	zeroLength		1658	40012	41012	  -mat	600			-dir  1	 		
element	zeroLength		1659	40013	41013	  -mat	600			-dir  1	 		
element	zeroLength		1660	40014	41014	  -mat	600			-dir  1	 		
element	zeroLength		1661	40015	41015	  -mat	600			-dir  1	 		
element	zeroLength		1662	40016	41016	  -mat	600			-dir  1	 		
element	zeroLength		1663	40017	41017	  -mat	600			-dir  1	 		
element	zeroLength		1664	40018	41018	  -mat	600			-dir  1	 		
element	zeroLength		1665	40019	41019	  -mat	600			-dir  1	 		
element	zeroLength		1666	40020	41020	  -mat	600			-dir  1	 		
element	zeroLength		1667	40021	41021	  -mat	600			-dir  1	 		
element	zeroLength		1668	40022	41022	  -mat	600			-dir  1	 		
element	zeroLength		1669	40023	41023	  -mat	600			-dir  1	 		
element	zeroLength		1670	40024	41024	  -mat	600			-dir  1	 		
element	zeroLength		1671	40025	41025	  -mat	600			-dir  1	 		
element	zeroLength		1672	40026	41026	  -mat	600			-dir  1	 		
element	zeroLength		1673	40027	41027	  -mat	600			-dir  1	 		
element	zeroLength		1674	40028	41028	  -mat	600			-dir  1	 		
element	zeroLength		1675	40029	41029	  -mat	600			-dir  1	 		
element	zeroLength		1676	40030	41030	  -mat	600			-dir  1	 		
element	zeroLength		1677	40031	41031	  -mat	600			-dir  1	 		
element	zeroLength		1678	40032	41032	  -mat	600			-dir  1	 		
element	zeroLength		1679	40033	41033	  -mat	600			-dir  1	 		
element	zeroLength		1680	40034	41034	  -mat	600			-dir  1	 		
element	zeroLength		1681	40035	41035	  -mat	600			-dir  1	 		
element	zeroLength		1682	40036	41036	  -mat	600			-dir  1	 		
element	zeroLength		1683	40037	41037	  -mat	600			-dir  1	 		
element	zeroLength		1684	40038	41038	  -mat	600			-dir  1	 		
element	zeroLength		1685	40039	41039	  -mat	600			-dir  1	 		
element	zeroLength		1686	40040	41040	  -mat	600			-dir  1	 		
element	zeroLength		1687	40041	41041	  -mat	600			-dir  1	 		
element	zeroLength		1688	40042	41042	  -mat	600			-dir  1	 		
element	zeroLength		1689	40043	41043	  -mat	600			-dir  1	 		
element	zeroLength		1690	40044	41044	  -mat	600			-dir  1	 		
element	zeroLength		1691	40045	41045	  -mat	600			-dir  1	 		
element	zeroLength		1692	40046	41046	  -mat	600			-dir  1	 		
element	zeroLength		1693	40047	41047	  -mat	600			-dir  1	 		
element	zeroLength		1694	40048	41048	  -mat	600			-dir  1	 		
element	zeroLength		1695	40049	41049	  -mat	600			-dir  1	 		
element	zeroLength		1696	40050	41050	  -mat	600			-dir  1	 		
element	zeroLength		1697	40051	41051	  -mat	600			-dir  1	 		
element	zeroLength		1698	40052	41052	  -mat	600			-dir  1	 		
element	zeroLength		1699	40053	41053	  -mat	600			-dir  1	 		
element	zeroLength		1700	40054	41054	  -mat	600			-dir  1	 		
element	zeroLength		1701	40055	41055	  -mat	600			-dir  1	 		
element	zeroLength		1702	40056	41056	  -mat	600			-dir  1	 		
element	zeroLength		1703	40057	41057	  -mat	600			-dir  1	 		
element	zeroLength		1704	40058	41058	  -mat	600			-dir  1	 		
element	zeroLength		1705	40059	41059	  -mat	600			-dir  1	 		
element	zeroLength		1706	40060	41060	  -mat	600			-dir  1	 		
element	zeroLength		1707	40061	41061	  -mat	600			-dir  1	 		
element	zeroLength		1708	40062	41062	  -mat	600			-dir  1	 		
element	zeroLength		1709	40063	41063	  -mat	600			-dir  1	 		
element	zeroLength		1710	40064	41064	  -mat	600			-dir  1	 		
element	zeroLength		1711	40065	41065	  -mat	600			-dir  1	 		
element	zeroLength		1712	40066	41066	  -mat	600			-dir  1	 		
element	zeroLength		1713	40067	41067	  -mat	600			-dir  1	 		
element	zeroLength		1714	40068	41068	  -mat	600			-dir  1	 		
element	zeroLength		1715	40069	41069	  -mat	600			-dir  1	 		
element	zeroLength		1716	40070	41070	  -mat	600			-dir  1	 		
element	zeroLength		1717	40071	41071	  -mat	600			-dir  1	 		
element	zeroLength		1718	40072	41072	  -mat	600			-dir  1	 		
element	zeroLength		1719	40073	41073	  -mat	600			-dir  1	 		
element	zeroLength		1720	40074	41074	  -mat	600			-dir  1	 		
element	zeroLength		1721	40075	41075	  -mat	600			-dir  1	 		
element	zeroLength		1722	40076	41076	  -mat	600			-dir  1	 		
element	zeroLength		1723	40077	41077	  -mat	600			-dir  1	 		
element	zeroLength		1724	40078	41078	  -mat	600			-dir  1	 		
element	zeroLength		1725	40079	41079	  -mat	600			-dir  1	 		
element	zeroLength		1726	40080	41080	  -mat	600			-dir  1	 		
element	zeroLength		1727	40081	41081	  -mat	600			-dir  1	 		
element	zeroLength		1728	40082	41082	  -mat	600			-dir  1	 		
element	zeroLength		1729	40083	41083	  -mat	600			-dir  1	 		
element	zeroLength		1730	40084	41084	  -mat	600			-dir  1	 		
element	zeroLength		1731	40085	41085	  -mat	600			-dir  1	 		
element	zeroLength		1732	40086	41086	  -mat	600			-dir  1	 		
element	zeroLength		1733	40087	41087	  -mat	600			-dir  1	 		
element	zeroLength		1734	40088	41088	  -mat	600			-dir  1	 		
element	zeroLength		1735	40089	41089	  -mat	600			-dir  1	 		
element	zeroLength		1736	40090	41090	  -mat	600			-dir  1	 		
element	zeroLength		1737	40091	41091	  -mat	600			-dir  1	 		
element	zeroLength		1738	40092	41092	  -mat	600			-dir  1	 		
element	zeroLength		1739	40093	41093	  -mat	600			-dir  1	 		
element	zeroLength		1740	40094	41094	  -mat	600			-dir  1	 		
element	zeroLength		1741	40095	41095	  -mat	600			-dir  1	 		
element	zeroLength		1742	40096	41096	  -mat	600			-dir  1	 		
element	zeroLength		1743	40097	41097	  -mat	600			-dir  1	 		
element	zeroLength		1744	40098	41098	  -mat	600			-dir  1	 		
element	zeroLength		1745	40099	41099	  -mat	600			-dir  1	 		
element	zeroLength		1746	40100	41100	  -mat	600			-dir  1	 		
element	zeroLength		1747	40101	41101	  -mat	600			-dir  1	 		
element	zeroLength		1748	40102	41102	  -mat	600			-dir  1	 		
element	zeroLength		1749	40103	41103	  -mat	600			-dir  1	 		
element	zeroLength		1750	40104	41104	  -mat	600			-dir  1	 		
element	zeroLength		1751	40105	41105	  -mat	600			-dir  1	 		
element	zeroLength		1752	40106	41106	  -mat	600			-dir  1	 		
element	zeroLength		1753	40107	41107	  -mat	600			-dir  1	 		
element	zeroLength		1754	40108	41108	  -mat	600			-dir  1	 		
element	zeroLength		1755	40109	41109	  -mat	600			-dir  1	 		
element	zeroLength		1756	40110	41110	  -mat	600			-dir  1	 		


#=========================================================
#                  LATERAL BLOCKING ELEMENTS
#=========================================================
# Lateral Blocking
set Fyl  453
set dyl  0.002
set K1l  [expr $Fyl/$dyl]

uniaxialMaterial Steel01 900 $Fyl $K1l 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element	zeroLength		1757	10001	11001	  -mat	900			-dir  2	 
element	zeroLength		1758	10002	11002	  -mat	900			-dir  2	 
element	zeroLength		1759	10003	11003	  -mat	900			-dir  2	 
element	zeroLength		1760	10004	11004	  -mat	900			-dir  2	 
element	zeroLength		1761	10005	11005	  -mat	900			-dir  2	 
element	zeroLength		1762	10006	11006	  -mat	900			-dir  2	 
element	zeroLength		1763	10007	11007	  -mat	900			-dir  2	 
element	zeroLength		1764	10008	11008	  -mat	900			-dir  2	 
element	zeroLength		1765	10009	11009	  -mat	900			-dir  2	 
element	zeroLength		1766	10010	11010	  -mat	900			-dir  2	 
element	zeroLength		1767	10011	11011	  -mat	900			-dir  2	 
element	zeroLength		1768	10012	11012	  -mat	900			-dir  2	 
element	zeroLength		1769	10013	11013	  -mat	900			-dir  2	 
element	zeroLength		1770	10014	11014	  -mat	900			-dir  2	 
element	zeroLength		1771	10015	11015	  -mat	900			-dir  2	 
element	zeroLength		1772	10016	11016	  -mat	900			-dir  2	 
element	zeroLength		1773	10017	11017	  -mat	900			-dir  2	 
element	zeroLength		1774	10018	11018	  -mat	900			-dir  2	 
element	zeroLength		1775	10019	11019	  -mat	900			-dir  2	 
element	zeroLength		1776	10020	11020	  -mat	900			-dir  2	 
element	zeroLength		1777	10021	11021	  -mat	900			-dir  2	 
element	zeroLength		1778	10022	11022	  -mat	900			-dir  2	 
element	zeroLength		1779	10023	11023	  -mat	900			-dir  2	 
element	zeroLength		1780	10024	11024	  -mat	900			-dir  2	 
element	zeroLength		1781	10025	11025	  -mat	900			-dir  2	 
element	zeroLength		1782	10026	11026	  -mat	900			-dir  2	 
element	zeroLength		1783	10027	11027	  -mat	900			-dir  2	 
element	zeroLength		1784	10028	11028	  -mat	900			-dir  2	 
element	zeroLength		1785	10029	11029	  -mat	900			-dir  2	 
element	zeroLength		1786	10030	11030	  -mat	900			-dir  2	 
element	zeroLength		1787	10031	11031	  -mat	900			-dir  2	 
element	zeroLength		1788	10032	11032	  -mat	900			-dir  2	 
element	zeroLength		1789	10033	11033	  -mat	900			-dir  2	 
element	zeroLength		1790	10034	11034	  -mat	900			-dir  2	 
element	zeroLength		1791	10035	11035	  -mat	900			-dir  2	 
element	zeroLength		1792	10036	11036	  -mat	900			-dir  2	 
element	zeroLength		1793	10037	11037	  -mat	900			-dir  2	 
element	zeroLength		1794	10038	11038	  -mat	900			-dir  2	 
element	zeroLength		1795	10039	11039	  -mat	900			-dir  2	 
element	zeroLength		1796	10040	11040	  -mat	900			-dir  2	 
element	zeroLength		1797	10041	11041	  -mat	900			-dir  2	 
element	zeroLength		1798	10042	11042	  -mat	900			-dir  2	 
element	zeroLength		1799	10043	11043	  -mat	900			-dir  2	 
element	zeroLength		1800	10044	11044	  -mat	900			-dir  2	 
element	zeroLength		1801	10045	11045	  -mat	900			-dir  2	 
element	zeroLength		1802	10046	11046	  -mat	900			-dir  2	 
element	zeroLength		1803	10047	11047	  -mat	900			-dir  2	 
element	zeroLength		1804	10048	11048	  -mat	900			-dir  2	 
element	zeroLength		1805	10049	11049	  -mat	900			-dir  2	 
element	zeroLength		1806	10050	11050	  -mat	900			-dir  2	 
element	zeroLength		1807	10051	11051	  -mat	900			-dir  2	 
element	zeroLength		1808	10052	11052	  -mat	900			-dir  2	 
element	zeroLength		1809	10053	11053	  -mat	900			-dir  2	 
element	zeroLength		1810	10054	11054	  -mat	900			-dir  2	 
element	zeroLength		1811	10055	11055	  -mat	900			-dir  2	 
element	zeroLength		1812	10056	11056	  -mat	900			-dir  2	 
element	zeroLength		1813	10057	11057	  -mat	900			-dir  2	 
element	zeroLength		1814	10058	11058	  -mat	900			-dir  2	 
element	zeroLength		1815	10059	11059	  -mat	900			-dir  2	 
element	zeroLength		1816	10060	11060	  -mat	900			-dir  2	 
element	zeroLength		1817	10061	11061	  -mat	900			-dir  2	 
element	zeroLength		1818	10062	11062	  -mat	900			-dir  2	 
element	zeroLength		1819	10063	11063	  -mat	900			-dir  2	 
element	zeroLength		1820	10064	11064	  -mat	900			-dir  2	 
element	zeroLength		1821	10065	11065	  -mat	900			-dir  2	 
element	zeroLength		1822	10066	11066	  -mat	900			-dir  2	 
element	zeroLength		1823	10067	11067	  -mat	900			-dir  2	 
element	zeroLength		1824	10068	11068	  -mat	900			-dir  2	 
element	zeroLength		1825	10069	11069	  -mat	900			-dir  2	 
element	zeroLength		1826	10070	11070	  -mat	900			-dir  2	 
element	zeroLength		1827	10071	11071	  -mat	900			-dir  2	 
element	zeroLength		1828	10072	11072	  -mat	900			-dir  2	 
element	zeroLength		1829	10073	11073	  -mat	900			-dir  2	 
element	zeroLength		1830	10074	11074	  -mat	900			-dir  2	 
element	zeroLength		1831	10075	11075	  -mat	900			-dir  2	 
element	zeroLength		1832	10076	11076	  -mat	900			-dir  2	 
element	zeroLength		1833	10077	11077	  -mat	900			-dir  2	 
element	zeroLength		1834	10078	11078	  -mat	900			-dir  2	 
element	zeroLength		1835	10079	11079	  -mat	900			-dir  2	 
element	zeroLength		1836	10080	11080	  -mat	900			-dir  2	 
element	zeroLength		1837	10081	11081	  -mat	900			-dir  2	 
element	zeroLength		1838	10082	11082	  -mat	900			-dir  2	 
element	zeroLength		1839	10083	11083	  -mat	900			-dir  2	 
element	zeroLength		1840	10084	11084	  -mat	900			-dir  2	 
element	zeroLength		1841	10085	11085	  -mat	900			-dir  2	 
element	zeroLength		1842	10086	11086	  -mat	900			-dir  2	 
element	zeroLength		1843	10087	11087	  -mat	900			-dir  2	 
element	zeroLength		1844	10088	11088	  -mat	900			-dir  2	 
element	zeroLength		1845	10089	11089	  -mat	900			-dir  2	 
element	zeroLength		1846	10090	11090	  -mat	900			-dir  2	 
element	zeroLength		1847	10091	11091	  -mat	900			-dir  2	 
element	zeroLength		1848	10092	11092	  -mat	900			-dir  2	 
element	zeroLength		1849	10093	11093	  -mat	900			-dir  2	 
element	zeroLength		1850	10094	11094	  -mat	900			-dir  2	 
element	zeroLength		1851	10095	11095	  -mat	900			-dir  2	 
element	zeroLength		1852	10096	11096	  -mat	900			-dir  2	 
element	zeroLength		1853	10097	11097	  -mat	900			-dir  2	 
element	zeroLength		1854	10098	11098	  -mat	900			-dir  2	 
element	zeroLength		1855	10099	11099	  -mat	900			-dir  2	 
element	zeroLength		1856	10100	11100	  -mat	900			-dir  2	 
element	zeroLength		1857	10101	11101	  -mat	900			-dir  2	 
element	zeroLength		1858	10102	11102	  -mat	900			-dir  2	 
element	zeroLength		1859	10103	11103	  -mat	900			-dir  2	 
element	zeroLength		1860	10104	11104	  -mat	900			-dir  2	 
element	zeroLength		1861	10105	11105	  -mat	900			-dir  2	 
element	zeroLength		1862	10106	11106	  -mat	900			-dir  2	 
element	zeroLength		1863	10107	11107	  -mat	900			-dir  2	 
element	zeroLength		1864	10108	11108	  -mat	900			-dir  2	 
element	zeroLength		1865	10109	11109	  -mat	900			-dir  2	 
element	zeroLength		1866	10110	11110	  -mat	900			-dir  2	 

element	zeroLength		1867	20001	21001	  -mat	900			-dir  2	 
element	zeroLength		1868	20002	21002	  -mat	900			-dir  2	 
element	zeroLength		1869	20003	21003	  -mat	900			-dir  2	 
element	zeroLength		1870	20004	21004	  -mat	900			-dir  2	 
element	zeroLength		1871	20005	21005	  -mat	900			-dir  2	 
element	zeroLength		1872	20006	21006	  -mat	900			-dir  2	 
element	zeroLength		1873	20007	21007	  -mat	900			-dir  2	 
element	zeroLength		1874	20008	21008	  -mat	900			-dir  2	 
element	zeroLength		1875	20009	21009	  -mat	900			-dir  2	 
element	zeroLength		1876	20010	21010	  -mat	900			-dir  2	 
element	zeroLength		1877	20011	21011	  -mat	900			-dir  2	 
element	zeroLength		1878	20012	21012	  -mat	900			-dir  2	 
element	zeroLength		1879	20013	21013	  -mat	900			-dir  2	 
element	zeroLength		1880	20014	21014	  -mat	900			-dir  2	 
element	zeroLength		1881	20015	21015	  -mat	900			-dir  2	 
element	zeroLength		1882	20016	21016	  -mat	900			-dir  2	 
element	zeroLength		1883	20017	21017	  -mat	900			-dir  2	 
element	zeroLength		1884	20018	21018	  -mat	900			-dir  2	 
element	zeroLength		1885	20019	21019	  -mat	900			-dir  2	 
element	zeroLength		1886	20020	21020	  -mat	900			-dir  2	 
element	zeroLength		1887	20021	21021	  -mat	900			-dir  2	 
element	zeroLength		1888	20022	21022	  -mat	900			-dir  2	 
element	zeroLength		1889	20023	21023	  -mat	900			-dir  2	 
element	zeroLength		1890	20024	21024	  -mat	900			-dir  2	 
element	zeroLength		1891	20025	21025	  -mat	900			-dir  2	 
element	zeroLength		1892	20026	21026	  -mat	900			-dir  2	 
element	zeroLength		1893	20027	21027	  -mat	900			-dir  2	 
element	zeroLength		1894	20028	21028	  -mat	900			-dir  2	 
element	zeroLength		1895	20029	21029	  -mat	900			-dir  2	 
element	zeroLength		1896	20030	21030	  -mat	900			-dir  2	 
element	zeroLength		1897	20031	21031	  -mat	900			-dir  2	 
element	zeroLength		1898	20032	21032	  -mat	900			-dir  2	 
element	zeroLength		1899	20033	21033	  -mat	900			-dir  2	 
element	zeroLength		1900	20034	21034	  -mat	900			-dir  2	 
element	zeroLength		1901	20035	21035	  -mat	900			-dir  2	 
element	zeroLength		1902	20036	21036	  -mat	900			-dir  2	 
element	zeroLength		1903	20037	21037	  -mat	900			-dir  2	 
element	zeroLength		1904	20038	21038	  -mat	900			-dir  2	 
element	zeroLength		1905	20039	21039	  -mat	900			-dir  2	 
element	zeroLength		1906	20040	21040	  -mat	900			-dir  2	 
element	zeroLength		1907	20041	21041	  -mat	900			-dir  2	 
element	zeroLength		1908	20042	21042	  -mat	900			-dir  2	 
element	zeroLength		1909	20043	21043	  -mat	900			-dir  2	 
element	zeroLength		1910	20044	21044	  -mat	900			-dir  2	 
element	zeroLength		1911	20045	21045	  -mat	900			-dir  2	 
element	zeroLength		1912	20046	21046	  -mat	900			-dir  2	 
element	zeroLength		1913	20047	21047	  -mat	900			-dir  2	 
element	zeroLength		1914	20048	21048	  -mat	900			-dir  2	 
element	zeroLength		1915	20049	21049	  -mat	900			-dir  2	 
element	zeroLength		1916	20050	21050	  -mat	900			-dir  2	 
element	zeroLength		1917	20051	21051	  -mat	900			-dir  2	 
element	zeroLength		1918	20052	21052	  -mat	900			-dir  2	 
element	zeroLength		1919	20053	21053	  -mat	900			-dir  2	 
element	zeroLength		1920	20054	21054	  -mat	900			-dir  2	 
element	zeroLength		1921	20055	21055	  -mat	900			-dir  2	 
element	zeroLength		1922	20056	21056	  -mat	900			-dir  2	 
element	zeroLength		1923	20057	21057	  -mat	900			-dir  2	 
element	zeroLength		1924	20058	21058	  -mat	900			-dir  2	 
element	zeroLength		1925	20059	21059	  -mat	900			-dir  2	 
element	zeroLength		1926	20060	21060	  -mat	900			-dir  2	 
element	zeroLength		1927	20061	21061	  -mat	900			-dir  2	 
element	zeroLength		1928	20062	21062	  -mat	900			-dir  2	 
element	zeroLength		1929	20063	21063	  -mat	900			-dir  2	 
element	zeroLength		1930	20064	21064	  -mat	900			-dir  2	 
element	zeroLength		1931	20065	21065	  -mat	900			-dir  2	 
element	zeroLength		1932	20066	21066	  -mat	900			-dir  2	 
element	zeroLength		1933	20067	21067	  -mat	900			-dir  2	 
element	zeroLength		1934	20068	21068	  -mat	900			-dir  2	 
element	zeroLength		1935	20069	21069	  -mat	900			-dir  2	 
element	zeroLength		1936	20070	21070	  -mat	900			-dir  2	 
element	zeroLength		1937	20071	21071	  -mat	900			-dir  2	 
element	zeroLength		1938	20072	21072	  -mat	900			-dir  2	 
element	zeroLength		1939	20073	21073	  -mat	900			-dir  2	 
element	zeroLength		1940	20074	21074	  -mat	900			-dir  2	 
element	zeroLength		1941	20075	21075	  -mat	900			-dir  2	 
element	zeroLength		1942	20076	21076	  -mat	900			-dir  2	 
element	zeroLength		1943	20077	21077	  -mat	900			-dir  2	 
element	zeroLength		1944	20078	21078	  -mat	900			-dir  2	 
element	zeroLength		1945	20079	21079	  -mat	900			-dir  2	 
element	zeroLength		1946	20080	21080	  -mat	900			-dir  2	 
element	zeroLength		1947	20081	21081	  -mat	900			-dir  2	 
element	zeroLength		1948	20082	21082	  -mat	900			-dir  2	 
element	zeroLength		1949	20083	21083	  -mat	900			-dir  2	 
element	zeroLength		1950	20084	21084	  -mat	900			-dir  2	 
element	zeroLength		1951	20085	21085	  -mat	900			-dir  2	 
element	zeroLength		1952	20086	21086	  -mat	900			-dir  2	 
element	zeroLength		1953	20087	21087	  -mat	900			-dir  2	 
element	zeroLength		1954	20088	21088	  -mat	900			-dir  2	 
element	zeroLength		1955	20089	21089	  -mat	900			-dir  2	 
element	zeroLength		1956	20090	21090	  -mat	900			-dir  2	 
element	zeroLength		1957	20091	21091	  -mat	900			-dir  2	 
element	zeroLength		1958	20092	21092	  -mat	900			-dir  2	 
element	zeroLength		1959	20093	21093	  -mat	900			-dir  2	 
element	zeroLength		1960	20094	21094	  -mat	900			-dir  2	 
element	zeroLength		1961	20095	21095	  -mat	900			-dir  2	 
element	zeroLength		1962	20096	21096	  -mat	900			-dir  2	 
element	zeroLength		1963	20097	21097	  -mat	900			-dir  2	 
element	zeroLength		1964	20098	21098	  -mat	900			-dir  2	 
element	zeroLength		1965	20099	21099	  -mat	900			-dir  2	 
element	zeroLength		1966	20100	21100	  -mat	900			-dir  2	 
element	zeroLength		1967	20101	21101	  -mat	900			-dir  2	 
element	zeroLength		1968	20102	21102	  -mat	900			-dir  2	 
element	zeroLength		1969	20103	21103	  -mat	900			-dir  2	 
element	zeroLength		1970	20104	21104	  -mat	900			-dir  2	 
element	zeroLength		1971	20105	21105	  -mat	900			-dir  2	 
element	zeroLength		1972	20106	21106	  -mat	900			-dir  2	 
element	zeroLength		1973	20107	21107	  -mat	900			-dir  2	 
element	zeroLength		1974	20108	21108	  -mat	900			-dir  2	 
element	zeroLength		1975	20109	21109	  -mat	900			-dir  2	 
element	zeroLength		1976	20110	21110	  -mat	900			-dir  2	 

element	zeroLength		1977	30001	31001	  -mat	900			-dir  2	 
element	zeroLength		1978	30002	31002	  -mat	900			-dir  2	 
element	zeroLength		1979	30003	31003	  -mat	900			-dir  2	 
element	zeroLength		1980	30004	31004	  -mat	900			-dir  2	 
element	zeroLength		1981	30005	31005	  -mat	900			-dir  2	 
element	zeroLength		1982	30006	31006	  -mat	900			-dir  2	 
element	zeroLength		1983	30007	31007	  -mat	900			-dir  2	 
element	zeroLength		1984	30008	31008	  -mat	900			-dir  2	 
element	zeroLength		1985	30009	31009	  -mat	900			-dir  2	 
element	zeroLength		1986	30010	31010	  -mat	900			-dir  2	 
element	zeroLength		1987	30011	31011	  -mat	900			-dir  2	 
element	zeroLength		1988	30012	31012	  -mat	900			-dir  2	 
element	zeroLength		1989	30013	31013	  -mat	900			-dir  2	 
element	zeroLength		1990	30014	31014	  -mat	900			-dir  2	 
element	zeroLength		1991	30015	31015	  -mat	900			-dir  2	 
element	zeroLength		1992	30016	31016	  -mat	900			-dir  2	 
element	zeroLength		1993	30017	31017	  -mat	900			-dir  2	 
element	zeroLength		1994	30018	31018	  -mat	900			-dir  2	 
element	zeroLength		1995	30019	31019	  -mat	900			-dir  2	 
element	zeroLength		1996	30020	31020	  -mat	900			-dir  2	 
element	zeroLength		1997	30021	31021	  -mat	900			-dir  2	 
element	zeroLength		1998	30022	31022	  -mat	900			-dir  2	 
element	zeroLength		1999	30023	31023	  -mat	900			-dir  2	 
element	zeroLength		2000	30024	31024	  -mat	900			-dir  2	 
element	zeroLength		2001	30025	31025	  -mat	900			-dir  2	 
element	zeroLength		2002	30026	31026	  -mat	900			-dir  2	 
element	zeroLength		2003	30027	31027	  -mat	900			-dir  2	 
element	zeroLength		2004	30028	31028	  -mat	900			-dir  2	 
element	zeroLength		2005	30029	31029	  -mat	900			-dir  2	 
element	zeroLength		2006	30030	31030	  -mat	900			-dir  2	 
element	zeroLength		2007	30031	31031	  -mat	900			-dir  2	 
element	zeroLength		2008	30032	31032	  -mat	900			-dir  2	 
element	zeroLength		2009	30033	31033	  -mat	900			-dir  2	 
element	zeroLength		2010	30034	31034	  -mat	900			-dir  2	 
element	zeroLength		2011	30035	31035	  -mat	900			-dir  2	 
element	zeroLength		2012	30036	31036	  -mat	900			-dir  2	 
element	zeroLength		2013	30037	31037	  -mat	900			-dir  2	 
element	zeroLength		2014	30038	31038	  -mat	900			-dir  2	 
element	zeroLength		2015	30039	31039	  -mat	900			-dir  2	 
element	zeroLength		2016	30040	31040	  -mat	900			-dir  2	 
element	zeroLength		2017	30041	31041	  -mat	900			-dir  2	 
element	zeroLength		2018	30042	31042	  -mat	900			-dir  2	 
element	zeroLength		2019	30043	31043	  -mat	900			-dir  2	 
element	zeroLength		2020	30044	31044	  -mat	900			-dir  2	 
element	zeroLength		2021	30045	31045	  -mat	900			-dir  2	 
element	zeroLength		2022	30046	31046	  -mat	900			-dir  2	 
element	zeroLength		2023	30047	31047	  -mat	900			-dir  2	 
element	zeroLength		2024	30048	31048	  -mat	900			-dir  2	 
element	zeroLength		2025	30049	31049	  -mat	900			-dir  2	 
element	zeroLength		2026	30050	31050	  -mat	900			-dir  2	 
element	zeroLength		2027	30051	31051	  -mat	900			-dir  2	 
element	zeroLength		2028	30052	31052	  -mat	900			-dir  2	 
element	zeroLength		2029	30053	31053	  -mat	900			-dir  2	 
element	zeroLength		2030	30054	31054	  -mat	900			-dir  2	 
element	zeroLength		2031	30055	31055	  -mat	900			-dir  2	 
element	zeroLength		2032	30056	31056	  -mat	900			-dir  2	 
element	zeroLength		2033	30057	31057	  -mat	900			-dir  2	 
element	zeroLength		2034	30058	31058	  -mat	900			-dir  2	 
element	zeroLength		2035	30059	31059	  -mat	900			-dir  2	 
element	zeroLength		2036	30060	31060	  -mat	900			-dir  2	 
element	zeroLength		2037	30061	31061	  -mat	900			-dir  2	 
element	zeroLength		2038	30062	31062	  -mat	900			-dir  2	 
element	zeroLength		2039	30063	31063	  -mat	900			-dir  2	 
element	zeroLength		2040	30064	31064	  -mat	900			-dir  2	 
element	zeroLength		2041	30065	31065	  -mat	900			-dir  2	 
element	zeroLength		2042	30066	31066	  -mat	900			-dir  2	 
element	zeroLength		2043	30067	31067	  -mat	900			-dir  2	 
element	zeroLength		2044	30068	31068	  -mat	900			-dir  2	 
element	zeroLength		2045	30069	31069	  -mat	900			-dir  2	 
element	zeroLength		2046	30070	31070	  -mat	900			-dir  2	 
element	zeroLength		2047	30071	31071	  -mat	900			-dir  2	 
element	zeroLength		2048	30072	31072	  -mat	900			-dir  2	 
element	zeroLength		2049	30073	31073	  -mat	900			-dir  2	 
element	zeroLength		2050	30074	31074	  -mat	900			-dir  2	 
element	zeroLength		2051	30075	31075	  -mat	900			-dir  2	 
element	zeroLength		2052	30076	31076	  -mat	900			-dir  2	 
element	zeroLength		2053	30077	31077	  -mat	900			-dir  2	 
element	zeroLength		2054	30078	31078	  -mat	900			-dir  2	 
element	zeroLength		2055	30079	31079	  -mat	900			-dir  2	 
element	zeroLength		2056	30080	31080	  -mat	900			-dir  2	 
element	zeroLength		2057	30081	31081	  -mat	900			-dir  2	 
element	zeroLength		2058	30082	31082	  -mat	900			-dir  2	 
element	zeroLength		2059	30083	31083	  -mat	900			-dir  2	 
element	zeroLength		2060	30084	31084	  -mat	900			-dir  2	 
element	zeroLength		2061	30085	31085	  -mat	900			-dir  2	 
element	zeroLength		2062	30086	31086	  -mat	900			-dir  2	 
element	zeroLength		2063	30087	31087	  -mat	900			-dir  2	 
element	zeroLength		2064	30088	31088	  -mat	900			-dir  2	 
element	zeroLength		2065	30089	31089	  -mat	900			-dir  2	 
element	zeroLength		2066	30090	31090	  -mat	900			-dir  2	 
element	zeroLength		2067	30091	31091	  -mat	900			-dir  2	 
element	zeroLength		2068	30092	31092	  -mat	900			-dir  2	 
element	zeroLength		2069	30093	31093	  -mat	900			-dir  2	 
element	zeroLength		2070	30094	31094	  -mat	900			-dir  2	 
element	zeroLength		2071	30095	31095	  -mat	900			-dir  2	 
element	zeroLength		2072	30096	31096	  -mat	900			-dir  2	 
element	zeroLength		2073	30097	31097	  -mat	900			-dir  2	 
element	zeroLength		2074	30098	31098	  -mat	900			-dir  2	 
element	zeroLength		2075	30099	31099	  -mat	900			-dir  2	 
element	zeroLength		2076	30100	31100	  -mat	900			-dir  2	 
element	zeroLength		2077	30101	31101	  -mat	900			-dir  2	 
element	zeroLength		2078	30102	31102	  -mat	900			-dir  2	 
element	zeroLength		2079	30103	31103	  -mat	900			-dir  2	 
element	zeroLength		2080	30104	31104	  -mat	900			-dir  2	 
element	zeroLength		2081	30105	31105	  -mat	900			-dir  2	 
element	zeroLength		2082	30106	31106	  -mat	900			-dir  2	 
element	zeroLength		2083	30107	31107	  -mat	900			-dir  2	 
element	zeroLength		2084	30108	31108	  -mat	900			-dir  2	 
element	zeroLength		2085	30109	31109	  -mat	900			-dir  2	 
element	zeroLength		2086	30110	31110	  -mat	900			-dir  2	 

element	zeroLength		2087	40001	41001	  -mat	900			-dir  2	 
element	zeroLength		2088	40002	41002	  -mat	900			-dir  2	 
element	zeroLength		2089	40003	41003	  -mat	900			-dir  2	 
element	zeroLength		2090	40004	41004	  -mat	900			-dir  2	 
element	zeroLength		2091	40005	41005	  -mat	900			-dir  2	 
element	zeroLength		2092	40006	41006	  -mat	900			-dir  2	 
element	zeroLength		2093	40007	41007	  -mat	900			-dir  2	 
element	zeroLength		2094	40008	41008	  -mat	900			-dir  2	 
element	zeroLength		2095	40009	41009	  -mat	900			-dir  2	 
element	zeroLength		2096	40010	41010	  -mat	900			-dir  2	 
element	zeroLength		2097	40011	41011	  -mat	900			-dir  2	 
element	zeroLength		2098	40012	41012	  -mat	900			-dir  2	 
element	zeroLength		2099	40013	41013	  -mat	900			-dir  2	 
element	zeroLength		2100	40014	41014	  -mat	900			-dir  2	 
element	zeroLength		2101	40015	41015	  -mat	900			-dir  2	 
element	zeroLength		2102	40016	41016	  -mat	900			-dir  2	 
element	zeroLength		2103	40017	41017	  -mat	900			-dir  2	 
element	zeroLength		2104	40018	41018	  -mat	900			-dir  2	 
element	zeroLength		2105	40019	41019	  -mat	900			-dir  2	 
element	zeroLength		2106	40020	41020	  -mat	900			-dir  2	 
element	zeroLength		2107	40021	41021	  -mat	900			-dir  2	 
element	zeroLength		2108	40022	41022	  -mat	900			-dir  2	 
element	zeroLength		2109	40023	41023	  -mat	900			-dir  2	 
element	zeroLength		2110	40024	41024	  -mat	900			-dir  2	 
element	zeroLength		2111	40025	41025	  -mat	900			-dir  2	 
element	zeroLength		2112	40026	41026	  -mat	900			-dir  2	 
element	zeroLength		2113	40027	41027	  -mat	900			-dir  2	 
element	zeroLength		2114	40028	41028	  -mat	900			-dir  2	 
element	zeroLength		2115	40029	41029	  -mat	900			-dir  2	 
element	zeroLength		2116	40030	41030	  -mat	900			-dir  2	 
element	zeroLength		2117	40031	41031	  -mat	900			-dir  2	 
element	zeroLength		2118	40032	41032	  -mat	900			-dir  2	 
element	zeroLength		2119	40033	41033	  -mat	900			-dir  2	 
element	zeroLength		2120	40034	41034	  -mat	900			-dir  2	 
element	zeroLength		2121	40035	41035	  -mat	900			-dir  2	 
element	zeroLength		2122	40036	41036	  -mat	900			-dir  2	 
element	zeroLength		2123	40037	41037	  -mat	900			-dir  2	 
element	zeroLength		2124	40038	41038	  -mat	900			-dir  2	 
element	zeroLength		2125	40039	41039	  -mat	900			-dir  2	 
element	zeroLength		2126	40040	41040	  -mat	900			-dir  2	 
element	zeroLength		2127	40041	41041	  -mat	900			-dir  2	 
element	zeroLength		2128	40042	41042	  -mat	900			-dir  2	 
element	zeroLength		2129	40043	41043	  -mat	900			-dir  2	 
element	zeroLength		2130	40044	41044	  -mat	900			-dir  2	 
element	zeroLength		2131	40045	41045	  -mat	900			-dir  2	 
element	zeroLength		2132	40046	41046	  -mat	900			-dir  2	 
element	zeroLength		2133	40047	41047	  -mat	900			-dir  2	 
element	zeroLength		2134	40048	41048	  -mat	900			-dir  2	 
element	zeroLength		2135	40049	41049	  -mat	900			-dir  2	 
element	zeroLength		2136	40050	41050	  -mat	900			-dir  2	 
element	zeroLength		2137	40051	41051	  -mat	900			-dir  2	 
element	zeroLength		2138	40052	41052	  -mat	900			-dir  2	 
element	zeroLength		2139	40053	41053	  -mat	900			-dir  2	 
element	zeroLength		2140	40054	41054	  -mat	900			-dir  2	 
element	zeroLength		2141	40055	41055	  -mat	900			-dir  2	 
element	zeroLength		2142	40056	41056	  -mat	900			-dir  2	 
element	zeroLength		2143	40057	41057	  -mat	900			-dir  2	 
element	zeroLength		2144	40058	41058	  -mat	900			-dir  2	 
element	zeroLength		2145	40059	41059	  -mat	900			-dir  2	 
element	zeroLength		2146	40060	41060	  -mat	900			-dir  2	 
element	zeroLength		2147	40061	41061	  -mat	900			-dir  2	 
element	zeroLength		2148	40062	41062	  -mat	900			-dir  2	 
element	zeroLength		2149	40063	41063	  -mat	900			-dir  2	 
element	zeroLength		2150	40064	41064	  -mat	900			-dir  2	 
element	zeroLength		2151	40065	41065	  -mat	900			-dir  2	 
element	zeroLength		2152	40066	41066	  -mat	900			-dir  2	 
element	zeroLength		2153	40067	41067	  -mat	900			-dir  2	 
element	zeroLength		2154	40068	41068	  -mat	900			-dir  2	 
element	zeroLength		2155	40069	41069	  -mat	900			-dir  2	 
element	zeroLength		2156	40070	41070	  -mat	900			-dir  2	 
element	zeroLength		2157	40071	41071	  -mat	900			-dir  2	 
element	zeroLength		2158	40072	41072	  -mat	900			-dir  2	 
element	zeroLength		2159	40073	41073	  -mat	900			-dir  2	 
element	zeroLength		2160	40074	41074	  -mat	900			-dir  2	 
element	zeroLength		2161	40075	41075	  -mat	900			-dir  2	 
element	zeroLength		2162	40076	41076	  -mat	900			-dir  2	 
element	zeroLength		2163	40077	41077	  -mat	900			-dir  2	 
element	zeroLength		2164	40078	41078	  -mat	900			-dir  2	 
element	zeroLength		2165	40079	41079	  -mat	900			-dir  2	 
element	zeroLength		2166	40080	41080	  -mat	900			-dir  2	 
element	zeroLength		2167	40081	41081	  -mat	900			-dir  2	 
element	zeroLength		2168	40082	41082	  -mat	900			-dir  2	 
element	zeroLength		2169	40083	41083	  -mat	900			-dir  2	 
element	zeroLength		2170	40084	41084	  -mat	900			-dir  2	 
element	zeroLength		2171	40085	41085	  -mat	900			-dir  2	 
element	zeroLength		2172	40086	41086	  -mat	900			-dir  2	 
element	zeroLength		2173	40087	41087	  -mat	900			-dir  2	 
element	zeroLength		2174	40088	41088	  -mat	900			-dir  2	 
element	zeroLength		2175	40089	41089	  -mat	900			-dir  2	 
element	zeroLength		2176	40090	41090	  -mat	900			-dir  2	 
element	zeroLength		2177	40091	41091	  -mat	900			-dir  2	 
element	zeroLength		2178	40092	41092	  -mat	900			-dir  2	 
element	zeroLength		2179	40093	41093	  -mat	900			-dir  2	 
element	zeroLength		2180	40094	41094	  -mat	900			-dir  2	 
element	zeroLength		2181	40095	41095	  -mat	900			-dir  2	 
element	zeroLength		2182	40096	41096	  -mat	900			-dir  2	 
element	zeroLength		2183	40097	41097	  -mat	900			-dir  2	 
element	zeroLength		2184	40098	41098	  -mat	900			-dir  2	 
element	zeroLength		2185	40099	41099	  -mat	900			-dir  2	 
element	zeroLength		2186	40100	41100	  -mat	900			-dir  2	 
element	zeroLength		2187	40101	41101	  -mat	900			-dir  2	 
element	zeroLength		2188	40102	41102	  -mat	900			-dir  2	 
element	zeroLength		2189	40103	41103	  -mat	900			-dir  2	 
element	zeroLength		2190	40104	41104	  -mat	900			-dir  2	 
element	zeroLength		2191	40105	41105	  -mat	900			-dir  2	 
element	zeroLength		2192	40106	41106	  -mat	900			-dir  2	 
element	zeroLength		2193	40107	41107	  -mat	900			-dir  2	 
element	zeroLength		2194	40108	41108	  -mat	900			-dir  2	 
element	zeroLength		2195	40109	41109	  -mat	900			-dir  2	 
element	zeroLength		2196	40110	41110	  -mat	900			-dir  2	 


#=========================================================
#                  SHEAR REINFORCEMENT ELEMENTS
#=========================================================
# Shear Reinforcement
set Fysr  22.5
set dysr  0.000075
set K1sr  [expr $Fysr/$dysr]

uniaxialMaterial Steel01 800 $Fysr $K1sr 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element	zeroLength		2197	50001	51001	  -mat 800 800 		-dir 1 2 	 
element	zeroLength		2198	50011	51011	  -mat 800 800 		-dir 1 2 	 
element	zeroLength		2199	50012	51012	  -mat 800 800 		-dir 1 2 
element	zeroLength		2200	50022	51022	  -mat 800 800 		-dir 1 2 
element	zeroLength		2201	50023	51023	  -mat 800 800 		-dir 1 2 
element	zeroLength		2202	50033	51033	  -mat 800 800 		-dir 1 2 
element	zeroLength		2203	50034	51034	  -mat 800 800 		-dir 1 2 
element	zeroLength		2204	50044	51044	  -mat 800 800 		-dir 1 2 
element	zeroLength		2205	50045	51045	  -mat 800 800 		-dir 1 2 
element	zeroLength		2206	50055	51055	  -mat 800 800 		-dir 1 2 
element	zeroLength		2207	50056	51056	  -mat 800 800 		-dir 1 2 
element	zeroLength		2208	50066	51066	  -mat 800 800 		-dir 1 2 
element	zeroLength		2209	50067	51067	  -mat 800 800 		-dir 1 2 
element	zeroLength		2210	50077	51077	  -mat 800 800 		-dir 1 2 
element	zeroLength		2211	50078	51078	  -mat 800 800 		-dir 1 2 
element	zeroLength		2212	50088	51088	  -mat 800 800 		-dir 1 2 
element	zeroLength		2213	50089	51089	  -mat 800 800 		-dir 1 2 
element	zeroLength		2214	50099	51099	  -mat 800 800 		-dir 1 2 
element	zeroLength		2215	50100	51100	  -mat 800 800 		-dir 1 2 
element	zeroLength		2216	50110	51110	  -mat 800 800 		-dir 1 2 

element	zeroLength		2217	60001	61001	  -mat 800 800 		-dir 1 2 
element	zeroLength		2218	60011	61011	  -mat 800 800 		-dir 1 2 
element	zeroLength		2219	60012	61012	  -mat 800 800 		-dir 1 2 
element	zeroLength		2220	60022	61022	  -mat 800 800 		-dir 1 2 
element	zeroLength		2221	60023	61023	  -mat 800 800 		-dir 1 2 
element	zeroLength		2222	60033	61033	  -mat 800 800 		-dir 1 2 
element	zeroLength		2223	60034	61034	  -mat 800 800 		-dir 1 2 
element	zeroLength		2224	60044	61044	  -mat 800 800 		-dir 1 2 
element	zeroLength		2225	60045	61045	  -mat 800 800 		-dir 1 2 
element	zeroLength		2226	60055	61055	  -mat 800 800 		-dir 1 2 
element	zeroLength		2227	60056	61056	  -mat 800 800 		-dir 1 2 
element	zeroLength		2228	60066	61066	  -mat 800 800 		-dir 1 2 
element	zeroLength		2229	60067	61067	  -mat 800 800 		-dir 1 2 
element	zeroLength		2230	60077	61077	  -mat 800 800 		-dir 1 2 
element	zeroLength		2231	60078	61078	  -mat 800 800 		-dir 1 2 
element	zeroLength		2232	60088	61088	  -mat 800 800 		-dir 1 2 
element	zeroLength		2233	60089	61089	  -mat 800 800 		-dir 1 2 
element	zeroLength		2234	60099	61099	  -mat 800 800 		-dir 1 2 
element	zeroLength		2235	60100	61100	  -mat 800 800 		-dir 1 2 
element	zeroLength		2236	60110	61110	  -mat 800 800 		-dir 1 2 


#=============================================================================================================
#                 TRACK SYSTEM MASS
#=============================================================================================================

#=========================================================
#                  TRACK PLATE MASSES
#=========================================================
set mass   3.5878
set massxx 1.9561
set massyy 3.0640
set masszz 4.9961

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	52001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	52110	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	62001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	62110	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#=========================================================
#                  BASE PLATE MASSES
#=========================================================
set mass   3.9466
set massxx 0.7282
set massyy 0.8537
set masszz 1.5759

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	51001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	51110	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	61001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	61110	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#=========================================================
#                  RAIL MASSES
#=========================================================
# Rail
set mass   0.1693
set massxx 0.0025
set massyy 0.1459
set masszz 0.1446

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	11001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11110	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	21001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	21110	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	31001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	31110	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	41001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	41110	$mass	$mass	$mass	$massxx	  $massyy	$masszz


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

#===========================================================================================================================================================================================
#                	BRIDGE SYSTEM NODES
#===========================================================================================================================================================================================

#=========================================================
#               	 DECK NODES
#=========================================================
# Total span length 31.95m, 10 spans, total length 319.5m
# Discretized into 3.195m with a 0.05m gap between spans

#	   nodeTag		 (x)	  (y)     (z)
node	90001	      0.000    0	  $yg; # Span 1
node	90002	      3.195	   0	  $yg
node	90003		  6.390	   0	  $yg
node	90004		  9.585	   0	  $yg
node	90005		 12.780	   0	  $yg
node	90006	     15.975	   0	  $yg
node	90007	     19.170	   0	  $yg
node	90008	     22.365	   0	  $yg
node	90009	     25.560	   0	  $yg
node	90010	     28.755	   0	  $yg
node	90011	     31.950	   0	  $yg
node	90012	     32.000	   0	  $yg
node	90013		 35.195	   0	  $yg
node	90014		 38.390	   0	  $yg
node	90015		 41.585	   0	  $yg
node	90016		 44.780	   0	  $yg
node	90017		 47.975	   0	  $yg
node	90018		 51.170	   0	  $yg
node	90019		 54.365	   0	  $yg
node	90020		 57.560	   0	  $yg
node	90021		 60.755	   0	  $yg
node	90022		 63.950	   0	  $yg
node	90023		 64.000	   0	  $yg
node	90024		 67.195	   0	  $yg
node	90025		 70.390	   0	  $yg
node	90026		 73.585	   0	  $yg
node	90027		 76.780	   0	  $yg
node	90028		 79.975	   0	  $yg
node	90029		 83.170	   0	  $yg
node	90030		 86.365	   0	  $yg
node	90031		 89.560	   0	  $yg
node	90032		 92.755	   0	  $yg
node	90033		 95.950	   0	  $yg
node	90034		 96.000	   0	  $yg
node	90035		 99.195	   0	  $yg
node	90036		102.390	   0	  $yg
node	90037		105.585	   0	  $yg
node	90038		108.780	   0	  $yg
node	90039		111.975	   0	  $yg
node	90040		115.170	   0	  $yg
node	90041		118.365	   0	  $yg
node	90042		121.560	   0	  $yg
node	90043		124.755	   0	  $yg
node	90044		127.950	   0	  $yg
node	90045		128.000	   0	  $yg
node	90046		131.195	   0	  $yg
node	90047		134.390	   0	  $yg
node	90048		137.585	   0	  $yg
node	90049		140.780	   0	  $yg
node	90050		143.975	   0	  $yg
node	90051		147.170	   0	  $yg
node	90052		150.365	   0	  $yg
node	90053		153.560	   0	  $yg
node	90054		156.755	   0	  $yg
node	90055		159.950	   0	  $yg
node	90056		160.000	   0	  $yg
node	90057		163.195	   0	  $yg
node	90058		166.390	   0	  $yg
node	90059		169.585	   0	  $yg
node	90060		172.780	   0	  $yg
node	90061		175.975	   0	  $yg
node	90062		179.170	   0	  $yg
node	90063		182.365	   0	  $yg
node	90064		185.560	   0	  $yg
node	90065		188.755	   0	  $yg
node	90066		191.950	   0	  $yg
node	90067		192.000	   0	  $yg
node	90068		195.195	   0	  $yg
node	90069		198.390	   0	  $yg
node	90070		201.585	   0	  $yg
node	90071		204.780	   0	  $yg
node	90072		207.975	   0	  $yg
node	90073		211.170	   0	  $yg
node	90074		214.365	   0	  $yg
node	90075		217.560	   0	  $yg
node	90076		220.755	   0	  $yg
node	90077		223.950	   0	  $yg
node	90078		224.000	   0	  $yg
node	90079		227.195	   0	  $yg
node	90080		230.390	   0	  $yg
node	90081		233.585	   0	  $yg
node	90082		236.780	   0	  $yg
node	90083		239.975	   0	  $yg
node	90084		243.170	   0	  $yg
node	90085		246.365	   0	  $yg
node	90086		249.560	   0	  $yg
node	90087		252.755	   0	  $yg
node	90088		255.950	   0	  $yg
node	90089		256.000	   0	  $yg
node	90090		259.195	   0	  $yg
node	90091		262.390	   0	  $yg
node	90092		265.585	   0	  $yg
node	90093		268.780	   0	  $yg
node	90094		271.975	   0	  $yg
node	90095		275.170	   0	  $yg
node	90096		278.365	   0	  $yg
node	90097		281.560	   0	  $yg
node	90098		284.755	   0	  $yg
node	90099		287.950	   0	  $yg
node	90100		288.000	   0	  $yg
node	90101		291.195	   0	  $yg
node	90102		294.390	   0	  $yg
node	90103		297.585	   0	  $yg
node	90104		300.780	   0	  $yg
node	90105		303.975	   0	  $yg
node	90106		307.170	   0	  $yg
node	90107		310.365	   0	  $yg
node	90108		313.560	   0	  $yg
node	90109		316.755	   0	  $yg
node	90110		319.950	   0	  $yg


#=========================================================
#               BEARING NODES        
#=========================================================
# Assume bearing distance 3.3m
#	   nodeTag		 (x)	    (y)       (z)
node	1101		 0.000	 	$Lb		$hcol
node	1102		 0.000	 	$Rb		$hcol
node	1103		31.950	 	$Lb		$hcol
node	1104		31.950	 	$Rb		$hcol
node	2101	 	 0.000		$Lb		$hcol
node	2102		 0.000		$Rb		$hcol
node	2103		31.950		$Lb		$hcol
node	2104		31.950		$Rb		$hcol
node	1105		32.000		$Lb		$hcol
node	1106		32.000		$Rb		$hcol
node	1107		63.950		$Lb		$hcol
node	1108		63.950		$Rb		$hcol
node	2105		32.000		$Lb		$hcol
node	2106		32.000		$Rb		$hcol
node	2107		63.950		$Lb		$hcol
node	2108		63.950		$Rb		$hcol
node	1109		64.000		$Lb		$hcol
node	1110		64.000		$Rb		$hcol
node	1111		95.950		$Lb		$hcol
node	1112		95.950		$Rb		$hcol
node	2109		64.000		$Lb		$hcol
node	2110		64.000		$Rb		$hcol
node	2111		95.950		$Lb		$hcol
node	2112		95.950		$Rb		$hcol
node	1113		96.000		$Lb		$hcol
node	1114		96.000		$Rb		$hcol
node	1115		127.950		$Lb		$hcol
node	1116		127.950		$Rb		$hcol
node	2113		96.000		$Lb		$hcol
node	2114		96.000		$Rb		$hcol
node	2115		127.950		$Lb		$hcol
node	2116		127.950		$Rb		$hcol
node	1117		128.000		$Lb		$hcol
node	1118		128.000		$Rb		$hcol
node	1119		159.950		$Lb		$hcol
node	1120		159.950		$Rb		$hcol
node	2117		128.000		$Lb		$hcol
node	2118		128.000		$Rb		$hcol
node	2119		159.950		$Lb		$hcol
node	2120		159.950		$Rb		$hcol
node	1121		160.000		$Lb		$hcol
node	1122		160.000		$Rb		$hcol
node	1123		191.950		$Lb		$hcol
node	1124		191.950		$Rb		$hcol
node	2121		160.000		$Lb		$hcol
node	2122		160.000		$Rb		$hcol
node	2123		191.950		$Lb		$hcol
node	2124		191.950		$Rb		$hcol
node	1125		192.000		$Lb		$hcol
node	1126		192.000		$Rb		$hcol
node	1127		223.950		$Lb		$hcol
node	1128		223.950		$Rb		$hcol
node	2125		192.000		$Lb		$hcol
node	2126		192.000		$Rb		$hcol
node	2127		223.950		$Lb		$hcol
node	2128		223.950		$Rb		$hcol
node	1129		224.000		$Lb		$hcol
node	1130		224.000		$Rb		$hcol
node	1131		255.950		$Lb		$hcol
node	1132		255.950		$Rb		$hcol
node	2129		224.000		$Lb		$hcol
node	2130		224.000		$Rb		$hcol
node	2131		255.950		$Lb		$hcol
node	2132		255.950		$Rb		$hcol
node	1133		256.000		$Lb		$hcol
node	1134		256.000		$Rb		$hcol
node	1135		287.950		$Lb		$hcol
node	1136		287.950		$Rb		$hcol
node	2133		256.000		$Lb		$hcol
node	2134		256.000		$Rb		$hcol
node	2135		287.950		$Lb		$hcol
node	2136		287.950		$Rb		$hcol
node	1137		288.000		$Lb		$hcol
node	1138		288.000		$Rb		$hcol
node	1139		319.950		$Lb		$hcol
node	1140		319.950		$Rb		$hcol
node	2137		288.000		$Lb		$hcol
node	2138		288.000		$Rb		$hcol
node	2139		319.950		$Lb		$hcol
node	2140		319.950		$Rb		$hcol

# Constraining DOF for bearing nodes
equalDOF	1101	2101	3	4	5	6
equalDOF	1102	2102	3	4	5	6
equalDOF	1103	2103	3	4	5	6
equalDOF	1104	2104	3	4	5	6
equalDOF	1105	2105	3	4	5	6
equalDOF	1106	2106	3	4	5	6
equalDOF	1107	2107	3	4	5	6
equalDOF	1108	2108	3	4	5	6
equalDOF	1109	2109	3	4	5	6
equalDOF	1110	2110	3	4	5	6
equalDOF	1111	2111	3	4	5	6
equalDOF	1112	2112	3	4	5	6
equalDOF	1113	2113	3	4	5	6
equalDOF	1114	2114	3	4	5	6
equalDOF	1115	2115	3	4	5	6
equalDOF	1116	2116	3	4	5	6
equalDOF	1117	2117	3	4	5	6
equalDOF	1118	2118	3	4	5	6
equalDOF	1119	2119	3	4	5	6
equalDOF	1120	2120	3	4	5	6
equalDOF	1121	2121	3	4	5	6
equalDOF	1122	2122	3	4	5	6
equalDOF	1123	2123	3	4	5	6
equalDOF	1124	2124	3	4	5	6
equalDOF	1125	2125	3	4	5	6
equalDOF	1126	2126	3	4	5	6
equalDOF	1127	2127	3	4	5	6
equalDOF	1128	2128	3	4	5	6
equalDOF	1129	2129	3	4	5	6
equalDOF	1130	2130	3	4	5	6
equalDOF	1131	2131	3	4	5	6
equalDOF	1132	2132	3	4	5	6
equalDOF	1133	2133	3	4	5	6
equalDOF	1134	2134	3	4	5	6
equalDOF	1135	2135	3	4	5	6
equalDOF	1136	2136	3	4	5	6
equalDOF	1137	2137	3	4	5	6
equalDOF	1138	2138	3	4	5	6
equalDOF	1139	2139	3	4	5	6
equalDOF	1140	2140	3	4	5	6


#=========================================================
#               COLUMN NODES            
#=========================================================

# Column 1
#		nodeTag		 (x)	  (y)   	  (z)
node	  111	   -0.025	   0     0
node	  112	   -0.025	   0 	 [expr 1*$hcol/4]
node	  113	   -0.025	   0 	 [expr 2*$hcol/4]
node	  114	   -0.025	   0 	 [expr 3*$hcol/4]
node	  115	   -0.025	   0 	 $hcol

# Column 2
#		nodeTag		 (x)	  (y)   (z)	
node	 211	   31.975	   0	 0
node	 212	   31.975	   0	 [expr 1*$hcol/4]
node	 213	   31.975	   0	 [expr 2*$hcol/4]
node	 214	   31.975	   0	 [expr 3*$hcol/4]
node	 215	   31.975	   0     $hcol

# Column 3		
node	 311	   63.975	   0	 0
node	 312	   63.975	   0	 [expr 1*$hcol/4]
node	 313	   63.975	   0	 [expr 2*$hcol/4]
node	 314	   63.975	   0	 [expr 3*$hcol/4]
node	 315	   63.975	   0	 $hcol

# Column 4				
node	 411	   95.975	   0	 0
node	 412	   95.975	   0	 [expr 1*$hcol/4]
node	 413	   95.975	   0	 [expr 2*$hcol/4]
node	 414	   95.975	   0	 [expr 3*$hcol/4]
node	 415	   95.975	   0	 $hcol

# Column 5				
node	 511	  127.975	   0	 0
node	 512	  127.975	   0	 [expr 1*$hcol/4]
node	 513	  127.975	   0	 [expr 2*$hcol/4]
node	 514	  127.975	   0	 [expr 3*$hcol/4]
node	 515	  127.975	   0	 $hcol

# Column 6				
node	 611	  159.975	   0	 0
node	 612	  159.975	   0	 [expr 1*$hcol/4]
node	 613	  159.975	   0	 [expr 2*$hcol/4]
node	 614	  159.975	   0	 [expr 3*$hcol/4]
node	 615	  159.975	   0	 $hcol

# Column 7	
node	 711	  191.975	   0	  0
node	 712	  191.975	   0	 [expr 1*$hcol/4]
node	 713	  191.975	   0	 [expr 2*$hcol/4]
node	 714	  191.975	   0	 [expr 3*$hcol/4]
node	 715	  191.975	   0	 $hcol

# Column 8			
node	 811	  223.975	   0	 0
node	 812	  223.975	   0	 [expr 1*$hcol/4]
node	 813	  223.975	   0	 [expr 2*$hcol/4]
node	 814	  223.975	   0	 [expr 3*$hcol/4]
node	 815	  223.975	   0	 $hcol

# Column 9				
node	 911	  255.975	   0	 0
node	 912	  255.975	   0	 [expr 1*$hcol/4]
node	 913	  255.975	   0	 [expr 2*$hcol/4]
node	 914	  255.975	   0	 [expr 3*$hcol/4]
node	 915	  255.975	   0	 $hcol

# Column 10	
node	 1011	  287.975	   0	 0
node	 1012	  287.975	   0	 [expr 1*$hcol/4]
node	 1013	  287.975	   0	 [expr 2*$hcol/4]
node	 1014	  287.975	   0	 [expr 3*$hcol/4]
node	 1015	  287.975	   0	 $hcol

# Column 11				
node	 1211	  319.975	   0	 0
node	 1212	  319.975	   0	 [expr 1*$hcol/4]
node	 1213	  319.975	   0	 [expr 2*$hcol/4]
node	 1214	  319.975	   0	 [expr 3*$hcol/4]
node	 1215	  319.975	   0	 $hcol


#=========================================================
#               FOOTING NODES
#=========================================================
# Assuming footing depth of 4

# Footing Center-of-Mass
#		nodeTag		 (x)	   (y)     (z)
node		1	   -0.025		0		$hf
node		2	   31.975	    0	    $hf
node	    3	   63.975	    0	    $hf
node	    4	   95.975	    0	    $hf
node	    5	  127.975	    0	    $hf
node	    6	  159.975	    0	    $hf
node	    7	  191.975	    0	    $hf
node	    8	  223.975	    0	    $hf
node	    9	  255.975	    0	    $hf
node	   10	  287.975	    0	    $hf
node	   11	  319.975	    0	    $hf

# Ground (Fixed)
#		nodeTag		 (x)	   (y)     (z)
node	   12	   -0.025	    0	    $hf
node	   13	   31.975	    0	    $hf
node	   14	   63.975	    0	    $hf
node	   15	   95.975	    0	    $hf
node	   16	  127.975	    0	    $hf
node	   17	  159.975	    0	    $hf
node	   18	  191.975	    0	    $hf
node	   19	  223.975	    0	    $hf
node	   20	  255.975	    0	    $hf
node	   21	  287.975	    0	    $hf
node	   22	  319.975	    0	    $hf


#=========================================================
#                GROUND RESTRAINTS
#=========================================================
fix	1   	0	0	1	1	1	1
fix	2   	0	0	1	1	1	1
fix	3   	0	0	1	1	1	1
fix	4   	0	0	1	1	1	1
fix	5   	0	0	1	1	1	1
fix	6   	0	0	1	1	1	1
fix	7   	0	0	1	1	1	1
fix	8   	0	0	1	1	1	1
fix	9   	0	0	1	1	1	1
fix	10   	0	0	1	1	1	1
fix	11   	0	0	1	1	1	1

fix	12   	1	1	1	1	1	1
fix	13   	1	1	1	1	1	1
fix	14   	1	1	1	1	1	1
fix	15   	1	1	1	1	1	1
fix	16   	1	1	1	1	1	1
fix	17   	1	1	1	1	1	1
fix	18   	1	1	1	1	1	1
fix	19   	1	1	1	1	1	1
fix	20   	1	1	1	1	1	1
fix	21   	1	1	1	1	1	1
fix	22   	1	1	1	1	1	1


#===========================================================================================================================================================================================
#               	 BRIDGE SYSTEM ELEMENTS
#===========================================================================================================================================================================================

#=========================================================
#             		RIGID ELEMENTS                  
#=========================================================
set Ar     1e3
set Er     1e8
set Jr     1e6
set Gr     1e8
set Ir     1e5

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   5
geomTransf Linear  $geomTransf  1 0 0 

# Footing Elements
# 							eleTag	    iNode   	jNode	 	 A		E	   G 	 J      Iy      Iz    transfTag
element elasticBeamColumn    3000   	   1     	 111        $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3001          2     	 211        $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3002   	   3     	 311    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3003   	   4     	 411    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3004   	   5     	 511    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3005   	   6     	 611    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3006   	   7     	 711    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3007   	   8     	 811    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3008   	   9     	 911    	$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3009   	  10        1011   		$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    3010   	  11     	1211   		$Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   6
geomTransf Linear  $geomTransf  0 0 1 

# Column-Bearing Connecting Elements
# 							eleTag	    iNode	    jNode	 	 A		E	   G 	 J      Iy     Iz    transfTag
element	elasticBeamColumn	3011		115			1101		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3012		215			1103		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3013		215			1105		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3014		315			1107		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3015		315			1109		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3016		415			1111		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3017		415			1113		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3018		515			1115		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3019		515			1117		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3020		615			1119		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3021		615			1121		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3022		715			1123		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3023		715			1125		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3024		815			1127		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3025		815			1129		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3026		915			1131		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3027		915			1133		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3028		1015		1135		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3029		1015		1137		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3030		1215		1139		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf

element	elasticBeamColumn	3031		115			1102		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3032		215			1104		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3033		215			1106		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3034		315			1108		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3035		315			1110		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3036		415			1112		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3037		415			1114		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3038		515			1116		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3039		515			1118		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3040		615			1120		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3041		615			1122		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3042		715			1124		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3043		715			1126		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3044		815			1128		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3045		815			1130		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3046		915			1132		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3047		915			1134		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3048		1015		1136		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3049		1015		1138		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf
element	elasticBeamColumn	3050		1215		1140		$Ar	   $Er	  $Gr	$Jr	   $Ir	  $Ir	$geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   7
geomTransf Linear  $geomTransf  1 0 0 

# Girder-Bearing Connecting Elements
# 							eleTag	    iNode	    jNode	 	 A		E	   G 	 J      Iy      Iz    transfTag
element	elasticBeamColumn	3051		90001		2101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3052		90011		2103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3053		90012		2105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3054		90022		2107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3055		90023		2109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3056		90033		2111		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3057		90034		2113		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3058		90044		2115		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3059		90045		2117		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3060		90055		2119		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3061		90056		2121		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3062		90066		2123		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3063		90067		2125		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3064		90077		2127		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3065		90078		2129		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3066		90088		2131		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3067		90089		2133		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3068		90099		2135		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3069		90100		2137		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3070		90110		2139		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

element	elasticBeamColumn	3071		90001		2102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3072		90011		2104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3073		90012		2106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3074		90022		2108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3075		90023		2110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3076		90033		2112		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3077		90034		2114		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3078		90044		2116		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3079		90045		2118		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3080		90055		2120		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3081		90056		2122		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3082		90066		2124		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3083		90067		2126		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3084		90077		2128		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3085		90078		2130		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3086		90088		2132		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3087		90089		2134		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3088		90099		2136		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3089		90100		2138		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	3090		90110		2140		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   8
geomTransf Linear  $geomTransf  1 0 0 

# Girder-Track System Connecting Elements
# 							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3091		90001		50001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3092		90002		50002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3093		90003		50003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3094		90004		50004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3095		90005		50005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3096		90006		50006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3097		90007		50007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3098		90008		50008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3099		90009		50009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3100		90010		50010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3101		90011		50011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3102		90012		50012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3103		90013		50013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3104		90014		50014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3105		90015		50015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3106		90016		50016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3107		90017		50017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3108		90018		50018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3109		90019		50019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3110		90020		50020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3111		90021		50021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3112		90022		50022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3113		90023		50023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3114		90024		50024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3115		90025		50025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3116		90026		50026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3117		90027		50027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3118		90028		50028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3119		90029		50029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3120		90030		50030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3121		90031		50031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3122		90032		50032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3123		90033		50033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3124		90034		50034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3125		90035		50035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3126		90036		50036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3127		90037		50037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3128		90038		50038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3129		90039		50039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3130		90040		50040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3131		90041		50041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3132		90042		50042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3133		90043		50043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3134		90044		50044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3135		90045		50045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3136		90046		50046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3137		90047		50047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3138		90048		50048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3139		90049		50049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3140		90050		50050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3141		90051		50051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3142		90052		50052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3143		90053		50053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3144		90054		50054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3145		90055		50055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3146		90056		50056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3147		90057		50057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3148		90058		50058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3149		90059		50059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3150		90060		50060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3151		90061		50061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3152		90062		50062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3153		90063		50063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3154		90064		50064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3155		90065		50065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3156		90066		50066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3157		90067		50067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3158		90068		50068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3159		90069		50069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3160		90070		50070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3161		90071		50071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3162		90072		50072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3163		90073		50073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3164		90074		50074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3165		90075		50075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3166		90076		50076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3167		90077		50077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3168		90078		50078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3169		90079		50079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3170		90080		50080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3171		90081		50081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3172		90082		50082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3173		90083		50083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3174		90084		50084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3175		90085		50085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3176		90086		50086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3177		90087		50087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3178		90088		50088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3179		90089		50089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3180		90090		50090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3181		90091		50091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3182		90092		50092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3183		90093		50093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3184		90094		50094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3185		90095		50095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3186		90096		50096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3187		90097		50097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3188		90098		50098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3189		90099		50099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3190		90100		50100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3191		90101		50101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3192		90102		50102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3193		90103		50103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn 	 3194		90104		50104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3195		90105		50105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3196		90106		50106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3197		90107		50107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3198		90108		50108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3199		90109		50109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3200		90110		50110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

element	elasticBeamColumn	 3201		60001		90001		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3202		60002		90002		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3203		60003		90003		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3204		60004		90004		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3205		60005		90005		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3206		60006		90006		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3207		60007		90007		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3208		60008		90008		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3209		60009		90009		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3210		60010		90010		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3211		60011		90011		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3212		60012		90012		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3213		60013		90013		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3214		60014		90014		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3215		60015		90015		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3216		60016		90016		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3217		60017		90017		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3218		60018		90018		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3219		60019		90019		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3220		60020		90020		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3221		60021		90021		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3222		60022		90022		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3223		60023		90023		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3224		60024		90024		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3225		60025		90025		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3226		60026		90026		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3227		60027		90027		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3228		60028		90028		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3229		60029		90029		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3230		60030		90030		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3231		60031		90031		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3232		60032		90032		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3233		60033		90033		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3234		60034		90034		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3235		60035		90035		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3236		60036		90036		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3237		60037		90037		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3238		60038		90038		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3239		60039		90039		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3240		60040		90040		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3241		60041		90041		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3242		60042		90042		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3243		60043		90043		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3244		60044		90044		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3245		60045		90045		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3246		60046		90046		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3247		60047		90047		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3248		60048		90048		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3249		60049		90049		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3250		60050		90050		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3251		60051		90051		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3252		60052		90052		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3253		60053		90053		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3254		60054		90054		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3255		60055		90055		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3256		60056		90056		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3257		60057		90057		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3258		60058		90058		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3259		60059		90059		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3260		60060		90060		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3261		60061		90061		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3262		60062		90062		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3263		60063		90063		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3264		60064		90064		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3265		60065		90065		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3266		60066		90066		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3267		60067		90067		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3268		60068		90068		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3269		60069		90069		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3270		60070		90070		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3271		60071		90071		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3272		60072		90072		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3273		60073		90073		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3274		60074		90074		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3275		60075		90075		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3276		60076		90076		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3277		60077		90077		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3278		60078		90078		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3279		60079		90079		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3280		60080		90080		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3281		60081		90081		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3282		60082		90082		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3283		60083		90083		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3284		60084		90084		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3285		60085		90085		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3286		60086		90086		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3287		60087		90087		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3288		60088		90088		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3289		60089		90089		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3290		60090		90090		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3291		60091		90091		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3292		60092		90092		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3293		60093		90093		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3294		60094		90094		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3295		60095		90095		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3296		60096		90096		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3297		60097		90097		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3298		60098		90098		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3299		60099		90099		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3300		60100		90100		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3301		60101		90101		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3302		60102		90102		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3303		60103		90103		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3304		60104		90104		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3305		60105		90105		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3306		60106		90106		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3307		60107		90107		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3308		60108		90108		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3309		60109		90109		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf
element	elasticBeamColumn	 3310		60110		90110		$Ar		$Er		$Gr		$Jr		$Ir		$Ir		$geomTransf

#===========================================================================================================================================================================================
#            	 BRIDGE SYSTEM ELEMENTS                   
#===========================================================================================================================================================================================

#=========================================================
#            	 GIRDER SECTION & ELEMENTS                   
#=========================================================
set geomTransf   9
geomTransf Linear $geomTransf 0 1 0  

set Ad   9.06;				# As given in Li et al.'s study, (m2)
set Ed   2.45e7; 		  	# Decreased from 3.45e7 to be conservative, (KN/m2)
set Gd   1.44e7;			# As given in Li et al.'s study, (KN/m2)
set Jd   22.6;				# As given in Li et al.'s study, (KN-m)
set Iyd  [expr 0.7*11.0]; 	# Decreased by 30% to be conservative, (m4)
set Izd  [expr 0.7*94.8]; 	# Decreased by 30% to be conservative, (m4)

# 1							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3311		90001		90002		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3312		90002		90003		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3313		90003		90004		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3314		90004		90005		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3315		90005		90006		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3316		90006		90007		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3317		90007		90008		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3318		90008		90009		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3319		90009		90010		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3320		90010		90011		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 2							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3322		90012		90013		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3323		90013		90014		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3324		90014		90015		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3325		90015		90016		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3326		90016		90017		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3327		90017		90018		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3328		90018		90019		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3329		90019		90020		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3330		90020		90021		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3331		90021		90022		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 3							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3333		90023		90024		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3334		90024		90025		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3335		90025		90026		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3336		90026		90027		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3337		90027		90028		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3338		90028		90029		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3339		90029		90030		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3340		90030		90031		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3341		90031		90032		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3342		90032		90033		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 4							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3344		90034		90035		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3345		90035		90036		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3346		90036		90037		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3347		90037		90038		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3348		90038		90039		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3349		90039		90040		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3350		90040		90041		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3351		90041		90042		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3352		90042		90043		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3353		90043		90044		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 5							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3355		90045		90046		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3356		90046		90047		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3357		90047		90048		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3358		90048		90049		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3359		90049		90050		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3360		90050		90051		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3361		90051		90052		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3362		90052		90053		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3363		90053		90054		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3364		90054		90055		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 6							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3366		90056		90057		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3367		90057		90058		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3368		90058		90059		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3369		90059		90060		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3370		90060		90061		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3371		90061		90062		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3372		90062		90063		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3373		90063		90064		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3374		90064		90065		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3375		90065		90066		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 7							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3377		90067		90068		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3378		90068		90069		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3379		90069		90070		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3380		90070		90071		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3381		90071		90072		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3382		90072		90073		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3383		90073		90074		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3384		90074		90075		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3385		90075		90076		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3386		90076		90077		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 8							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3388		90078		90079		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3389		90079		90080		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3390		90080		90081		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3391		90081		90082		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3392		90082		90083		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3393		90083		90084		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3394		90084		90085		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3395		90085		90086		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3396		90086		90087		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3397		90087		90088		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 9							eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3399		90089		90090		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3400		90090		90091		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3401		90091		90092		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3402		90092		90093		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3403		90093		90094		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3404		90094		90095		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3405		90095		90096		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3406		90096		90097		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3407		90097		90098		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3408		90098		90099		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
# 10						eleTag	    iNode	    jNode	 	 A		 E		 G 	     J       Iy      Iz    	 transfTag
element	elasticBeamColumn	 3410		90100		90101		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3411		90101		90102		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3412		90102		90103		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3413		90103		90104		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3414		90104		90105		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3415		90105		90106		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3416		90106		90107		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3417		90107		90108		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3418		90108		90109		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf
element	elasticBeamColumn	 3419		90109		90110		$Ad		$Ed		$Gd		$Jd		$Iyd	$Izd	$geomTransf


#=========================================================
#                  COLUMN MATERIAL                         
#=========================================================
# Nominal concrete compressive strength
set fc 		28890;		                # Concrete compressive strength, (KN/m2)
set nu      0.2;                        # Concrete Poisson's ratio
set Ec 	[expr 4700*sqrt($fc/1e3)*1e3];	# Concrete elastic modulus, (KN/m2)
set Gc 	[expr $Ec/(2*(1+$nu))];	    	# Concrete shear modulus, (KN/m2)

# Cover concrete (un-confined) 
set fc1U 	$fc;		    			# Unconfined concrete, maximum stress
set eps1U  -0.003;			    		# Strain at maximum strength of unconfined concrete
set fc2U 	[expr 0.2*$fc1U];			# Ultimate stress, (KN/m2)
set eps2U  -0.01;			    		# Strain at ultimate stress
set lambda  0.1;						# Ratio between unloading slope at $eps2 and initial slope $Ec

# Core concrete (confined) 
set Kfc 	1.3;				        # Ratio of confined to unconfined concrete strength
set fc1C 	[expr $Kfc*$fc]    ;		# Confined concrete (Mander model), maximum stress, (KN/m2)
set eps1C	[expr 2.*$fc1C/$Ec];	    # Strain at maximum stress 
set fc2C 	[expr 0.2*$fc1C]   ;		# Ultimate stress, (KN/m2)
set eps2C 	[expr 5*$eps1C]    ;		# Strain at ultimate stress 

# Tensile-strength properties
set ftC     [expr -0.14*$fc1C];			# Tensile strength + tension confined concrete, (KN/m2)
set ftU     [expr -0.14*$fc1U];			# Tensile strength + tension unconfined concrete, (KN/m2)
set Ets     [expr $ftU/0.002];			# Tension softening stiffness, (KN/m2)

# Reinforcing steel
set fys 	483510; 					# Reinforcing steel yield strength, (KN/m2)
set fsu 	725265; 					# Reinforcing steel ultimate strength, (KN/m2)
set Es  	200000000; 					# Reinforcing steel elastic modulus, (KN/m2)
set b   	0.005;						# Strain-hardening ratio
set R0		15;							# Parameters to control the transition from elastic to plastic branches
set cR1		0.925;						# Parameters to control the transition from elastic to plastic branches
set cR2		0.15;						# Parameters to control the transition from elastic to plastic branches

# ------------------------------------------------------------------------------

# General Cross-Section	    matTag	  E
uniaxialMaterial Elastic	   5     1e10

# Cover Concrete			matTag	 fpc     epsc    fpcu   epsU     lambda    ft    Ets
uniaxialMaterial Concrete02    1 	$fc1C   $eps1C 	$fc2C  $eps2C 	$lambda   $ftC 	$Ets

# Core Concrete			    matTag	 fpc     epsc    fpcu   epsU     lambda    ft    Ets
uniaxialMaterial Concrete02    2 	$fc1U   $eps1U 	$fc2U  $eps2U 	$lambda   $ftU 	$Ets

# Reinforcing Steel		    matTag	 Fy      E       b      R0     cR1    cR2
uniaxialMaterial Steel02       3    $fys    $Es     $b     $R0    $cR1   $cR2


#==========================================================================
#                       COLUMN SECTION                                     
#==========================================================================
set Dtran 12.7e-3; 	# Transverse reinforcement diameter (m)
set Abar  1006e-3;	# Longitudinal reinforcement area (m2)
set Dbar  35.81e-3; # Longitudinal reinforcement diameter (m)
set Nbar1  28; 		# Number of bars on short end
set Nbar2  60; 		# Number of bars on long end
set cc    0.04; 	# Assumption of clear cover (m)
set ycol  5.434; 	# Y dimension of column (m)
set zcol  2.50; 	# Z dimension of column (m)
set divy  6; 		# Number of subdivisions in the local y-direction
set divz  3; 		# Number of subdivisions in the local z-direction
set s [expr (($ycol - 2*($cc + $Dtran) - $Dbar)/($Nbar2))]; # Spacing of bars in the y-direction (m)

# ------------------------------------------------------------------------------

# Coordinates within the column cross-section to define section
set yy1 [expr -($ycol/2 - ($cc + $Dtran))]
set zz1 [expr -($zcol/2 - ($cc + $Dtran))]
set yy2 [expr ($ycol/2 - ($cc + $Dtran))]
set zz2 [expr ($zcol/2 - ($cc + $Dtran))]

set y1 [expr -($ycol/2 - ($cc + $Dtran + 0.5*$Dbar))]
set z1 [expr -($zcol/2 - ($cc + $Dtran + 0.5*$Dbar))]
set y2 [expr -($ycol/2 - ($cc + $Dtran + 0.5*$Dbar-$s))]
set z2 $z1 
set y3 [expr ($ycol/2 - ($cc + $Dtran + 0.5*$Dbar-$s))]
set z3 $z1
set y4 [expr ($ycol/2 - ($cc + $Dtran + 0.5*$Dbar))]
set z4 $z1
set y5 $y1
set z5 [expr ($zcol/2 - ($cc + $Dtran + 0.5*$Dbar))]
set y6 $y2
set z6 $z5 
set y7 $y3 
set z7 $z5
set y8 $y4
set z8 $z5

# ------------------------------------------------------------------------------

# Cross-Section of Column

section Fiber 1 -GJ 0 {    

# Cover concrete      tag      divY       divZ          yI                  zI                 yJ                zJ 
patch rect             1      $divy      $divz     [expr -$ycol/2]    [expr -$zcol/2]    [expr $ycol/2]    [expr $zcol/2] 

# Core concrete       tag         divY                  divZ          		yI        zI        yJ        zJ 
patch rect             2      [expr (2*$divy)]     [expr (2*$divz)]        $yy1    	 $zz1      $yy2      $zz2

# Reinforcing Steel   tag     Nbar     Abar  	yStart		zStart		yEnd		zEnd
layer straight         3     $Nbar1   $Abar  	  $y1 		 $z1  		 $y5 		 $y5

layer straight         3     $Nbar1   $Abar       $y4  		 $z4  		 $y8 		 $y8 

layer straight         3     $Nbar2   $Abar       $y2  		 $z2  		 $y3  		 $y3

layer straight         3     $Nbar2   $Abar       $y6  		 $z6  		 $y7  		 $y7 
} 

#					secTag	  matTag	dof1	sectionTag
section Aggregator   100        5        T      -section 1

#=========================================================
#                  COLUMN ELEMENTS                          
#=========================================================
set n 5  
set geomTransf   10
geomTransf PDelta  $geomTransf 1 0 0  
 
#					   	eleTag	iNode	jNode  numIntgrPts	secTag	 transfTag
element dispBeamColumn   3420  	 111  	 112       $n  		  100    $geomTransf
element dispBeamColumn   3421  	 112     113       $n         100    $geomTransf 
element dispBeamColumn   3422    113   	 114       $n         100    $geomTransf 
element dispBeamColumn   3423    114     115       $n         100    $geomTransf 

element dispBeamColumn   3424    211     212       $n  		  100    $geomTransf
element dispBeamColumn   3425    212     213       $n		  100    $geomTransf 
element dispBeamColumn   3426    213     214       $n		  100    $geomTransf 
element dispBeamColumn   3427    214     215       $n		  100    $geomTransf 

element dispBeamColumn   3428    311     312       $n		  100    $geomTransf
element dispBeamColumn   3429    312     313       $n		  100    $geomTransf 
element dispBeamColumn   3430    313     314       $n		  100    $geomTransf 
element dispBeamColumn   3431    314     315       $n		  100    $geomTransf 

element dispBeamColumn   3432    411     412       $n		  100    $geomTransf
element dispBeamColumn   3433    412     413       $n		  100    $geomTransf 
element dispBeamColumn   3434    413     414       $n		  100    $geomTransf 
element dispBeamColumn   3435    414     415       $n		  100    $geomTransf 

element dispBeamColumn   3436    511     512       $n		  100    $geomTransf
element dispBeamColumn   3437    512     513       $n		  100    $geomTransf 
element dispBeamColumn   3438    513     514       $n		  100    $geomTransf 
element dispBeamColumn   3439    514     515       $n		  100    $geomTransf 

element dispBeamColumn   3440    611     612       $n		  100    $geomTransf
element dispBeamColumn   3441    612     613       $n		  100    $geomTransf 
element dispBeamColumn   3442    613     614       $n		  100    $geomTransf 
element dispBeamColumn   3443    614     615       $n		  100    $geomTransf 

element dispBeamColumn   3444    711     712       $n		  100    $geomTransf
element dispBeamColumn   3445    712     713       $n		  100    $geomTransf 
element dispBeamColumn   3446    713     714       $n		  100    $geomTransf 
element dispBeamColumn   3447    714     715       $n		  100    $geomTransf 

element dispBeamColumn   3448    811     812       $n		  100    $geomTransf
element dispBeamColumn   3449    812     813       $n		  100    $geomTransf 
element dispBeamColumn   3450    813     814       $n		  100    $geomTransf 
element dispBeamColumn   3451    814     815       $n		  100    $geomTransf 

element dispBeamColumn   3452    911     912       $n		  100    $geomTransf
element dispBeamColumn   3453    912     913       $n		  100    $geomTransf 
element dispBeamColumn   3454    913     914       $n		  100    $geomTransf 
element dispBeamColumn   3455    914     915       $n		  100    $geomTransf 

element dispBeamColumn   3456   1011    1012       $n		  100    $geomTransf
element dispBeamColumn   3457   1012    1013       $n		  100    $geomTransf 
element dispBeamColumn   3458   1013    1014       $n		  100    $geomTransf 
element dispBeamColumn   3459   1014    1015       $n		  100    $geomTransf 

element dispBeamColumn   3460   1211    1212       $n		  100    $geomTransf
element dispBeamColumn   3461   1212    1213       $n		  100    $geomTransf 
element dispBeamColumn   3462   1213    1214       $n		  100    $geomTransf 
element dispBeamColumn   3463   1214    1215       $n		  100    $geomTransf 


#=========================================================
#      GENERATE MATERIAL AND ELEMENTS FOR FOUNDATIONS       
#=========================================================
# From Abassi (California Soil) imitating a pinned connection
# Foundation Translational  Springs

set KGh  155440.00
uniaxialMaterial Elastic 8 $KGh

# Foundation Rotational  Springs
set KGr  0.00
uniaxialMaterial Elastic 9 $KGr

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element  zeroLength  	3464      12   	  1    	  -mat 8 8 9 9  	-dir 1 2 4 5       
element  zeroLength 	3465      13      2    	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength 	3466      14      3       -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength 	3467      15      4    	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3468      16      5   	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3469      17      6   	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3470      18      7   	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3471      19      8       -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3472      20      9   	  -mat 8 8 9 9  	-dir 1 2 4 5 
element  zeroLength  	3473      21     10   	  -mat 8 8 9 9  	-dir 1 2 4 5          
element  zeroLength  	3474      22     11   	  -mat 8 8 9 9  	-dir 1 2 4 5 



#=========================================================
#                  BEARING ELEMENTS
#=========================================================
# Fixed Bearing
set Fybear1  5000
set dybear1  0.002
set K1bear1  [expr $Fybear1/$dybear1]
uniaxialMaterial Steel01 300 $Fybear1 $K1bear1 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element  zeroLength  	3475  	 1101    2101     -mat 300 300 		-dir 1 2 
element  zeroLength  	3476  	 1104    2104     -mat 300 300 		-dir 1 2 
element  zeroLength  	3477  	 1105    2105     -mat 300 300 		-dir 1 2  
element  zeroLength  	3478  	 1108    2108     -mat 300 300 		-dir 1 2  
element  zeroLength  	3479  	 1109    2109     -mat 300 300 		-dir 1 2  
element  zeroLength  	3480  	 1112    2112     -mat 300 300 		-dir 1 2  
element  zeroLength  	3481  	 1113    2113     -mat 300 300 		-dir 1 2  
element  zeroLength  	3482  	 1116    2116     -mat 300 300 		-dir 1 2  
element  zeroLength  	3483  	 1117    2117     -mat 300 300 		-dir 1 2  
element  zeroLength  	3484  	 1120    2120     -mat 300 300 		-dir 1 2  
element  zeroLength  	3485  	 1121    2121     -mat 300 300 		-dir 1 2  
element  zeroLength  	3486  	 1124    2124     -mat 300 300 		-dir 1 2  
element  zeroLength  	3487  	 1125    2125     -mat 300 300 		-dir 1 2  
element  zeroLength  	3488  	 1128    2128     -mat 300 300 		-dir 1 2  
element  zeroLength  	3489  	 1129    2129     -mat 300 300 		-dir 1 2  
element  zeroLength  	3490  	 1132    2132     -mat 300 300 		-dir 1 2 
element  zeroLength  	3491  	 1133    2133     -mat 300 300 		-dir 1 2  
element  zeroLength  	3492  	 1136    2136     -mat 300 300 		-dir 1 2  
element  zeroLength  	3493  	 1137    2137     -mat 300 300 		-dir 1 2  
element  zeroLength  	3494  	 1140    2140     -mat 300 300 		-dir 1 2  

# ------------------------------------------------------------------------------

# Sliding Bearing
set Fybear2  470
set dybear2  0.002
set K1bear2  [expr $Fybear2/$dybear2]
uniaxialMaterial Steel01 400 $Fybear2 $K1bear2 0.0

#					   eleTag	iNode	jNode	  -mat matTag1...	-dir dir1...
element  zeroLength 	3495  	 1102    2102     -mat 400 400 		-dir 1 2 
element  zeroLength  	3496  	 1103    2103     -mat 400 400 		-dir 1 2 
element  zeroLength  	3497   	 1106    2106     -mat 400 400 		-dir 1 2 
element  zeroLength  	3498  	 1107    2107     -mat 400 400 		-dir 1 2  
element  zeroLength  	3499   	 1110    2110     -mat 400 400 		-dir 1 2 
element  zeroLength  	3500  	 1111    2111     -mat 400 400 		-dir 1 2 
element  zeroLength  	3501   	 1114    2114     -mat 400 400 		-dir 1 2 
element  zeroLength  	3502  	 1115    2115     -mat 400 400 		-dir 1 2
element  zeroLength  	3503   	 1118    2118     -mat 400 400 		-dir 1 2 
element  zeroLength  	3504  	 1119    2119     -mat 400 400 		-dir 1 2 
element  zeroLength  	3505   	 1122    2122     -mat 400 400 		-dir 1 2
element  zeroLength  	3506  	 1123    2123     -mat 400 400 		-dir 1 2 
element  zeroLength  	3507   	 1126    2126     -mat 400 400 		-dir 1 2 
element  zeroLength  	3508  	 1127    2127     -mat 400 400 		-dir 1 2 
element  zeroLength  	3509   	 1130    2130     -mat 400 400 		-dir 1 2 
element  zeroLength  	3510  	 1131    2131     -mat 400 400 		-dir 1 2  
element  zeroLength  	3511   	 1134    2134     -mat 400 400 		-dir 1 2 
element  zeroLength  	3512  	 1135    2135     -mat 400 400 		-dir 1 2 
element  zeroLength  	3513   	 1138    2138     -mat 400 400 		-dir 1 2 
element  zeroLength  	3514  	 1139    2139     -mat 400 400 		-dir 1 2 


#=============================================================================================================
#                	 BRIDGE SYSTEM MASS
#=============================================================================================================

#=========================================================
#                 	 DECK MASSES
#=========================================================
# Girder
set mass    63.7359
set massxx 159.1817
set massyy  61.1692
set masszz 189.1868

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	90001	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90003	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90004	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90006	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90008	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90010	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90016	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90017	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90018	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90019	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90020	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90023	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90024	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90025	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90026	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90027	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90028	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90029	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90030	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90033	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90034	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90035	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90036	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90037	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90038	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90039	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90040	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90043	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90044	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90045	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90046	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90047	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90048	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90049	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90050	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90053	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90054	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90055	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90056	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90057	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90058	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90059	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90060	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90063	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90064	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90065	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90066	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90067	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90068	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90069	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90070	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90073	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90074	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90075	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90076	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90077	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90078	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90079	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90080	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90083	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90084	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90085	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90086	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90087	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90088	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90089	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90090	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90093	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90094	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90095	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90096	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90097	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90098	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90099	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90100	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90102	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90103	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90104	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90105	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90106	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90107	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90108	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90109	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	90110	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#=========================================================
#                  COLUMN MASSES
#=========================================================
# Column
set mass   88.0308
set massxx 300.1776
set massyy 129.4099
set masszz 262.4664

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	111		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	112		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	113		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	114		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	115		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	211		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	212		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	213		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	214		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	215		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	311		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	312		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	313		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	314		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	315		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	411		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	412		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	413		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	414		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	415		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	511		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	512		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	513		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	514		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	515		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	611		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	612		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	613		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	614		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	615		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	711		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	712		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	713		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	714		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	715		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	811		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	812		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	813		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	814		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	815		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	911		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	912		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	913		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	914		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	915		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1011 	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1012 	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1014	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1211	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1212	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1213	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1214	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	1215	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#=========================================================
#                  	FOUNDATION MASSES
#=========================================================
# Foundation
set mass    629.7408
set massxx  7859.6900
set massyy  7859.6900
set masszz 14122.9870

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	1		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	2		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	3		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	4		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	5		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	6		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass    7		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	8		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	9		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	10		$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	11		$mass	$mass	$mass	$massxx	  $massyy	$masszz


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

#===========================================================================================================================================================================
#             	   	TRAIN SYSTEM
#===========================================================================================================================================================================

# Train Vertical Dimensions
set hpm   1.720; 	# Height of centroid: Power car
set hcm   1.627; 	# Height of centroid: Passenger car
set hb    0.560; 	# Height of bogie COM assumption
set hp    0.605;	# Vertical distance from top of primary suspension to power car-body COM (Given in reference study)
set hm    0.420; 	# Vertical distance from top of primary suspension to extreme passenger car-body COM (Given in reference study)
set hc    0.508; 	# Vertical distance from top of primary suspension to intermediate passenger car-body COM (Given in reference study)

# Train Longitudinal Dimensions
set Lp  14.000; 	# Length of power car (Given in reference study)
set Lm  18.700; 	# Length of extreme passenger car (Given in reference study)
set Lc  18.700; 	# Length of intermediate passenger car (Given in reference study)
set LT 193.150;     # Total length of train system

set w 	 3.000; 	# Distance between same bogie axle wheels in the x-direction (Given in reference study)
set wp   3.275;     # Distance between the power car axle wheel and extreme passenger car axle wheel (Given in reference study)
set x  -33.175; 	# Location of last axle wheel node, depends on load case

# ------------------------------------------------------------------------------------------------------------------------------------------------------------
# Train nodes starting with 7 is for the right half of the train, ie. wheels, bogies, suspension arms
# Train nodes starting with 8 is for the left half of the train, ie. wheels, bogies, suspension arms
# Train nodes starting with 6 is for the center of the train, ie. center of bogies, suspension arms, car-bodies

# Power Car
# 	   NodeTag      	  (X)					 	(Y)		(Z)
#node	70011		$x								$R1		$hr; 					# Wheel for bogie 1
#node	70012		[expr $x + $w]					$R1		$hr; 					# Wheel for bogie 1
#node	80011		$x								$R2		$hr; 					# Wheel for bogie 1
#node	80012		[expr $x + $w]					$R2		$hr; 					# Wheel for bogie 1

#node	71011		$x								$R1		[expr $hr + $hb]; 		# Bogie 1
#node	71012		[expr $x + $w/2]				$R1		[expr $hr + $hb]; 		# Bogie 1
#node	71013		[expr $x + $w]					$R1		[expr $hr + $hb]; 		# Bogie 1

#node	610012		[expr $x + $w/2]				$R		[expr $hr + $hb]; 		# Bogie 1

#node	81011		$x								$R2		[expr $hr + $hb]; 		# Bogie 1
#node	81012		[expr $x + $w/2]				$R2		[expr $hr + $hb]; 		# Bogie 1
#node	81013		[expr $x + $w]					$R2		[expr $hr + $hb]; 		# Bogie 1

#node	620012		[expr $x + $w/2]				$R		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 1
#node	720012		[expr $x + $w/2]				$R1		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 1
#node	820012		[expr $x + $w/2]				$R2		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 1

#node	70021		[expr $x + $Lp]					$R1		$hr; 					# Wheel for bogie 2
#node	70022		[expr $x + ($Lp + $w)]			$R1		$hr; 					# Wheel for bogie 2
#node	80021		[expr $x + $Lp]					$R2		$hr; 					# Wheel for bogie 2
#node	80022		[expr $x + ($Lp + $w)]			$R2		$hr; 					# Wheel for bogie 2

#node	71021		[expr $x + $Lp]					$R1		[expr $hr + $hb]; 		# Bogie 2
#node	71022		[expr $x + $Lp + $w/2]			$R1		[expr $hr + $hb]; 		# Bogie 2
#node	71023		[expr $x + ($Lp + $w)]			$R1		[expr $hr + $hb]; 		# Bogie 2

#node	610022		[expr $x + $Lp + $w/2]			$R		[expr $hr + $hb]; 		# Bogie 2

#node	81021		[expr $x + $Lp]					$R2		[expr $hr + $hb]; 		# Bogie 2
#node	81022		[expr $x + $Lp + $w/2]			$R2		[expr $hr + $hb]; 		# Bogie 2
#node	81023		[expr $x + ($Lp + $w)]			$R2		[expr $hr + $hb]; 		# Bogie 2

#node	620022		[expr $x + $Lp + $w/2]			$R		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 2
#node	720022		[expr $x + $Lp + $w/2]			$R1		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 2
#node	820022		[expr $x + $Lp + $w/2]			$R2		[expr $hr + $hpm - $hp];  # Primary Suspension for bogie 2

#node	63001		[expr $x + $w/2]				$R		[expr $hr + $hpm]; 		# Car Body 1
#node	63002		[expr $x + $w/2 + $Lp/2]		$R		[expr $hr + $hpm]; 		# Car Body 1 (COM)
#node	63003		[expr $x + $Lp + $w/2]			$R		[expr $hr + $hpm]; 		# Car Body 1

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Extreme Passenger Car
# 	   NodeTag      	  (X)					 			(Y)		(Z)
#node	70031	[expr $x + ($Lp + $w + $wp)]				$R1		$hr; 					# Wheel for bogie 3
#node	70032	[expr $x + ($Lp + 2*$w + $wp)]				$R1		$hr; 					# Wheel for bogie 3

#node	80031	[expr $x + ($Lp + $w + $wp)]				$R2		$hr; 					# Wheel for bogie 3
#node	80032	[expr $x + ($Lp + 2*$w + $wp)]				$R2		$hr; 					# Wheel for bogie 3

#node	71031	[expr $x + ($Lp + $w + $wp)]				$R1		[expr $hr + $hb]; 		# Bogie 3
#node	71032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R1		[expr $hr + $hb]; 		# Bogie 3
#node	71033	[expr $x + ($Lp + 2*$w + $wp)]				$R1		[expr $hr + $hb]; 		# Bogie 3

#node	610032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R		[expr $hr + $hb]; 		# Bogie 3

#node	81031	[expr $x + ($Lp + $w + $wp)]				$R2		[expr $hr + $hb]; 		# Bogie 3
#node	81032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R2		[expr $hr + $hb]; 		# Bogie 3
#node	81033	[expr $x + ($Lp + 2*$w + $wp)]				$R2		[expr $hr + $hb]; 		# Bogie 3

node	70041	[expr $x + ($Lp + $w + $wp + $Lm)]			$R1		$hr; 					# Wheel for bogie 4
node	80041	[expr $x + ($Lp + $w + $wp + $Lm)]			$R2		$hr; 					# Wheel for bogie 4

node	71041	[expr $x + ($Lp + $w + $wp + $Lm)]			$R1		[expr $hr + $hb];		# Bogie 4
node	81041	[expr $x + ($Lp + $w + $wp + $Lm)]			$R2		[expr $hr + $hb]; 		# Bogie 4

#node	620032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R		[expr $hr + $hpm - $hm];  # Primary Suspension for bogie 3
#node	720032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R1		[expr $hr + $hpm - $hm];  # Primary Suspension for bogie 3
#node	820032	[expr $x + ($Lp + $w + $wp) + $w/2]			$R2		[expr $hr + $hpm - $hm];  # Primary Suspension for bogie 3

#node	63004	[expr $x + ($Lp + $w + $wp) + $w/2]			$R		[expr $hr + $hpm]; 		# Car Body 2
#node	63005	[expr $x + ($Lp + $w + $wp) + $Lm/2]		$R		[expr $hr + $hpm]; 		# Car Body 2 (COM)

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Intermediate Passenger Cars
set	n	1	
# 	   NodeTag      	  (X)					 												(Y)		(Z)
node	70042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; 					# Wheel for bogie 4
node	70051	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R1		$hr; 					# Wheel for bogie 5

node	80042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; 					# Wheel for bogie 4
node	80051	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		$hr; 					# Wheel for bogie 5

node	71042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; 		# Bogie 4
node	71043	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]; 		# Bogie 4

node	610042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]; 		# Bogie 4

node	81042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; 		# Bogie 4
node	81043	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]; 		# Bogie 4

node	71051	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R1		[expr $hr + $hb]; 		# Bogie 5
node	81051	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		[expr $hr + $hb]; 		# Bogie 5

node	620042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc];  # Primary Suspension for bogie 4
node	720042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc];  # Primary Suspension for bogie 4
node	820042	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc];  # Primary Suspension for bogie 4

node	63006	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; 		# Car Body 2 & 3 (Articulated)
node	63007	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]; 		# Car Body 3 (COM)

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set	n	2		
node	70052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; # Wheels
node	70061	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R1		$hr

node	80052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; # Wheels
node	80061	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		$hr

node	71052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; # Bogies
node	71053	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]
node	71061	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R1		[expr $hr + $hb]

node	610052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]

node	81052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; # Bogies
node	81053	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]
node	81061	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		[expr $hr + $hb]

node	620052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc]; # Primary Suspension
node	720052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc]
node	820052	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc]

node	63008	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; # Car Body
node	63009	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set	n	3	
node	70062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; # Wheels
node	70071	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]  					$R1		$hr

node	80062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; # Wheels
node	80071	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]  					$R2		$hr

node	71062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; # Bogies
node	71063	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]
node	71071	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]  					$R1		[expr $hr + $hb]

node	610062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]
	
node	81062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; # Bogies
node	81063	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]
node	81071	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]  					$R2		[expr $hr + $hb]

node	620062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc]; # Primary Suspension
node	720062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc]
node	820062	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc]

node	63010	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; # Car Body
node	63011	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set	n	4	
node	70072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; # Wheels
node	70081	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R1		$hr

node	80072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; # Wheels
node	80081	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		$hr

node	71072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; # Bogies
node	71073	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]
node	71081	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	   				$R1		[expr $hr + $hb]

node	610072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]

node	81072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; # Bogies
node	81073	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]
node	81081	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)]	    			$R2		[expr $hr + $hb]

node	620072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc]; # Primary Suspension
node	720072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc]
node	820072	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc]

node	63012	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; # Car Body
node	63013	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set	n	5
node	70082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; # Wheels
node	70091	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R1		$hr

node	80082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; # Wheels
node	80091	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R2		$hr

node	71082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; # Bogies
node	71083	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]
node	71091	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R1		[expr $hr + $hb]

node	610082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]

node	81082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; # Bogies
node	81083	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]
node	81091	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R2		[expr $hr + $hb]

node	620082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc]; # Primary Suspension
node	720082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc]
node	820082	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc]

node	63014	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; # Car Body
node	63015	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set	n	6
node	70092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		$hr; # Wheels
node	70101	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R1		$hr

node	80092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		$hr; # Wheels
node	80101	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R2		$hr

node	71092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hb]; # Bogies
node	71093	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R1		[expr $hr + $hb]
node	71101	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R1		[expr $hr + $hb]

node	610092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hb]

node	81092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hb]; # Bogies
node	81093	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w)]					$R2		[expr $hr + $hb]
node	81101	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n)*($Lc - $w)] 					$R2		[expr $hr + $hb]
	
node	620092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm - $hc]; # Primary Suspension
node	720092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R1		[expr $hr + $hcm - $hc]
node	820092	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R2		[expr $hr + $hcm - $hc]

node	63016	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2]			$R		[expr $hr + $hcm]; # Car Body
node	63017	[expr $x + ($Lp + $w + $wp + $Lm) + ($n)*3 + ($n-1)*($Lc - $w) - $w/2 + $Lc/2]	$R		[expr $hr + $hcm]
	
# ------------------------------------------------------------------------------------------------------------------------------------------------------------
	
# Extreme Passenger Car
node	70102	[expr $x + $LT - ($Lp + $w + $wp + $Lm)]	                        	$R1		$hr; # Wheels
node	70111	[expr $x + $LT - ($Lp + 2*$w + $wp)]	                        		$R1		$hr
node	70112	[expr $x + $LT - ($Lp + $w + $wp)]	                        			$R1		$hr

node	80102	[expr $x + $LT - ($Lp + $w + $wp + $Lm)]	                        	$R2		$hr; # Wheels
node	80111	[expr $x + $LT - ($Lp + 2*$w + $wp)]	                        		$R2		$hr
node	80112	[expr $x + $LT - ($Lp + $w + $wp)]	                        			$R2		$hr

node	71102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R1		[expr $hr + $hb]; # Bogies
node	71103	[expr $x + $LT - ($Lp + $w + $wp + $Lm)]	                        	$R1		[expr $hr + $hb]

node	610102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R		[expr $hr + $hb]

node	81102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R2		[expr $hr + $hb]
node	81103	[expr $x + $LT - ($Lp + $w + $wp + $Lm)]	                        	$R2		[expr $hr + $hb]

node	620102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R		[expr $hr + $hcm - $hm]; # Primary Suspension
node	720102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R1		[expr $hr + $hcm - $hm]
node	820102	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R2		[expr $hr + $hcm - $hm]

node	71111	[expr $x + $LT - ($Lp + 2*$w + $wp)]	                        		$R1		[expr $hr + $hb]; # Bogies
node	71112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R1		[expr $hr + $hb]
node	71113	[expr $x + $LT - ($Lp + $w + $wp)]	                        			$R1		[expr $hr + $hb]

node	610112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R		[expr $hr + $hb]

node	81111	[expr $x + $LT - ($Lp + 2*$w + $wp)]	                        		$R2		[expr $hr + $hb]
node	81112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R2		[expr $hr + $hb]
node	81113	[expr $x + $LT - ($Lp + $w + $wp)]	                        			$R2		[expr $hr + $hb]

node	620112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R		[expr $hr + $hcm - $hm]; # Primary Suspension
node	720112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R1		[expr $hr + $hcm - $hm]
node	820112	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R2		[expr $hr + $hcm - $hm]

node	63018	[expr $x + $LT - ($Lp + $w + $wp + $Lm) - $w/2]	                		$R		[expr $hr + $hcm]; # Car Body
node	63019	[expr $x + $LT - ($Lp + $w + $wp + $Lm) + $Lm/2]	                	$R		[expr $hr + $hcm]
node	63020	[expr $x + $LT - ($Lp + $w + $wp) - $w/2]	                			$R		[expr $hr + $hcm]

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Power Car
node	70121	[expr $x + $LT - ($Lp + $w)]	                           		$R1		$hr; # Wheels
node	70122	[expr $x + $LT - $Lp]	                           				$R1		$hr
node	70131	[expr $x + $LT - $w]											$R1		$hr
node	70132	[expr $x + $LT] 												$R1		$hr

node	80121	[expr $x + $LT - ($Lp + $w)]	                           	 	$R2		$hr; # Wheels
node	80122	[expr $x + $LT - $Lp]	                          	 			$R2		$hr
node	80131	[expr $x + $LT - $w]											$R2		$hr
node	80132	[expr $x + $LT] 												$R2		$hr

node	71121	[expr $x + $LT - ($Lp + $w)]	                           	 	$R1		[expr $hr + $hb]; # Bogies
node	71122	[expr $x + $LT - $Lp - $w/2]	                   	 			$R1		[expr $hr + $hb]
node	71123	[expr $x + $LT - $Lp]	                           	 			$R1		[expr $hr + $hb]

node	610122	[expr $x + $LT - $Lp - $w/2]	                   	 			$R		[expr $hr + $hb]

node	81121	[expr $x + $LT - ($Lp + $w)]	                            	$R2		[expr $hr + $hb]
node	81122	[expr $x + $LT - $Lp - $w/2]	                    			$R2		[expr $hr + $hb]
node	81123	[expr $x + $LT - $Lp]	                            			$R2		[expr $hr + $hb]

node	620122	[expr $x + $LT - $Lp - $w/2]	                   	 			$R		[expr $hr + $hpm - $hp]; # Primary Suspension
node	720122	[expr $x + $LT - $Lp - $w/2]	                   	 			$R1		[expr $hr + $hpm - $hp]
node	820122	[expr $x + $LT - $Lp - $w/2]	                   	 			$R2		[expr $hr + $hpm - $hp]

node	71131	[expr $x + $LT - $w]											$R1		[expr $hr + $hb]; # Bogies
node	71132	[expr $x + $LT - $w/2]											$R1		[expr $hr + $hb]
node	71133	[expr $x + $LT] 												$R1		[expr $hr + $hb]
	
node	610132	[expr $x + $LT - $w/2]											$R		[expr $hr + $hb]

node	81131	[expr $x + $LT - $w]											$R2		[expr $hr + $hb]
node	81132	[expr $x + $LT - $w/2]											$R2		[expr $hr + $hb]
node	81133	[expr $x + $LT] 												$R2		[expr $hr + $hb]

node	620132	[expr $x + $LT - $w/2]											$R		[expr $hr + $hpm - $hp]; # Primary Suspension
node	720132	[expr $x + $LT - $w/2]											$R1		[expr $hr + $hpm - $hp]
node	820132	[expr $x + $LT - $w/2]											$R2		[expr $hr + $hpm - $hp]

node	63021	[expr $x + $LT - $Lp - $w/2]	                   	 			$R		[expr $hr + $hpm]; # Car Body
node	63022	[expr $x + $LT - $Lp/2 - $w/2]	                  		 		$R		[expr $hr + $hpm]
node	63023	[expr $x + $LT - $w/2]											$R		[expr $hr + $hpm]


#==============================================================================================================================================================
#					TRAIN SYSTEM CARBODY & BOGIE RIGID CONNECTIONS
#==============================================================================================================================================================

set geomTransf   11
geomTransf Linear  $geomTransf  0 1 0 
set Ar     1e3
set Ir     1e5
set Er     1e8
set Gr     1e8
set Jr     1e6

# Bogie arms in the x-direction
# 							eleTag	  iNode	   jNode	  A		 E		G 	  J      Iy      Iz    transfTag
#element elasticBeamColumn    30001    71011    71012     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30002    71012    71013     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30003    71021    71022     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30004    71022    71023     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30005    71031    71032     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30006    71032    71033     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30007    71041    71042     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30008    71042    71043     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30009    71051    71052     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30010    71052    71053     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30011    71061    71062     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30012    71062    71063     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30013    71071    71072     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30014    71072    71073     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30015    71081    71082     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30016    71082    71083     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30017    71091    71092     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30018    71092    71093     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30019    71101    71102     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30020    71102    71103     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30021    71111    71112     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30022    71112    71113     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30023    71121    71122     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30024    71122    71123     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30025    71131    71132     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30026    71132    71133     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

#element elasticBeamColumn    30027    81011    81012     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30028    81012    81013     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30029    81021    81022     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30030    81022    81023     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30031    81031    81032     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30032    81032    81033     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30033    81041    81042     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30034    81042    81043     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30035    81051    81052     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30036    81052    81053     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30037    81061    81062     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30038    81062    81063     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30039    81071    81072     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30040    81072    81073     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30041    81081    81082     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30042    81082    81083     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30043    81091    81092     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30044    81092    81093     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30045    81101    81102     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30046    81102    81103     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30047    81111    81112     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30048    81112    81113     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30049    81121    81122     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30050    81122    81123     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30051    81131    81132     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30052    81132    81133     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   12
geomTransf Linear  $geomTransf  0 0 1 

# Bogie arms in the y-direction
# 							eleTag	  iNode	   jNode	   A	  E		 G 	   J      Iy      Iz    transfTag
#element elasticBeamColumn    30087    71012    610012     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30088    610012    81012     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30089    71022    610022     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30090    610022    81022     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30100    71032    610032     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element elasticBeamColumn    30101    610032    81032     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30102    71042    610042     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30103    610042    81042     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30104    71052    610052     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30105    610052    81052     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30106    71062    610062     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30107    610062    81062     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30108    71072    610072     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30109    610072    81072     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30110    71082    610082     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30111    610082    81082     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30112    71092    610092     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30113    610092    81092     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30114    71102    610102     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30115    610102    81102     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30116    71112    610112     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30117    610112    81112     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30118    71122    610122     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30119    610122    81122     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30120    71132    610132     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element elasticBeamColumn    30121    610132    81132     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Primary Suspension arms in the y-direction
# 							eleTag	  iNode	   jNode	      A		 E		G 	  J      Iy      Iz    transfTag
#element	elasticBeamColumn	30122	 620012	   720012	 	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30123	 620012	   820012	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30124	 620022	   720022	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30125	 620022	   820022	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30126	 620032	   720032	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30127	 620032	   820032	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30128	 620042	   720042	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30129	 620042	   820042	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30130	 620052	   720052	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30131	 620052	   820052	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30132	 620062	   720062	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30133	 620062	   820062	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30134	 620072	   720072	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30135	 620072	   820072	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30136	 620082	   720082	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30137	 620082	   820082	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30138	 620092	   720092	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30139	 620092	   820092	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30140	 620102	   720102	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30141	 620102	   820102	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30142	 620112	   720112	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30143	 620112	   820112	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30144	 620122	   720122	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30145	 620122	   820122	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30146	 620132	   720132	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30147	 620132	   820132	     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   13
geomTransf Linear  $geomTransf  1 0 0 

# Connection for car-body ends to Primary Suspension system in the z-direction
# 							eleTag	  iNode	   jNode	  A		 E		G 	  J      Iy      Iz    transfTag
#element	elasticBeamColumn	30074	 620012	   63001	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30075	 620022	   63003	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30076	 620032	   63004	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30077	 620042	   63006	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30078	 620052	   63008	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30079	 620062	   63010	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30080	 620072	   63012	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30081	 620082	   63014	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30082	 620092	   63016	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30083	 620102	   63018	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30084	 620112	   63020	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30085	 620122	   63021	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30086	 620132    63023	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

set geomTransf   14
geomTransf Linear  $geomTransf  0 1 0 

# Connecting car-bodies in the x-direction
# All car-bodies except the power cars are connected due to the articulated bogie system
# 							eleTag	  iNode	   jNode	  A		 E		G 	  J      Iy      Iz    transfTag
#element	elasticBeamColumn	30053	  63001	   63002	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30054	  63002	   63003	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30055	  63004	   63005	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
#element	elasticBeamColumn	30056	  63005	   63006     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30057	  63006	   63007	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30058	  63007	   63008	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30059	  63008	   63009	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30060	  63009	   63010	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30061	  63010	   63011	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30062	  63011	   63012	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30063	  63012	   63013	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30064	  63013	   63014	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30065	  63014	   63015	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30066	  63015	   63016	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30067	  63016	   63017	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30068	  63017	   63018	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30069	  63018	   63019	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30070	  63019	   63020	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30072	  63021	   63022     $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf
element	elasticBeamColumn	30073	  63022    63023	 $Ar    $Er    $Gr   $Jr    $Ir     $Ir   $geomTransf


#==============================================================================================================================================================
#					TRAIN SYSTEM SUSPENSIONS
#==============================================================================================================================================================

#=========================================================
#             BOGIE SECONDARY SUSPENSION SYSTEM
#=========================================================

# Power Car
set Kpx   	 303
set Kpy   	 303 
set Kpz   	1270

set Cpy   	 100
set Cpz   	  20
set Cpphi 	4230

# Stiffness
uniaxialMaterial Elastic 	      10 	$Kpx; 				  # x-direction
uniaxialMaterial Elastic 	      11 	$Kpy; 				  # y-direction 
uniaxialMaterial Elastic 	      12 	$Kpz; 				  # z-direction 
uniaxialMaterial Elastic 	      13 	   1; 			      # rz-direction 

# Damping
uniaxialMaterial ViscousDamper 	  14     0     $Cpy    0.01;  # y-direction 
uniaxialMaterial ViscousDamper 	  15     0     $Cpz    0.01;  # z-direction 
uniaxialMaterial ViscousDamper 	  16     0     $Cpphi  0.01;  # rz-direction 

# Combined
uniaxialMaterial Parallel 	      17  	11 	  14; 			  # y-direction 
uniaxialMaterial Parallel 	      18  	12 	  15; 			  # z-direction 
uniaxialMaterial Parallel 	      19  	13 	  16; 			  # rz-direction 

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
#element twoNodeLink 	300002   71012      720012     -mat 10 17 18	 -dir 1 2 3 	-orient 1 0 0 0 1 0
#element twoNodeLink 	300001   610012     620012     -mat 19			 -dir 6			-orient 1 0 0 0 1 0
#element twoNodeLink 	300003   81012      820012     -mat 10 17 18     -dir 1 2 3 	-orient 1 0 0 0 1 0

#element twoNodeLink 	300005   71022      720022     -mat 10 17 18     -dir 1 2 3 	-orient 1 0 0 0 1 0
#element twoNodeLink 	300004   610022     620022     -mat 19		     -dir 6			-orient 1 0 0 0 1 0
#element twoNodeLink 	300006   81022      820022     -mat 10 17 18     -dir 1 2 3 	-orient 1 0 0 0 1 0

element twoNodeLink 	300008   71122      720122     -mat 10 17 18	 -dir 1 2 3 	-orient 1 0 0 0 1 0
element twoNodeLink 	300007   610122     620122     -mat 19			 -dir 6			-orient 1 0 0 0 1 0
element twoNodeLink 	300009   81122      820122     -mat 10 17 18	 -dir 1 2 3 	-orient 1 0 0 0 1 0

element twoNodeLink 	300011   71132      720132     -mat 10 17 18	 -dir 1 2 3 	-orient 1 0 0 0 1 0
element twoNodeLink 	300010   610132     620132     -mat 19		     -dir 6			-orient 1 0 0 0 1 0
element twoNodeLink 	300012   81132      820132     -mat 10 17 18	 -dir 1 2 3 	-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	    DOFs...
#equalDOF   		71012		720012		4 5 6
#equalDOF   		610012		620012		1 2 3 4 5 
#equalDOF   		81012		820012		4 5 6

#equalDOF   		71022		720022		4 5 6
#equalDOF   		610022		620022		1 2 3 4 5 
#equalDOF   		81022		820022		4 5 6
	
equalDOF   		71122		720122		4 5 6
equalDOF   		610122		620122		1 2 3 4 5 
equalDOF   		81122		820122		4 5 6
	
equalDOF   		71132		720132		4 5 6
equalDOF   		610132		620132		1 2 3 4 5 
equalDOF   		81132		820132		4 5 6

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Extreme Passenger Car
set Kmx   	 100
set Kmy   	 150 
set Kmz   	 370

set Cmy		  30
set Cmz		  20
set Cmphi	4230

# Stiffness
uniaxialMaterial Elastic 	      20 	$Kmx; 				  # x-direction
uniaxialMaterial Elastic 	      21 	$Kmy; 				  # y-direction 
uniaxialMaterial Elastic 	      22 	$Kmz; 				  # z-direction 
uniaxialMaterial Elastic 	      23 	   1; 			      # rz-direction 

# Damping
uniaxialMaterial ViscousDamper 	  24     0    $Cmy  0.01;     # y-direction 
uniaxialMaterial ViscousDamper 	  25     0    $Cmz  0.01;     # z-direction 
uniaxialMaterial ViscousDamper 	  26     0    $Cmphi  0.01;   # rz-direction 

# Combined
uniaxialMaterial Parallel 	      27  	21 	  24; 			  # y-direction 
uniaxialMaterial Parallel 	      28  	22 	  25; 			  # z-direction 
uniaxialMaterial Parallel 	      29  	23 	  26; 			  # rz-direction 

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
#element	twoNodeLink		300014	 71032		720032	   -mat 20 27 28  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
#element	twoNodeLink		300013	 610032		620032	   -mat 29  		 -dir 6		  	-orient 1 0 0 0 1 0
#element	twoNodeLink		300015	 81032		820032	   -mat 20 21 22     -dir 1 2 3 	-orient 1 0 0 0 1 0

element	twoNodeLink		300017	 71112		720112	   -mat 20 27 28     -dir 1 2 3 	-orient 1 0 0 0 1 0
element	twoNodeLink		300016	 610112		620112	   -mat 29  		 -dir 6			-orient 1 0 0 0 1 0
element	twoNodeLink		300018	 81112		820112	   -mat 20 27 28     -dir 1 2 3 	-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	    DOFs...
#equalDOF   		71032		720032		4 5 6 
#equalDOF   		610032		620032		1 2 3 4 5 
#equalDOF   		81032		820032		4 5 6

equalDOF   		71112		720112		4 5 6
equalDOF  		610112		620112		1 2 3 4 5 
equalDOF   		81112		820112		4 5 6

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Intermediate Passenger Car
set Kcx   	 100
set Kcy   	 170 
set Kcz   	 303

set Ccphi	 240

# Stiffness
uniaxialMaterial Elastic 	      30 	$Kcx; 				  # x-direction
uniaxialMaterial Elastic 	      31 	$Kcy; 				  # y-direction 
uniaxialMaterial Elastic 	      32 	$Kcz; 				  # z-direction 
uniaxialMaterial Elastic 	      33 	   1; 			      # rz-direction 

# Damping
uniaxialMaterial ViscousDamper 	  34     0    $Ccphi  0.01;   # rz-direction 

# Combined
uniaxialMaterial Parallel 	      35  	33 	  34; 			  # rz-direction 

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
element	twoNodeLink		300020	 71042		720042	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300019	 610042		620042	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300021	 81042		820042	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300023	 71052		720052	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300022	 610052		620052	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300024	 81052		820052	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300026	 71062		720062	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300025	 610062		620062	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300027	 81062		820062	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300029	 71072		720072	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300028	 610072		620072	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300030	 81072		820072	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300032	 71082		720082	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300031	 610082		620082	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300033	 81082		820082	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300035	 71092		720092	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300034	 610092		620092	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300036	 81092		820092	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0

element	twoNodeLink		300038	 71102		720102	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0
element	twoNodeLink		300037	 610102		620102	   -mat 35  		 -dir 6		  	-orient 1 0 0 0 1 0
element	twoNodeLink		300039	 81102		820102	   -mat 30 31 32  	 -dir 1 2 3  	-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	    DOFs...
equalDOF   		71042		720042		4 5 6 
equalDOF   		610042		620042		1 2 3 4 5
equalDOF   		81042		820042		4 5 6

equalDOF   		71052		720052		4 5 6
equalDOF   		610052		620052		1 2 3 4 5
equalDOF   		81052		820052		4 5 6

equalDOF   		71062		720062		4 5 6
equalDOF   		610062		620062		1 2 3 4 5
equalDOF   		81062		820062		4 5 6

equalDOF   		71072		720072		4 5 6
equalDOF   		610072		620072		1 2 3 4 5
equalDOF   		81072		820072		4 5 6

equalDOF   		71082		720082		4 5 6
equalDOF   		610082		620082		1 2 3 4 5
equalDOF   		81082		820082		4 5 6

equalDOF   		71092		720092		4 5 6
equalDOF   		610092		620092		1 2 3 4 5
equalDOF   		81092		820092		4 5 6

equalDOF   		71102		720102		4 5 6
equalDOF   		610102		620102		1 2 3 4 5
equalDOF   		81102		820102		4 5 6
	

#=========================================================
#           AXLE BOX PRIMARY SUSPENSION SYSTEM
#=========================================================

# Power Car
set Kapx   40000
set Kapy    9000
set Kapz  	1250

set Capz      10

# Stiffness
uniaxialMaterial Elastic 	      40 	$Kapx; 				  # x-direction
uniaxialMaterial Elastic 	      41 	$Kapy; 				  # y-direction 
uniaxialMaterial Elastic 	      42 	$Kapz; 				  # z-direction 

# Damping
uniaxialMaterial ViscousDamper 	  43     0    $Capz    0.01;  # z-direction 

# Combined
uniaxialMaterial Parallel 	      44  	42 	  43; 			  # z-direction 

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
#element	twoNodeLink		301262	 71011		70011	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0 
#element	twoNodeLink		301263	 71013		70012	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301264	 71021		70021	   -mat 40 41 44 	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301265	 71023		70022	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0

#element	twoNodeLink		301370	 81011		80011	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301371	 81013		80012	   -mat 40 41 44 	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301372	 81021		80021	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301373	 81023		80022	   -mat 40 41 44	 -dir 1 2 3		-orient 1 0 0 0 1 0

element	twoNodeLink		301366	 71121		70121	   -mat 40 41 44	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301367	 71123		70122	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301368	 71131		70131	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301369	 71133		70132	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0

element	twoNodeLink		301374	 81121		80121	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301375	 81123		80122	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301476	 81131		80131	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301477	 81133		80132	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	    DOFs...
#equalDOF   		71011		70011		4 5 6
#equalDOF   		71013		70012		4 5 6
#equalDOF   		71021		70021		4 5 6
#equalDOF   		71023		70022		4 5 6

#equalDOF   		81011		80011		4 5 6
#equalDOF   		81013		80012		4 5 6
#equalDOF   		81021		80021		4 5 6
#equalDOF   		81023		80022		4 5 6

equalDOF   		71121		70121		4 5 6
equalDOF   		71123		70122		4 5 6
equalDOF   		71131		70131		4 5 6
equalDOF   		71133		70132		4 5 6

equalDOF   		81121		80121		4 5 6
equalDOF  		81123		80122		4 5 6
equalDOF  		81131		80131		4 5 6
equalDOF   		81133		80132		4 5 6

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Extreme Passenger Car

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
#element	twoNodeLink		301478	 71031		70031	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301479	 71033		70032	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0

#element	twoNodeLink		301482	 81031		80031	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
#element	twoNodeLink		301483	 81033		80032	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0

element	twoNodeLink		301480	 71111		70111	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301481	 71113		70112	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0

element	twoNodeLink		301484	 81111		80111	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301485	 81113		80112	   -mat 40 41 44  	 -dir 1 2 3		-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	    DOFs...
#equalDOF   		71031		70031		4 5 6
#equalDOF   		71033		70032		4 5 6

#equalDOF   		81031		80031		4 5 6
#equalDOF   		81033		80032		4 5 6

equalDOF   		71111		70111		4 5 6
equalDOF   		71113		70112		4 5 6

equalDOF   		81111		80111		4 5 6
equalDOF   		81113		80112		4 5 6

# ------------------------------------------------------------------------------------------------------------------------------------------------------------

# Intermediate Passenger Car
set Kacx   55000
set Kacy   11000 
set Kacz     800

set Cacz       6

# Stiffness
uniaxialMaterial Elastic 	      50 	$Kacx; 				  # x-direction
uniaxialMaterial Elastic 	      51 	$Kacy; 				  # y-direction 
uniaxialMaterial Elastic 	      52 	$Kacz; 				  # z-direction 

# Damping
uniaxialMaterial ViscousDamper 	  53     0    $Cacz    0.01;  # z-direction
 
# Combined
uniaxialMaterial Parallel 	      54  	52 	  53; 			  # z-direction 

#						eleTag	 iNode		jNode	    matTag...	 	  dir...		 orient...
element	twoNodeLink		301486	 71041		70041	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301487	 71043		70042	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301488	 71051		70051	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301489	 71053		70052	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301490	 71061		70061	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301491	 71063		70062	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301492	 71071		70071	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301493	 71073		70072	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301494	 71081		70081	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301495	 71083		70082	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301496	 71091		70091	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301497	 71093		70092	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301498	 71101		70101	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301499	 71103		70102	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0

element	twoNodeLink		301500	 81041		80041	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301501	 81043		80042	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301502	 81051		80051	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301503	 81053		80052	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301504	 81061		80061	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301505	 81063		80062	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301506	 81071		80071	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301507	 81073		80072	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301508	 81081		80081	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301509	 81083		80082	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301510	 81091		80091	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301511	 81093		80092	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301512	 81101		80101	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0
element	twoNodeLink		301513	 81103		80102	   -mat 50 51 54 	 -dir 1 2 3		-orient 1 0 0 0 1 0


# Constraining the other DOFs
#				iNode		jNode	   DOFs...
equalDOF		71041		70041	   4 5 6
equalDOF		71043		70042	   4 5 6
equalDOF		71051		70051	   4 5 6
equalDOF		71053		70052	   4 5 6
equalDOF		71061		70061	   4 5 6
equalDOF		71063		70062	   4 5 6
equalDOF		71071		70071	   4 5 6
equalDOF		71073		70072	   4 5 6
equalDOF		71081		70081	   4 5 6
equalDOF		71083		70082	   4 5 6
equalDOF	    71091		70091	   4 5 6
equalDOF		71093		70092	   4 5 6
equalDOF		71101		70101	   4 5 6
equalDOF		71103		70102	   4 5 6

equalDOF		81041		80041	   4 5 6
equalDOF		81043		80042	   4 5 6
equalDOF		81051		80051	   4 5 6
equalDOF		81053		80052	   4 5 6
equalDOF		81061		80061	   4 5 6
equalDOF		81063		80062	   4 5 6
equalDOF		81071		80071	   4 5 6
equalDOF		81073		80072	   4 5 6
equalDOF		81081		80081	   4 5 6
equalDOF		81083		80082	   4 5 6
equalDOF		81091		80091	   4 5 6
equalDOF		81093		80092	   4 5 6
equalDOF		81101		80101	   4 5 6
equalDOF		81103		80102	   4 5 6


#==============================================================================================================================================================
#					TRAIN SYSTEM MASSES
#==============================================================================================================================================================

#=========================================================
#                  CAR BODY MASSES
#=========================================================
# Car Body

# Power Car
set mass     54.960
set massxx   59.400
set massyy 1132.800
set masszz 1112.900

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
#mass	63002	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63022	$mass	$mass	$mass	$massxx	  $massyy	$masszz

# ----------------------------------------------------------------------------

# Extreme Passenger Car
set mass    26.000
set massxx  33.940
set massyy 971.810
set masszz 971.810


#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
#mass	63005	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63019	$mass	$mass	$mass	$massxx	  $massyy	$masszz

# ----------------------------------------------------------------------------

# Intermediate Passenger Car

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	63007	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63009	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63013	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63015	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	63017	$mass	$mass	$mass	$massxx	  $massyy	$masszz

#=========================================================
#                  BOGIE MASSES
#=========================================================
# Bogie

# Power Car
set mass   2.420
set massxx 1.645
set massyy 2.593
set masszz 3.068

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
#mass	610012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	610022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610122	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610132	$mass	$mass	$mass	$massxx	  $massyy	$masszz

# ----------------------------------------------------------------------------

# Extreme Passenger Car
set mass   2.514
set massxx 2.070
set massyy 3.260
set masszz 3.860

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
#mass	610032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610112	$mass	$mass	$mass	$massxx	  $massyy	$masszz

# ----------------------------------------------------------------------------

# Intermediate Passenger Car
set mass   3.050
set massxx 2.030
set massyy 3.200
set masszz 3.790

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	610042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	610102	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#=========================================================
#                  AXLE MASSES
#=========================================================
# Wheel

# Power and Extreme Passenger Car
set mass   1.0250
set massxx 1.0300
set massyy 0.0008
set masszz 1.0300

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
#mass	70011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	70012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	70021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	70022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	70031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	70032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70111	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70112	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70121	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70122	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70131	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70132	$mass	$mass	$mass	$massxx	  $massyy	$masszz

#mass	80011	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	80012	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	80021	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	80022	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	80031	$mass	$mass	$mass	$massxx	  $massyy	$masszz
#mass	80032	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80111	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80112	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80121	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80122	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80131	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80132	$mass	$mass	$mass	$massxx	  $massyy	$masszz

# ----------------------------------------------------------------------------

# Intermediate Passenger Car
set mass   1.0000
set massxx 1.0300
set massyy 0.0008
set masszz 1.0300

#	   nodeTag	 ndf1	 ndf2	 ndf3	  ndf4	    ndf5	  ndf6
mass	70041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	70102	$mass	$mass	$mass	$massxx	  $massyy	$masszz

mass	80041	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80042	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80051	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80052	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80061	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80062	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80071	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80072	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80081	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80082	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80091	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80092	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80101	$mass	$mass	$mass	$massxx	  $massyy	$masszz
mass	80102	$mass	$mass	$mass	$massxx	  $massyy	$masszz


#==============================================================================================================================================================
#					TRAIN AND RAIL INTERACTION
#==============================================================================================================================================================

set geomTransf   16
geomTransf Linear $geomTransf 0 1 0  

set Ar   7.75e-3
set Izr  3.20e-5
set Iyr  5e-6
set Jr   2e-6
set Gr   8.05e6
set Er   2.06e8


# Connecting wheel nodes and rail nodes for the portion of the train that is located on the bridge
# Each individual wheel node and rail node are organized accordingly in Excel
# 							eleTag	  	iNode	    jNode	  	 A		 E		 G 	     J       Iy       Iz     transfTag
element	elasticBeamColumn	8000	11001	11002	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8001	11002	70041	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8002	70041	11003	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8003	11003	70042	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8004	70042	11004	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8005	11004	11005	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8006	11005	11006	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8007	11006	11007	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8008	11007	11008	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8009	11008	70051	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8010	70051	11009	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8011	11009	70052	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8012	70052	11010	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8013	11010	11011	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8014	11011	11012	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8015	11012	11013	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8016	11013	11014	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8017	11014	11015	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8018	11015	70061	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8019	70061	11016	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8020	11016	70062	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8021	70062	11017	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8022	11017	11018	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8023	11018	11019	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8024	11019	11020	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8025	11020	11021	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8026	11021	70071	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8027	70071	11022	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8028	11022	11023	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8029	11023	70072	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8030	70072	11024	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8031	11024	11025	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8032	11025	11026	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8033	11026	11027	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8034	11027	11028	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8035	11028	70081	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8036	70081	11029	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8037	11029	70082	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8038	70082	11030	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8039	11030	11031	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8040	11031	11032	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8041	11032	11033	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8042	11033	11034	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8043	11034	11035	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8044	11035	70091	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8045	70091	70092	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8046	70092	11036	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8047	11036	11037	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8048	11037	11038	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8049	11038	11039	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8050	11039	11040	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8051	11040	70101	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8052	70101	11041	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8053	11041	70102	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8054	70102	11042	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8055	11042	11043	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8056	11043	11044	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8057	11044	11045	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8058	11045	11046	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8059	11046	11047	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8060	11047	70111	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8061	70111	11048	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8062	11048	70112	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8063	70112	11049	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8064	11049	70121	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8065	70121	11050	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8066	11050	70122	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8067	70122	11051	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8068	11051	11052	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8069	11052	11053	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8070	11053	11054	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8071	11054	70131	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8072	70131	11055	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8073	11055	70132	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8074	70132	11056	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8075	11056	11057	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8076	11057	11058	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8077	11058	11059	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8078	11059	11060	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8079	11060	11061	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8080	11061	11062	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8081	11062	11063	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8082	11063	11064	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8083	11064	11065	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8084	11065	11066	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8085	11066	11067	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8086	11067	11068	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8087	11068	11069	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8088	11069	11070	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8089	11070	11071	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8090	11071	11072	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8091	11072	11073	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8092	11073	11074	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8093	11074	11075	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8094	11075	11076	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8095	11076	11077	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8096	11077	11078	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8097	11078	11079	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8098	11079	11080	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8099	11080	11081	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8100	11081	11082	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8101	11082	11083	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8102	11083	11084	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8103	11084	11085	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8104	11085	11086	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8105	11086	11087	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8106	11087	11088	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8107	11088	11089	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8108	11089	11090	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8109	11090	11091	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8110	11091	11092	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8111	11092	11093	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8112	11093	11094	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8113	11094	11095	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8114	11095	11096	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8115	11096	11097	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8116	11097	11098	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8117	11098	11099	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8118	11099	11100	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8119	11100	11101	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8120	11101	11102	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8121	11102	11103	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8122	11103	11104	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8123	11104	11105	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8124	11105	11106	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8125	11106	11107	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8126	11107	11108	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8127	11108	11109	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8128	11109	11110	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf

element	elasticBeamColumn	8140	21001	21002	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8141	21002	80041	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8142	80041	21003	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8143	21003	80042	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8144	80042	21004	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8145	21004	21005	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8146	21005	21006	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8147	21006	21007	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8148	21007	21008	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8149	21008	80051	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8150	80051	21009	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8151	21009	80052	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8152	80052	21010	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8153	21010	21011	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8154	21011	21012	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8155	21012	21013	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8156	21013	21014	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8157	21014	21015	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8158	21015	80061	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8159	80061	21016	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8160	21016	80062	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8161	80062	21017	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8162	21017	21018	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8163	21018	21019	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8164	21019	21020	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8165	21020	21021	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8166	21021	80071	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8167	80071	21022	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8168	21022	21023	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8169	21023	80072	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8170	80072	21024	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8171	21024	21025	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8172	21025	21026	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8173	21026	21027	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8174	21027	21028	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8175	21028	80081	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8176	80081	21029	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8177	21029	80082	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8178	80082	21030	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8179	21030	21031	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8180	21031	21032	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8181	21032	21033	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8182	21033	21034	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8183	21034	21035	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8184	21035	80091	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8185	80091	80092	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8186	80092	21036	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8187	21036	21037	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8188	21037	21038	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8189	21038	21039	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8190	21039	21040	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8191	21040	80101	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8192	80101	21041	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8193	21041	80102	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8194	80102	21042	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8195	21042	21043	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8196	21043	21044	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8197	21044	21045	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8198	21045	21046	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8199	21046	21047	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8200	21047	80111	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8201	80111	21048	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8202	21048	80112	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8203	80112	21049	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8204	21049	80121	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8205	80121	21050	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8206	21050	80122	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8207	80122	21051	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8208	21051	21052	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8209	21052	21053	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8210	21053	21054	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8211	21054	80131	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8212	80131	21055	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8213	21055	80132	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8214	80132	21056	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8215	21056	21057	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8216	21057	21058	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8217	21058	21059	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8218	21059	21060	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8219	21060	21061	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8220	21061	21062	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8221	21062	21063	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8222	21063	21064	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8223	21064	21065	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8224	21065	21066	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8225	21066	21067	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8226	21067	21068	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8227	21068	21069	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8228	21069	21070	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8229	21070	21071	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8230	21071	21072	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8231	21072	21073	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8232	21073	21074	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8233	21074	21075	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8234	21075	21076	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8235	21076	21077	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8236	21077	21078	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8237	21078	21079	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8238	21079	21080	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8239	21080	21081	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8240	21081	21082	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8241	21082	21083	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8242	21083	21084	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8243	21084	21085	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8244	21085	21086	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8245	21086	21087	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8246	21087	21088	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8247	21088	21089	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8248	21089	21090	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8249	21090	21091	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8250	21091	21092	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8251	21092	21093	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8252	21093	21094	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8253	21094	21095	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8254	21095	21096	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8255	21096	21097	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8256	21097	21098	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8257	21098	21099	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8258	21099	21100	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8259	21100	21101	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8260	21101	21102	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8261	21102	21103	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8262	21103	21104	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8263	21104	21105	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8264	21105	21106	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8265	21106	21107	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8266	21107	21108	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8267	21108	21109	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf
element	elasticBeamColumn	8268	21109	21110	$Ar	$Er	$Gr	$Jr	$Izr	$Iyr	$geomTransf


#=========================================================================================================================================================================================
#                       END OF MODEL GENERATION                             
#=========================================================================================================================================================================================
#==========================================================================
#                       DEFINE GRAVITY LOADS                               
#==========================================================================                    

pattern Plain 1 "Linear" {

# Rail Self Weight
#       Node      X       Y         Z         Mx 	  My      Mz
load	11001	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11002	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11003	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11004	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11005	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11006	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11007	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11008	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11009	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11010	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11011	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11012	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11013	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11014	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11015	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11016	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11017	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11018	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11019	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11020	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11021	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11022	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11023	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11024	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11025	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11026	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11027	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11028	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11029	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11030	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11031	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11032	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11033	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11034	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11035	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11036	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11037	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11038	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11039	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11040	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11041	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11042	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11043	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11044	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11045	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11046	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11047	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11048	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11049	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11050	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11051	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11052	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11053	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11054	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11055	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11056	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11057	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11058	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11059	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11060	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11061	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11062	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11063	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11064	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11065	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11066	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11067	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11068	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11069	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11070	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11071	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11072	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11073	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11074	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11075	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11076	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11077	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11078	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11079	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11080	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11081	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11082	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11083	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11084	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11085	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11086	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11087	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11088	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11089	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11090	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11091	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11092	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11093	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11094	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11095	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11096	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11097	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11098	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11099	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11100	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11101	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11102	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11103	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11104	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11105	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11106	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11107	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11108	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11109	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	11110	0.000	0.000	  -1.661 	0.000	0.000	0.000

load	21001	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21002	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21003	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21004	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21005	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21006	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21007	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21008	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21009	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21010	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21011	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21012	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21013	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21014	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21015	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21016	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21017	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21018	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21019	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21020	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21021	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21022	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21023	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21024	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21025	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21026	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21027	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21028	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21029	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21030	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21031	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21032	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21033	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21034	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21035	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21036	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21037	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21038	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21039	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21040	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21041	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21042	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21043	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21044	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21045	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21046	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21047	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21048	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21049	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21050	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21051	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21052	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21053	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21054	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21055	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21056	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21057	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21058	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21059	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21060	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21061	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21062	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21063	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21064	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21065	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21066	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21067	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21068	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21069	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21070	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21071	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21072	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21073	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21074	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21075	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21076	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21077	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21078	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21079	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21080	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21081	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21082	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21083	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21084	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21085	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21086	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21087	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21088	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21089	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21090	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21091	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21092	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21093	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21094	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21095	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21096	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21097	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21098	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21099	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21100	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21101	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21102	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21103	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21104	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21105	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21106	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21107	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21108	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21109	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	21110	0.000	0.000	  -1.661 	0.000	0.000	0.000

load	31001	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31002	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31003	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31004	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31005	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31006	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31007	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31008	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31009	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31010	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31011	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31012	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31013	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31014	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31015	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31016	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31017	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31018	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31019	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31020	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31021	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31022	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31023	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31024	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31025	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31026	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31027	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31028	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31029	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31030	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31031	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31032	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31033	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31034	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31035	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31036	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31037	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31038	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31039	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31040	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31041	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31042	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31043	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31044	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31045	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31046	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31047	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31048	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31049	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31050	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31051	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31052	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31053	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31054	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31055	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31056	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31057	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31058	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31059	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31060	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31061	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31062	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31063	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31064	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31065	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31066	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31067	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31068	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31069	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31070	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31071	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31072	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31073	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31074	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31075	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31076	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31077	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31078	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31079	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31080	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31081	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31082	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31083	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31084	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31085	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31086	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31087	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31088	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31089	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31090	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31091	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31092	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31093	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31094	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31095	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31096	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31097	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31098	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31099	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31100	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31101	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31102	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31103	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31104	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31105	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31106	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31107	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31108	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31109	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	31110	0.000	0.000	  -1.661 	0.000	0.000	0.000

load	41001	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41002	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41003	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41004	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41005	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41006	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41007	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41008	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41009	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41010	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41011	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41012	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41013	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41014	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41015	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41016	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41017	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41018	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41019	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41020	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41021	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41022	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41023	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41024	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41025	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41026	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41027	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41028	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41029	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41030	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41031	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41032	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41033	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41034	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41035	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41036	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41037	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41038	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41039	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41040	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41041	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41042	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41043	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41044	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41045	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41046	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41047	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41048	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41049	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41050	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41051	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41052	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41053	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41054	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41055	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41056	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41057	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41058	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41059	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41060	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41061	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41062	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41063	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41064	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41065	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41066	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41067	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41068	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41069	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41070	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41071	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41072	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41073	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41074	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41075	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41076	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41077	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41078	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41079	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41080	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41081	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41082	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41083	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41084	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41085	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41086	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41087	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41088	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41089	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41090	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41091	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41092	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41093	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41094	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41095	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41096	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41097	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41098	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41099	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41100	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41101	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41102	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41103	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41104	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41105	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41106	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41107	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41108	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41109	0.000	0.000	  -1.661 	0.000	0.000	0.000
load	41110	0.000	0.000	  -1.661 	0.000	0.000	0.000

# Track Plate Self Weight
#       Node      X       Y         Z         Mx 	  My      Mz
load	52001	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52002	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52003	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52004	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52005	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52006	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52007	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52008	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52009	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52010	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52011	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52012	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52013	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52014	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52015	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52016	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52017	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52018	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52019	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52020	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52021	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52022	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52023	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52024	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52025	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52026	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52027	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52028	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52029	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52030	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52031	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52032	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52033	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52034	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52035	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52036	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52037	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52038	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52039	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52040	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52041	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52042	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52043	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52044	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52045	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52046	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52047	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52048	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52049	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52050	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52051	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52052	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52053	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52054	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52055	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52056	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52057	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52058	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52059	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52060	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52061	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52062	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52063	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52064	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52065	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52066	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52067	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52068	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52069	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52070	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52071	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52072	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52073	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52074	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52075	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52076	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52077	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52078	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52079	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52080	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52081	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52082	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52083	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52084	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52085	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52086	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52087	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52088	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52089	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52090	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52091	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52092	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52093	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52094	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52095	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52096	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52097	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52098	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52099	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52100	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52101	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52102	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52103	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52104	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52105	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52106	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52107	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52108	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52109	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	52110	0.000	0.000	 -35.196 	0.000	0.000	0.000

load	62001	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62002	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62003	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62004	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62005	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62006	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62007	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62008	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62009	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62010	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62011	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62012	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62013	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62014	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62015	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62016	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62017	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62018	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62019	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62020	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62021	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62022	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62023	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62024	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62025	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62026	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62027	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62028	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62029	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62030	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62031	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62032	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62033	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62034	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62035	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62036	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62037	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62038	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62039	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62040	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62041	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62042	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62043	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62044	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62045	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62046	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62047	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62048	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62049	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62050	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62051	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62052	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62053	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62054	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62055	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62056	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62057	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62058	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62059	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62060	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62061	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62062	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62063	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62064	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62065	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62066	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62067	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62068	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62069	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62070	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62071	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62072	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62073	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62074	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62075	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62076	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62077	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62078	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62079	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62080	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62081	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62082	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62083	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62084	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62085	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62086	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62087	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62088	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62089	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62090	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62091	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62092	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62093	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62094	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62095	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62096	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62097	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62098	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62099	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62100	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62101	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62102	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62103	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62104	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62105	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62106	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62107	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62108	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62109	0.000	0.000	 -35.196 	0.000	0.000	0.000
load	62110	0.000	0.000	 -35.196 	0.000	0.000	0.000

# Base Plate Self Weight
#       Node      X       Y         Z         Mx 	  My      Mz
load	51001	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51002	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51003	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51004	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51005	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51006	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51007	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51008	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51009	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51010	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51011	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51012	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51013	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51014	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51015	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51016	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51017	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51018	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51019	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51020	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51021	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51022	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51023	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51024	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51025	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51026	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51027	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51028	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51029	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51030	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51031	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51032	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51033	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51034	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51035	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51036	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51037	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51038	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51039	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51040	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51041	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51042	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51043	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51044	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51045	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51046	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51047	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51048	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51049	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51050	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51051	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51052	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51053	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51054	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51055	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51056	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51057	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51058	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51059	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51060	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51061	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51062	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51063	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51064	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51065	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51066	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51067	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51068	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51069	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51070	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51071	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51072	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51073	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51074	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51075	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51076	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51077	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51078	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51079	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51080	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51081	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51082	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51083	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51084	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51085	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51086	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51087	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51088	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51089	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51090	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51091	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51092	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51093	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51094	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51095	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51096	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51097	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51098	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51099	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51100	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51101	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51102	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51103	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51104	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51105	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51106	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51107	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51108	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51109	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	51110	0.000	0.000	 -38.716 	0.000	0.000	0.000

load	61001	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61002	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61003	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61004	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61005	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61006	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61007	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61008	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61009	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61010	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61011	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61012	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61013	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61014	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61015	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61016	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61017	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61018	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61019	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61020	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61021	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61022	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61023	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61024	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61025	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61026	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61027	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61028	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61029	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61030	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61031	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61032	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61033	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61034	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61035	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61036	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61037	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61038	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61039	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61040	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61041	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61042	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61043	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61044	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61045	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61046	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61047	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61048	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61049	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61050	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61051	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61052	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61053	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61054	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61055	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61056	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61057	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61058	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61059	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61060	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61061	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61062	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61063	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61064	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61065	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61066	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61067	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61068	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61069	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61070	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61071	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61072	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61073	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61074	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61075	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61076	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61077	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61078	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61079	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61080	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61081	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61082	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61083	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61084	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61085	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61086	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61087	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61088	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61089	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61090	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61091	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61092	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61093	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61094	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61095	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61096	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61097	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61098	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61099	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61100	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61101	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61102	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61103	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61104	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61105	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61106	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61107	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61108	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61109	0.000	0.000	 -38.716 	0.000	0.000	0.000
load	61110	0.000	0.000	 -38.716 	0.000	0.000	0.000

# -------------------------------------------------------------------------

# Bridge Girder Self Weight
#       Node      X       Y         Z         Mx 	  My      Mz
load	90001	0.000	0.000	-625.249	0.000	0.000	0.000
load	90002	0.000	0.000	-625.249	0.000	0.000	0.000
load	90003	0.000	0.000	-625.249	0.000	0.000	0.000
load	90004	0.000	0.000	-625.249	0.000	0.000	0.000
load	90005	0.000	0.000	-625.249	0.000	0.000	0.000
load	90006	0.000	0.000	-625.249	0.000	0.000	0.000
load	90007	0.000	0.000	-625.249	0.000	0.000	0.000
load	90008	0.000	0.000	-625.249	0.000	0.000	0.000
load	90009	0.000	0.000	-625.249	0.000	0.000	0.000
load	90010	0.000	0.000	-625.249	0.000	0.000	0.000
load	90011	0.000	0.000	-625.249	0.000	0.000	0.000
load	90012	0.000	0.000	-625.249	0.000	0.000	0.000
load	90013	0.000	0.000	-625.249	0.000	0.000	0.000
load	90014	0.000	0.000	-625.249	0.000	0.000	0.000
load	90015	0.000	0.000	-625.249	0.000	0.000	0.000
load	90016	0.000	0.000	-625.249	0.000	0.000	0.000
load	90017	0.000	0.000	-625.249	0.000	0.000	0.000
load	90018	0.000	0.000	-625.249	0.000	0.000	0.000
load	90019	0.000	0.000	-625.249	0.000	0.000	0.000
load	90020	0.000	0.000	-625.249	0.000	0.000	0.000
load	90021	0.000	0.000	-625.249	0.000	0.000	0.000
load	90022	0.000	0.000	-625.249	0.000	0.000	0.000
load	90023	0.000	0.000	-625.249	0.000	0.000	0.000
load	90024	0.000	0.000	-625.249	0.000	0.000	0.000
load	90025	0.000	0.000	-625.249	0.000	0.000	0.000
load	90026	0.000	0.000	-625.249	0.000	0.000	0.000
load	90027	0.000	0.000	-625.249	0.000	0.000	0.000
load	90028	0.000	0.000	-625.249	0.000	0.000	0.000
load	90029	0.000	0.000	-625.249	0.000	0.000	0.000
load	90030	0.000	0.000	-625.249	0.000	0.000	0.000
load	90031	0.000	0.000	-625.249	0.000	0.000	0.000
load	90032	0.000	0.000	-625.249	0.000	0.000	0.000
load	90033	0.000	0.000	-625.249	0.000	0.000	0.000
load	90034	0.000	0.000	-625.249	0.000	0.000	0.000
load	90035	0.000	0.000	-625.249	0.000	0.000	0.000
load	90036	0.000	0.000	-625.249	0.000	0.000	0.000
load	90037	0.000	0.000	-625.249	0.000	0.000	0.000
load	90038	0.000	0.000	-625.249	0.000	0.000	0.000
load	90039	0.000	0.000	-625.249	0.000	0.000	0.000
load	90040	0.000	0.000	-625.249	0.000	0.000	0.000
load	90041	0.000	0.000	-625.249	0.000	0.000	0.000
load	90042	0.000	0.000	-625.249	0.000	0.000	0.000
load	90043	0.000	0.000	-625.249	0.000	0.000	0.000
load	90044	0.000	0.000	-625.249	0.000	0.000	0.000
load	90045	0.000	0.000	-625.249	0.000	0.000	0.000
load	90046	0.000	0.000	-625.249	0.000	0.000	0.000
load	90047	0.000	0.000	-625.249	0.000	0.000	0.000
load	90048	0.000	0.000	-625.249	0.000	0.000	0.000
load	90049	0.000	0.000	-625.249	0.000	0.000	0.000
load	90050	0.000	0.000	-625.249	0.000	0.000	0.000
load	90051	0.000	0.000	-625.249	0.000	0.000	0.000
load	90052	0.000	0.000	-625.249	0.000	0.000	0.000
load	90053	0.000	0.000	-625.249	0.000	0.000	0.000
load	90054	0.000	0.000	-625.249	0.000	0.000	0.000
load	90055	0.000	0.000	-625.249	0.000	0.000	0.000
load	90056	0.000	0.000	-625.249	0.000	0.000	0.000
load	90057	0.000	0.000	-625.249	0.000	0.000	0.000
load	90058	0.000	0.000	-625.249	0.000	0.000	0.000
load	90059	0.000	0.000	-625.249	0.000	0.000	0.000
load	90060	0.000	0.000	-625.249	0.000	0.000	0.000
load	90061	0.000	0.000	-625.249	0.000	0.000	0.000
load	90062	0.000	0.000	-625.249	0.000	0.000	0.000
load	90063	0.000	0.000	-625.249	0.000	0.000	0.000
load	90064	0.000	0.000	-625.249	0.000	0.000	0.000
load	90065	0.000	0.000	-625.249	0.000	0.000	0.000
load	90066	0.000	0.000	-625.249	0.000	0.000	0.000
load	90067	0.000	0.000	-625.249	0.000	0.000	0.000
load	90068	0.000	0.000	-625.249	0.000	0.000	0.000
load	90069	0.000	0.000	-625.249	0.000	0.000	0.000
load	90070	0.000	0.000	-625.249	0.000	0.000	0.000
load	90071	0.000	0.000	-625.249	0.000	0.000	0.000
load	90072	0.000	0.000	-625.249	0.000	0.000	0.000
load	90073	0.000	0.000	-625.249	0.000	0.000	0.000
load	90074	0.000	0.000	-625.249	0.000	0.000	0.000
load	90075	0.000	0.000	-625.249	0.000	0.000	0.000
load	90076	0.000	0.000	-625.249	0.000	0.000	0.000
load	90077	0.000	0.000	-625.249	0.000	0.000	0.000
load	90078	0.000	0.000	-625.249	0.000	0.000	0.000
load	90079	0.000	0.000	-625.249	0.000	0.000	0.000
load	90080	0.000	0.000	-625.249	0.000	0.000	0.000
load	90081	0.000	0.000	-625.249	0.000	0.000	0.000
load	90082	0.000	0.000	-625.249	0.000	0.000	0.000
load	90083	0.000	0.000	-625.249	0.000	0.000	0.000
load	90084	0.000	0.000	-625.249	0.000	0.000	0.000
load	90085	0.000	0.000	-625.249	0.000	0.000	0.000
load	90086	0.000	0.000	-625.249	0.000	0.000	0.000
load	90087	0.000	0.000	-625.249	0.000	0.000	0.000
load	90088	0.000	0.000	-625.249	0.000	0.000	0.000
load	90089	0.000	0.000	-625.249	0.000	0.000	0.000
load	90090	0.000	0.000	-625.249	0.000	0.000	0.000
load	90091	0.000	0.000	-625.249	0.000	0.000	0.000
load	90092	0.000	0.000	-625.249	0.000	0.000	0.000
load	90093	0.000	0.000	-625.249	0.000	0.000	0.000
load	90094	0.000	0.000	-625.249	0.000	0.000	0.000
load	90095	0.000	0.000	-625.249	0.000	0.000	0.000
load	90096	0.000	0.000	-625.249	0.000	0.000	0.000
load	90097	0.000	0.000	-625.249	0.000	0.000	0.000
load	90098	0.000	0.000	-625.249	0.000	0.000	0.000
load	90099	0.000	0.000	-625.249	0.000	0.000	0.000
load	90100	0.000	0.000	-625.249	0.000	0.000	0.000
load	90101	0.000	0.000	-625.249	0.000	0.000	0.000
load	90102	0.000	0.000	-625.249	0.000	0.000	0.000
load	90103	0.000	0.000	-625.249	0.000	0.000	0.000
load	90104	0.000	0.000	-625.249	0.000	0.000	0.000
load	90105	0.000	0.000	-625.249	0.000	0.000	0.000
load	90106	0.000	0.000	-625.249	0.000	0.000	0.000
load	90107	0.000	0.000	-625.249	0.000	0.000	0.000
load	90108	0.000	0.000	-625.249	0.000	0.000	0.000
load	90109	0.000	0.000	-625.249	0.000	0.000	0.000
load	90110	0.000	0.000	-625.249	0.000	0.000	0.000

# Pier Column Self Weight
#       Node      X       Y         Z         Mx 	  My      Mz
load	111		0.000	0.000	-863.582	0.000	0.000	0.000
load	112		0.000	0.000	-863.582	0.000	0.000	0.000
load	113		0.000	0.000	-863.582	0.000	0.000	0.000
load	114		0.000	0.000	-863.582	0.000	0.000	0.000
load	115		0.000	0.000	-863.582	0.000	0.000	0.000

load	211		0.000	0.000	-863.582	0.000	0.000	0.000
load	212		0.000	0.000	-863.582	0.000	0.000	0.000
load	213		0.000	0.000	-863.582	0.000	0.000	0.000
load	214		0.000	0.000	-863.582	0.000	0.000	0.000
load	215		0.000	0.000	-863.582	0.000	0.000	0.000

load	311		0.000	0.000	-863.582	0.000	0.000	0.000
load	312		0.000	0.000	-863.582	0.000	0.000	0.000
load	313		0.000	0.000	-863.582	0.000	0.000	0.000
load	314		0.000	0.000	-863.582	0.000	0.000	0.000
load	315		0.000	0.000	-863.582	0.000	0.000	0.000

load	411		0.000	0.000	-863.582	0.000	0.000	0.000
load	412		0.000	0.000	-863.582	0.000	0.000	0.000
load	413		0.000	0.000	-863.582	0.000	0.000	0.000
load	414		0.000	0.000	-863.582	0.000	0.000	0.000
load	415		0.000	0.000	-863.582	0.000	0.000	0.000

load	511		0.000	0.000	-863.582	0.000	0.000	0.000
load	512		0.000	0.000	-863.582	0.000	0.000	0.000
load	513		0.000	0.000	-863.582	0.000	0.000	0.000
load	514		0.000	0.000	-863.582	0.000	0.000	0.000
load	515		0.000	0.000	-863.582	0.000	0.000	0.000

load	611		0.000	0.000	-863.582	0.000	0.000	0.000
load	612		0.000	0.000	-863.582	0.000	0.000	0.000
load	613		0.000	0.000	-863.582	0.000	0.000	0.000
load	614		0.000	0.000	-863.582	0.000	0.000	0.000
load	615		0.000	0.000	-863.582	0.000	0.000	0.000

load	711		0.000	0.000	-863.582	0.000	0.000	0.000
load	712		0.000	0.000	-863.582	0.000	0.000	0.000
load	713		0.000	0.000	-863.582	0.000	0.000	0.000
load	714		0.000	0.000	-863.582	0.000	0.000	0.000
load	715		0.000	0.000	-863.582	0.000	0.000	0.000

load	811		0.000	0.000	-863.582	0.000	0.000	0.000
load	812		0.000	0.000	-863.582	0.000	0.000	0.000
load	813		0.000	0.000	-863.582	0.000	0.000	0.000
load	814		0.000	0.000	-863.582	0.000	0.000	0.000
load	815		0.000	0.000	-863.582	0.000	0.000	0.000

load	911		0.000	0.000	-863.582	0.000	0.000	0.000
load	912		0.000	0.000	-863.582	0.000	0.000	0.000
load	913		0.000	0.000	-863.582	0.000	0.000	0.000
load	914		0.000	0.000	-863.582	0.000	0.000	0.000
load	915		0.000	0.000	-863.582	0.000	0.000	0.000

load    1011	0.000	0.000	-863.582	0.000	0.000	0.000
load	1012	0.000	0.000	-863.582	0.000	0.000	0.000
load	1013	0.000	0.000	-863.582	0.000	0.000	0.000
load	1014	0.000	0.000	-863.582	0.000	0.000	0.000
load	1015	0.000	0.000	-863.582	0.000	0.000	0.000

load	1211	0.000	0.000	-863.582	0.000	0.000	0.000
load	1212	0.000	0.000	-863.582	0.000	0.000	0.000
load	1213	0.000	0.000	-863.582	0.000	0.000	0.000
load	1214	0.000	0.000	-863.582	0.000	0.000	0.000
load	1215	0.000	0.000	-863.582	0.000	0.000	0.000

# Foundation Self Weight 
#       Node      X       Y         Z         Mx 	  My      Mz
load	1		0.000	0.000  -6177.757	0.000	0.000	0.000
load	2		0.000	0.000  -6177.757	0.000	0.000	0.000
load	3		0.000	0.000  -6177.757	0.000	0.000	0.000
load	4		0.000	0.000  -6177.757	0.000	0.000	0.000
load	5		0.000	0.000  -6177.757	0.000	0.000	0.000
load	6		0.000	0.000  -6177.757	0.000	0.000	0.000
load	7		0.000	0.000  -6177.757	0.000	0.000	0.000
load	8		0.000	0.000  -6177.757	0.000	0.000	0.000
load	9		0.000	0.000  -6177.757	0.000	0.000	0.000
load	10		0.000	0.000  -6177.757	0.000	0.000	0.000
load	11		0.000	0.000  -6177.757	0.000	0.000	0.000

# -------------------------------------------------------------------------

# Power Car Body Loads
#       Node      X       Y         Z         Mx 	  My      Mz
#load	63002	0.000	0.000	-539.158	0.000	0.000	0.000
load	63022	0.000	0.000	-539.158	0.000	0.000	0.000	

# Extreme Passenger Car Body Loads	
#       Node      X       Y         Z         Mx 	  My      Mz					
#load	63005	0.000	0.000	-255.060	0.000	0.000	0.000
load	63019	0.000	0.000	-255.060	0.000	0.000	0.000

# Intermediate Passenger Car Body Loads	
#       Node      X       Y         Z         Mx 	  My      Mz								
load	63007	0.000	0.000	-255.060	0.000	0.000	0.000
load	63009	0.000	0.000	-255.060	0.000	0.000	0.000
load	63011	0.000	0.000	-255.060	0.000	0.000	0.000
load	63013	0.000	0.000	-255.060	0.000	0.000	0.000
load	63015	0.000	0.000	-255.060	0.000	0.000	0.000
load	63017	0.000	0.000	-255.060	0.000	0.000	0.000

# Power Car Bogie Loads				
#       Node      X       Y         Z         Mx 	  My      Mz				
#load	610012	0.000	0.000	-23.740		0.000	0.000	0.000
#load	610022	0.000	0.000	-23.740		0.000	0.000	0.000
load	610122	0.000	0.000	-23.740		0.000	0.000	0.000
load	610132	0.000	0.000	-23.740		0.000	0.000	0.000	

# Extreme Passenger Car Bogie Loads	
#       Node      X       Y         Z         Mx 	  My      Mz					
#load	610032	0.000	0.000	-24.662		0.000	0.000	0.000
load	610112	0.000	0.000	-24.662		0.000	0.000	0.000

# Intermediate Passenger Car Bogie Loads
#       Node      X       Y         Z         Mx 	  My      Mz				
load	610042	0.000	0.000	-29.921		0.000	0.000	0.000
load	610052	0.000	0.000	-29.921		0.000	0.000	0.000
load	610062	0.000	0.000	-29.921		0.000	0.000	0.000
load	610072	0.000	0.000	-29.921		0.000	0.000	0.000
load	610082	0.000	0.000	-29.921		0.000	0.000	0.000
load	610092	0.000	0.000	-29.921		0.000	0.000	0.000
load	610102	0.000	0.000	-29.921		0.000	0.000	0.000

# Power and  Extreme Passenger Car Wheel Loads	
#       Node      X       Y         Z         Mx 	  My      Mz								
#load	70011	0.000	0.000	-10.055		0.000	0.000	0.000
#load	70012	0.000	0.000	-10.055		0.000	0.000	0.000
#load	70021	0.000	0.000	-10.055		0.000	0.000	0.000
#load	70022	0.000	0.000	-10.055		0.000	0.000	0.000
#load	70031	0.000	0.000	-10.055		0.000	0.000	0.000
#load	70032	0.000	0.000	-10.055		0.000	0.000	0.000	
					
#load	80011	0.000	0.000	-10.055		0.000	0.000	0.000
#load	80012	0.000	0.000	-10.055		0.000	0.000	0.000
#load	80021	0.000	0.000	-10.055		0.000	0.000	0.000
#load	80022	0.000	0.000	-10.055		0.000	0.000	0.000
#load	80031	0.000	0.000	-10.055		0.000	0.000	0.000
#load	80032	0.000	0.000	-10.055		0.000	0.000	0.000

load	70111	0.000	0.000	-10.055		0.000	0.000	0.000
load	70112	0.000	0.000	-10.055		0.000	0.000	0.000
load	70121	0.000	0.000	-10.055		0.000	0.000	0.000
load	70122	0.000	0.000	-10.055		0.000	0.000	0.000
load	70131	0.000	0.000	-10.055		0.000	0.000	0.000
load	70132	0.000	0.000	-10.055		0.000	0.000	0.000	

load	80111	0.000	0.000	-10.055		0.000	0.000	0.000
load	80112	0.000	0.000	-10.055		0.000	0.000	0.000
load	80121	0.000	0.000	-10.055		0.000	0.000	0.000
load	80122	0.000	0.000	-10.055		0.000	0.000	0.000
load	80131	0.000	0.000	-10.055		0.000	0.000	0.000
load	80132	0.000	0.000	-10.055		0.000	0.000	0.000

# Intermediate Passenger Car Wheel Loads
#       Node      X       Y         Z         Mx 	  My      Mz											
load	70041	0.000	0.000	-9.810		0.000	0.000	0.000
load	70042	0.000	0.000	-9.810		0.000	0.000	0.000
load	70051	0.000	0.000	-9.810		0.000	0.000	0.000
load	70052	0.000	0.000	-9.810		0.000	0.000	0.000
load	70061	0.000	0.000	-9.810		0.000	0.000	0.000
load	70062	0.000	0.000	-9.810		0.000	0.000	0.000
load	70071	0.000	0.000	-9.810		0.000	0.000	0.000
load	70072	0.000	0.000	-9.810		0.000	0.000	0.000
load	70081	0.000	0.000	-9.810		0.000	0.000	0.000
load	70082	0.000	0.000	-9.810		0.000	0.000	0.000
load	70091	0.000	0.000	-9.810		0.000	0.000	0.000
load	70092	0.000	0.000	-9.810		0.000	0.000	0.000
load	70101	0.000	0.000	-9.810		0.000	0.000	0.000
load	70102	0.000	0.000	-9.810		0.000	0.000	0.000
						
load	80041	0.000	0.000	-9.810		0.000	0.000	0.000
load	80042	0.000	0.000	-9.810		0.000	0.000	0.000
load	80051	0.000	0.000	-9.810		0.000	0.000	0.000
load	80052	0.000	0.000	-9.810		0.000	0.000	0.000
load	80061	0.000	0.000	-9.810		0.000	0.000	0.000
load	80062	0.000	0.000	-9.810		0.000	0.000	0.000
load	80071	0.000	0.000	-9.810		0.000	0.000	0.000
load	80072	0.000	0.000	-9.810		0.000	0.000	0.000
load	80081	0.000	0.000	-9.810		0.000	0.000	0.000
load	80082	0.000	0.000	-9.810		0.000	0.000	0.000
load	80091	0.000	0.000	-9.810		0.000	0.000	0.000
load	80092	0.000	0.000	-9.810		0.000	0.000	0.000
load	80101	0.000	0.000	-9.810		0.000	0.000	0.000
load	80102	0.000	0.000	-9.810		0.000	0.000	0.000
}


#==========================================================================
#                     DEFINE RECORDERS                                     
#==========================================================================
# BASE
recorder Node 		-file  $dataDir/basereactions_x.txt  -time -node  1 2 3 4 5 6 7 8 9 10 11 -dof 1 reaction
recorder Node 		-file  $dataDir/basereactions_y.txt  -time -node  1 2 3 4 5 6 7 8 9 10 11 -dof 2 reaction
recorder Node 		-file  $dataDir/basereactions_z.txt  -time -node  1 2 3 4 5 6 7 8 9 10 11 -dof 3 reaction

# COLUMN
recorder Node 		-file  $dataDir/Ctop_disp_x.txt     -time -node  115 215 315 415 515 615 715 815 915 1015 1215 -dof 1 disp
recorder Node 		-file  $dataDir/Ctop_disp_y.txt     -time -node  115 215 315 415 515 615 715 815 915 1015 1215 -dof 2 disp
recorder Node 		-file  $dataDir/Ctop_disp_z.txt     -time -node  115 215 315 415 515 615 715 815 915 1015 1215 -dof 3 disp

recorder Element 	-file  $dataDir/C_force.txt        	-time -ele  3420 3424 3428 3432 3436 3440 3444 3448 3452 3456 3460 section 1 force;																	# CH5 - Column Bot Shear and Moment Local

recorder Element 	-file  $dataDir/C_deformation.txt  	-time -ele  3420 3424 3428 3432 3436 3440 3444 3448 3452 3456 3460 section 1 deformation;															# CH5 - Column Bot Curvature Local

# GIRDER
recorder Element 	-file  $dataDir/Gend_Forces.txt  	-time -ele 3311 3320 3322 3331 3333 3342 3344 3353 3355 3364 3366 3377 3378 3386 3388 3397 3399 3408 3410 3419 force; 								# CH5 - Girder Ends Shear and Moment Local	

recorder Node 		-file  $dataDir/Gend_disp_x.txt    	-time -node  90001 90011 90012 90022 90023 90033 90034 90044 90045 90055 90056 90066 90067 90077 90078 90088 90089 90099 90100 90110 -dof 1 disp;	# CH5 - Girder Ends Disp Global
recorder Node 		-file  $dataDir/Gend_disp_y.txt    	-time -node  90001 90011 90012 90022 90023 90033 90034 90044 90045 90055 90056 90066 90067 90077 90078 90088 90089 90099 90100 90110 -dof 2 disp;	# CH5 - Girder Ends Disp Global

recorder Node		-file  $dataDir/Gend_accel_x.txt	-time -node  90001 90011 90012 90022 90023 90033 90034 90044 90045 90055 90056 90066 90067 90077 90078 90088 90089 90099 90100 90110 -dof 1 accel;	# CH5 - Girder Ends Accel Global
recorder Node		-file  $dataDir/Gend_accel_y.txt	-time -node  90001 90011 90012 90022 90023 90033 90034 90044 90045 90055 90056 90066 90067 90077 90078 90088 90089 90099 90100 90110 -dof 2 accel;	# CH5 - Girder Ends Accel Global

recorder Node 	 	-file  $dataDir/G_disp_x.txt    	-time -nodeRange 90001 90110 -dof 1 disp
recorder Node 	 	-file  $dataDir/G_disp_y.txt    	-time -nodeRange 90001 90110 -dof 2 disp
recorder Node 	 	-file  $dataDir/G_disp_z.txt    	-time -nodeRange 90001 90110 -dof 3 disp
																																																	
recorder Element 	-file  $dataDir/G_Forces.txt  		-time -ele 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 	3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 	3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 	3344 3345 3346 3347 3348 3349 3350 3351 3352 3353 	3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 		3366 3367 3368 3369 3370 3371 3372 3373 3374 3375 3377 		3378 3379 3380 3381 3382 3383 3384 3385 3386 		3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 		3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 		3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 force

# Interaction Layer
recorder Element 	-file  $dataDir/Sliding_Forces.txt  -time -ele 908 941 force
recorder Element 	-file  $dataDir/CA_Forces.txt  		-time -ele 1128 1161 force
recorder Element 	-file  $dataDir/Fastener_Forces.txt -time -ele 1348 1381 1458 1491 force

recorder Element 	-file  $dataDir/Sliding_Def.txt  -time -ele 908 941 deformation
recorder Element 	-file  $dataDir/CA_Def.txt  		-time -ele 1128 1161 deformation
recorder Element 	-file  $dataDir/Fastener_Def.txt -time -ele 1348 1381 1458 1491 deformation

#==========================================================================
#             START OF ANALYSIS GENERATION FOR GRAVITY ANALYSIS             
#==========================================================================
# Define Gravity Analysis Parameters

# CONSTRAINTS handler-- Determines how the constraint equations are enforced in the analysis
constraints Transformation;				# Transformation Method: Performs a condensation of constrained degrees of freedom 

# DOF NUMBERER -- Numbers the degrees of freedom in the domain
numberer RCM;							# RCM: Renumbers the DOF to minimize the matrix band-width using the Reverse Cuthill-McKee algorithm

# Solution ALGORITHM -- Iterates from the last time step to the current
set algorithmTypeGravity Newton;      	# Newton's solution algorithm: Updates tangent stiffness at every iteration
algorithm $algorithmTypeGravity;

# CONVERGENCE test -- Determines if convergence has been achieved at the end of an iteration step
set Tol 1.0e-6;							# Tolerance
set maxNumIterGravity 100;            	# Max number of iterations
set printFlagGravity 1;		      		# Flag used to print information on convergence (optional)
set TestTypeGravity NormDispIncr;	  	# NormDispIncr: Specifies a tolerance on the norm of the displacement increments at the current iteration 
test $TestTypeGravity 	$Tol  $maxNumIterGravity  $printFlagGravity;

# SYSTEM -- Linear Equation Solvers (how to store and solve the system of equations in the analysis, solves Ku = P)
system UmfPack;							# UmfPack: Direct UmfPack solver for unsymmetric matrices 

# Static INTEGRATOR: -- Determines the next time step for an analysis
set NstepGravity 10;					# Apply gravity in 10 steps
set DGravity [expr 1.0/$NstepGravity];	# First load increment
integrator LoadControl  $DGravity;		# LoadControl: Specifies the incremental load factor to be applied to the loads in the domain 

# ANALYSIS  -- Defines what type of analysis is to be performed
analysis Static;						# Static Analysis: Solves the KU = R problem, without the mass or damping matrices

#==========================================================================
#             PERFORM GRAVITY LOAD ANALYSIS                                 
#==========================================================================
# Perform Gravity Analysis

analyze $NstepGravity; 					# Perform gravity analysis with the amount of steps defined
loadConst -time 0.0;					# Sets loads constant and resets time to be 0.0

puts "################################################"
puts           "Gravity Analysis Complete"
puts "################################################"

#==========================================================================
#                    MODAL ANALYSIS                                     
#==========================================================================
# Perform Modal Analysis

set numModes 10
set lambda [eigen $numModes];		# Number of eigenvalues desired

set T {}
set pi 3.141593

foreach lam $lambda {
	lappend T [expr (2*$pi)/sqrt($lam)]
}

# Open Output File
set period "$dataDir/Periods.txt"
set Periods [open $period "w"]

# Write the Data
foreach t $T {
	puts $Periods "$t"
}

#Close the Fileclose $Periods
close $Periods
 
 
# Make OpenSees output periods for the first 10 modes
puts "T1  [expr 2*3.14/sqrt([lindex $lambda 0])] sec"
puts "T2  [expr 2*3.14/sqrt([lindex $lambda 1])] sec"
puts "T3  [expr 2*3.14/sqrt([lindex $lambda 2])] sec"
puts "T4  [expr 2*3.14/sqrt([lindex $lambda 3])] sec"

puts "TAKE CARE! - Moustafa "

#==========================================================================
#                    DEFINE DAMPING                                     
#==========================================================================
# Select two modes for Rayleigh Damping
set wi 			[expr sqrt([lindex $lambda 0])];		# Natural frequency of mode 1
set wj 			[expr sqrt([lindex $lambda 6])];		# Natural frequency of mode 6

# Define damping coefficient
set xi 			0.02; 								# Damping Coefficient MIGHT CHANGE (2 or 5%)

# Define parameters for damping equation
set alphaM 		[expr $xi*(2*$wi*$wj)/($wi+$wj)]; 	# M-prop. damping; D = alphaM*M
set betaKcurr  	0.; 								# K-proportional damping; +betaKcurr*KCurrent
set betaKinit  	[expr $xi*(2)/($wi+$wj)];			# Initial stiffness proportional damping; +betaKinit*Kini
set betaKcomm  	0.; 								# K-prop. damping parameter; +betaKcomm*KlastCommitt

rayleigh $alphaM $betaKcurr $betaKinit $betaKcomm;	# Apply Rayleigh Damping

#==========================================================================
#                      DEFINE TRANSIENT LOADS                              
#==========================================================================
# Define Dynamic Analysis Parameters

# CONSTRAINTS handler-- Determines how the constraint equations are enforced in the analysis
constraints Transformation;				# Transformation Method: Performs a condensation of constrained degrees of freedom 

# DOF NUMBERER -- Numbers the degrees of freedom in the domain
numberer RCM;							# RCM: Renumbers the DOF to minimize the matrix band-width using the Reverse Cuthill-McKee algorithm 

# Solution ALGORITHM: -- Iterates from the last time step to the current
set algorithmTypeDynamic Newton;		# Newton: Uses the tangent at the current iteration to iterate to convergence
algorithm $algorithmTypeDynamic		

# CONVERGENCE test -- Determines if convergence has been achieved at the end of an iteration step
set TolDynamic 1.e-8;                   # Tolerance
set maxNumIterDynamic 1000;             # Maximum number of iterations that will be performed before "failure to converge" is returned
set printFlagDynamic 1;               	# Flag used to print information on convergence (optional)
set testTypeDynamic EnergyIncr;			# EnergyIncr: Specifies a tolerance on the inner product of the unbalanced load and displacement increments at the current iteration 
test $testTypeDynamic $TolDynamic $maxNumIterDynamic $printFlagDynamic

# SYSTEM -- Linear Equation Solvers (how to store and solve the system of equations in the analysis, solves Ku = P)
set systemTypeDynamic UmfPack;			# UmfPack: Direct UmfPack solver for unsymmetric matrices 
system  $systemTypeDynamic						

# Dynamic INTEGRATOR: -- Determines the next time step for an analysis
set NewmarkGamma 0.5;					# Newmark-integrator gamma parameter
set NewmarkBeta 0.25;					# Newmark-integrator beta parameter
set integratorTypeDynamic Newmark;
integrator $integratorTypeDynamic $NewmarkGamma $NewmarkBeta

# ANALYSIS  -- Defines what type of analysis is to be performed
analysis Transient;						# Transient Analysis: Solves the time-dependent analysis. The time step in this type of analysis is constant. 

# -------------------------------------------------------------------------
# Define Ground Motion Parameters

set GMfile "RSN1004_NORTHR_SPV270";			# Ground-motion file from PEER
source ReadSMDFile.tcl;						# Converts PEER ground-motion to an OpenSees readable format
set inFilename $GMfile.AT2;					# Original filename and extension (AT2)
set outFilename $GMfile.g3; 				# Set variable holding new filename (PEER files have .at2/dt2 extension)
ReadSMDFile $inFilename $outFilename dt;	# Call procedure to convert the ground-motion file

set DT 				0.005;					# Time-step used in dynamic analysis
set Nstep 			9557;					# Number of steps in dynamic analysis

set GMfact  	   $scale; 					# Convert GM acceleration from "g" to m/s2 
set GMfatt		[expr $g*$GMfact];			# Total GM amplification

# -------------------------------------------------------------------------
# Apply Ground Motion to Model

set IDloadTagx 400; 			# For uniformSupport excitation
set GMdirection_x 1; 			# Ground-motion x-direction
set xacc "Series -dt $DT -filePath $outFilename -factor $GMfatt"; 	# Time series information
pattern UniformExcitation $IDloadTagx $GMdirection_x -accel $xacc; 	# Create uniform excitation

set IDloadTagy 500; 			# For uniformSupport excitation
set GMdirection_y 2; 			# Ground-motion y-direction
set yacc "Series -dt $DT -filePath $outFilename -factor $GMfatt"; 	# Time series information
pattern UniformExcitation $IDloadTagy $GMdirection_y -accel $yacc; 	# Create uniform excitation

#==========================================================================
#                  PERFORM DYNAMIC LOAD ANALYSIS                              
#==========================================================================
# Perform Dynamic Load Analysis

set ok [analyze $Nstep $DT];			# Perform analysis; returns ok = 0 if analysis was successful

# Create a Loop to Try Other Algorithms and Convergence Test Types if Initial Analysis Fails

set TmaxAnalysis  [expr $Nstep*$DT];  	# Maximum duration of ground-motion analysis

if {$ok != 0} {
set ok 0;
set controlTime [getTime];
while {$controlTime < $TmaxAnalysis && $ok == 0} {
set controlTime [getTime]
set ok [analyze 1 $DT]
if {$ok != 0} {
puts "Trying Newton with Initial Tangent .."
test NormDispIncr $Tol 1000 1
algorithm Newton -initial
set ok [analyze 1 $DT]
test $testTypeDynamic $TolDynamic $maxNumIterDynamic 0
algorithm $algorithmTypeDynamic
}
if {$ok != 0} {
puts "Trying Broyden .."
algorithm Broyden 8
set ok [analyze 1 $DT]
algorithm $algorithmTypeDynamic
}
if {$ok != 0} {
puts "Trying NewtonWithLineSearch .."
algorithm NewtonLineSearch .8
set ok [analyze 1 $DT]
algorithm $algorithmTypeDynamic
}
}; # end while loop
}; # end if ok !0


puts "################################################"
puts     "Ground Motion Done. End Time: [getTime]"
puts "################################################"
